%%
%% This is file 'bxcoloremoji-names.def'.
%%
%% Copyright (c) 2017-2024 Takayuki YATO (aka. "ZR")
%%   GitHub:   https://github.com/zr-tex8r
%%   Twitter:  @zr_tex8r
%%
%% This package is distributed under the MIT License.
%%

%% file declaration
\ProvidesFile{bxcoloremoji-names.def}[2024/11/18 v1.0a]

%--------------------------------------- name mappings
\bxce@ndbegin
\ifcase\bxce@ndindex %[0]
\bxce@do{100}{1F4AF}
\bxce@do{1234}{1F522}
\bxce@do{8ball}{1F3B1}
\bxce@do{a}{1F170}
\bxce@do{ab}{1F18E}
\bxce@do{abacus}{1F9EE}
\bxce@do{abc}{1F524}
\bxce@do{abcd}{1F521}
\bxce@do{accept}{1F251}
\bxce@do{accordion}{1FA97}
\bxce@do{adhesive_bandage}{1FA79}
\bxce@do{adult}{1F9D1}
\bxce@do{adult_tone1}{1F9D1 1F3FB}
\bxce@do{adult_tone2}{1F9D1 1F3FC}
\bxce@do{adult_tone3}{1F9D1 1F3FD}
\bxce@do{adult_tone4}{1F9D1 1F3FE}
\bxce@do{adult_tone5}{1F9D1 1F3FF}
\bxce@do{aerial_tramway}{1F6A1}
\bxce@do{airplane}{2708}
\bxce@do{airplane_arriving}{1F6EC}
\bxce@do{airplane_departure}{1F6EB}
\bxce@do{airplane_small}{1F6E9}
\bxce@do{alarm_clock}{23F0}
\bxce@do{alembic}{2697}
\bxce@do{alien}{1F47D}
\bxce@do{ambulance}{1F691}
\bxce@do{amphora}{1F3FA}
\bxce@do{anatomical_heart}{1FAC0}
\bxce@do{anchor}{2693}
\bxce@do{angel}{1F47C}
\bxce@do{angel_tone1}{1F47C 1F3FB}
\bxce@do{angel_tone2}{1F47C 1F3FC}
\bxce@do{angel_tone3}{1F47C 1F3FD}
\bxce@do{angel_tone4}{1F47C 1F3FE}
\bxce@do{angel_tone5}{1F47C 1F3FF}
\bxce@do{anger}{1F4A2}
\bxce@do{anger_right}{1F5EF}
\bxce@do{angry}{1F620}
\bxce@do{anguished}{1F627}
\bxce@do{ant}{1F41C}
\bxce@do{apple}{1F34E}
\bxce@do{aquarius}{2652}
\bxce@do{aries}{2648}
\bxce@do{arrow_backward}{25C0}
\bxce@do{arrow_double_down}{23EC}
\bxce@do{arrow_double_up}{23EB}
\bxce@do{arrow_down}{2B07}
\bxce@do{arrow_down_small}{1F53D}
\bxce@do{arrow_forward}{25B6}
\bxce@do{arrow_heading_down}{2935}
\bxce@do{arrow_heading_up}{2934}
\bxce@do{arrow_left}{2B05}
\bxce@do{arrow_lower_left}{2199}
\bxce@do{arrow_lower_right}{2198}
\bxce@do{arrow_right}{27A1}
\bxce@do{arrow_right_hook}{21AA}
\bxce@do{arrow_up}{2B06}
\bxce@do{arrow_up_down}{2195}
\bxce@do{arrow_up_small}{1F53C}
\bxce@do{arrow_upper_left}{2196}
\bxce@do{arrow_upper_right}{2197}
\bxce@do{arrows_clockwise}{1F503}
\bxce@do{arrows_counterclockwise}{1F504}
\bxce@do{art}{1F3A8}
\bxce@do{articulated_lorry}{1F69B}
\bxce@do{artist}{1F9D1 200D 1F3A8}
\bxce@do{artist_tone1}{1F9D1 1F3FB 200D 1F3A8}
\bxce@do{artist_tone2}{1F9D1 1F3FC 200D 1F3A8}
\bxce@do{artist_tone3}{1F9D1 1F3FD 200D 1F3A8}
\bxce@do{artist_tone4}{1F9D1 1F3FE 200D 1F3A8}
\bxce@do{artist_tone5}{1F9D1 1F3FF 200D 1F3A8}
\bxce@do{asterisk}{2A 20E3}
\bxce@do{asterisk_symbol}{2A}%NA
\bxce@do{astonished}{1F632}
\bxce@do{astronaut}{1F9D1 200D 1F680}
\bxce@do{astronaut_tone1}{1F9D1 1F3FB 200D 1F680}
\bxce@do{astronaut_tone2}{1F9D1 1F3FC 200D 1F680}
\bxce@do{astronaut_tone3}{1F9D1 1F3FD 200D 1F680}
\bxce@do{astronaut_tone4}{1F9D1 1F3FE 200D 1F680}
\bxce@do{astronaut_tone5}{1F9D1 1F3FF 200D 1F680}
\bxce@do{athletic_shoe}{1F45F}
\bxce@do{atm}{1F3E7}
\bxce@do{atom}{269B}
\bxce@do{auto_rickshaw}{1F6FA}
\bxce@do{avocado}{1F951}
\bxce@do{axe}{1FA93}
\bxce@do{b}{1F171}
\bxce@do{baby}{1F476}
\bxce@do{baby_bottle}{1F37C}
\bxce@do{baby_chick}{1F424}
\bxce@do{baby_symbol}{1F6BC}
\bxce@do{baby_tone1}{1F476 1F3FB}
\bxce@do{baby_tone2}{1F476 1F3FC}
\bxce@do{baby_tone3}{1F476 1F3FD}
\bxce@do{baby_tone4}{1F476 1F3FE}
\bxce@do{baby_tone5}{1F476 1F3FF}
\bxce@do{back}{1F519}
\bxce@do{bacon}{1F953}
\bxce@do{badger}{1F9A1}
\bxce@do{badminton}{1F3F8}
\bxce@do{bagel}{1F96F}
\bxce@do{baggage_claim}{1F6C4}
\bxce@do{bald}{1F9B2}
\bxce@do{ballet_shoes}{1FA70}
\bxce@do{balloon}{1F388}
\bxce@do{ballot_box}{1F5F3}
\bxce@do{ballot_box_with_check}{2611}
\bxce@do{bamboo}{1F38D}
\bxce@do{banana}{1F34C}
\bxce@do{bangbang}{203C}
\bxce@do{banjo}{1FA95}
\bxce@do{bank}{1F3E6}
\bxce@do{bar_chart}{1F4CA}
\bxce@do{barber}{1F488}
\bxce@do{baseball}{26BE}
\bxce@do{basket}{1F9FA}
\bxce@do{basketball}{1F3C0}
\bxce@do{bat}{1F987}
\bxce@do{bath}{1F6C0}
\bxce@do{bath_tone1}{1F6C0 1F3FB}
\bxce@do{bath_tone2}{1F6C0 1F3FC}
\bxce@do{bath_tone3}{1F6C0 1F3FD}
\bxce@do{bath_tone4}{1F6C0 1F3FE}
\bxce@do{bath_tone5}{1F6C0 1F3FF}
\bxce@do{bathtub}{1F6C1}
\bxce@do{battery}{1F50B}
\bxce@do{beach}{1F3D6}
\bxce@do{beach_umbrella}{26F1}
\bxce@do{bear}{1F43B}
\bxce@do{bearded_person}{1F9D4}
\bxce@do{bearded_person_tone1}{1F9D4 1F3FB}
\bxce@do{bearded_person_tone2}{1F9D4 1F3FC}
\bxce@do{bearded_person_tone3}{1F9D4 1F3FD}
\bxce@do{bearded_person_tone4}{1F9D4 1F3FE}
\bxce@do{bearded_person_tone5}{1F9D4 1F3FF}
\bxce@do{beaver}{1F9AB}
\bxce@do{bed}{1F6CF}
\bxce@do{bee}{1F41D}
\bxce@do{beer}{1F37A}
\bxce@do{beers}{1F37B}
\bxce@do{beetle}{1FAB2}
\bxce@do{beginner}{1F530}
\bxce@do{bell}{1F514}
\bxce@do{bell_pepper}{1FAD1}
\bxce@do{bellhop}{1F6CE}
\bxce@do{bento}{1F371}
\bxce@do{beverage_box}{1F9C3}
\bxce@do{bike}{1F6B2}
\bxce@do{bikini}{1F459}
\bxce@do{billed_cap}{1F9E2}
\bxce@do{biohazard}{2623}
\bxce@do{bird}{1F426}
\bxce@do{birthday}{1F382}
\bxce@do{bison}{1F9AC}
\bxce@do{black_cat}{1F408 200D 2B1B}
\bxce@do{black_circle}{26AB}
\bxce@do{black_heart}{1F5A4}
\bxce@do{black_joker}{1F0CF}
\bxce@do{black_large_square}{2B1B}
\bxce@do{black_medium_small_square}{25FE}
\bxce@do{black_medium_square}{25FC}
\bxce@do{black_nib}{2712}
\bxce@do{black_small_square}{25AA}
\bxce@do{black_square_button}{1F532}
\bxce@do{blond-haired_man}{1F471 200D 2642}
\bxce@do{blond-haired_man_tone1}{1F471 1F3FB 200D 2642}
\bxce@do{blond-haired_man_tone2}{1F471 1F3FC 200D 2642}
\bxce@do{blond-haired_man_tone3}{1F471 1F3FD 200D 2642}
\bxce@do{blond-haired_man_tone4}{1F471 1F3FE 200D 2642}
\bxce@do{blond-haired_man_tone5}{1F471 1F3FF 200D 2642}
\bxce@do{blond-haired_woman}{1F471 200D 2640}
\bxce@do{blond-haired_woman_tone1}{1F471 1F3FB 200D 2640}
\bxce@do{blond-haired_woman_tone2}{1F471 1F3FC 200D 2640}
\bxce@do{blond-haired_woman_tone3}{1F471 1F3FD 200D 2640}
\bxce@do{blond-haired_woman_tone4}{1F471 1F3FE 200D 2640}
\bxce@do{blond-haired_woman_tone5}{1F471 1F3FF 200D 2640}
\bxce@do{blond_haired_person}{1F471}
\bxce@do{blond_haired_person_tone1}{1F471 1F3FB}
\bxce@do{blond_haired_person_tone2}{1F471 1F3FC}
\bxce@do{blond_haired_person_tone3}{1F471 1F3FD}
\bxce@do{blond_haired_person_tone4}{1F471 1F3FE}
\bxce@do{blond_haired_person_tone5}{1F471 1F3FF}
\bxce@do{blossom}{1F33C}
\bxce@do{blowfish}{1F421}
\bxce@do{blue_book}{1F4D8}
\bxce@do{blue_car}{1F699}
\bxce@do{blue_circle}{1F535}
\bxce@do{blue_heart}{1F499}
\bxce@do{blue_square}{1F7E6}
\bxce@do{blueberries}{1FAD0}
\bxce@do{blush}{1F60A}
\bxce@do{boar}{1F417}
\bxce@do{bomb}{1F4A3}
\bxce@do{bone}{1F9B4}
\bxce@do{book}{1F4D6}
\bxce@do{bookmark}{1F516}
\bxce@do{bookmark_tabs}{1F4D1}
\bxce@do{books}{1F4DA}
\bxce@do{boom}{1F4A5}
\bxce@do{boomerang}{1FA83}
\bxce@do{boot}{1F462}
\bxce@do{bouquet}{1F490}
\bxce@do{bow_and_arrow}{1F3F9}
\bxce@do{bowl_with_spoon}{1F963}
\bxce@do{bowling}{1F3B3}
\bxce@do{boxing_glove}{1F94A}
\bxce@do{boy}{1F466}
\bxce@do{boy_tone1}{1F466 1F3FB}
\bxce@do{boy_tone2}{1F466 1F3FC}
\bxce@do{boy_tone3}{1F466 1F3FD}
\bxce@do{boy_tone4}{1F466 1F3FE}
\bxce@do{boy_tone5}{1F466 1F3FF}
\bxce@do{brain}{1F9E0}
\bxce@do{bread}{1F35E}
\bxce@do{breast_feeding}{1F931}
\bxce@do{breast_feeding_tone1}{1F931 1F3FB}
\bxce@do{breast_feeding_tone2}{1F931 1F3FC}
\bxce@do{breast_feeding_tone3}{1F931 1F3FD}
\bxce@do{breast_feeding_tone4}{1F931 1F3FE}
\bxce@do{breast_feeding_tone5}{1F931 1F3FF}
\bxce@do{bricks}{1F9F1}
\bxce@do{bridge_at_night}{1F309}
\bxce@do{briefcase}{1F4BC}
\bxce@do{briefs}{1FA72}
\bxce@do{broccoli}{1F966}
\bxce@do{broken_heart}{1F494}
\bxce@do{broom}{1F9F9}
\bxce@do{brown_circle}{1F7E4}
\bxce@do{brown_heart}{1F90E}
\bxce@do{brown_square}{1F7EB}
\bxce@do{bubble_tea}{1F9CB}
\bxce@do{bucket}{1FAA3}
\bxce@do{bug}{1F41B}
\bxce@do{bulb}{1F4A1}
\bxce@do{bullettrain_front}{1F685}
\bxce@do{bullettrain_side}{1F684}
\bxce@do{burrito}{1F32F}
\bxce@do{bus}{1F68C}
\bxce@do{busstop}{1F68F}
\bxce@do{bust_in_silhouette}{1F464}
\bxce@do{busts_in_silhouette}{1F465}
\bxce@do{butter}{1F9C8}
\bxce@do{butterfly}{1F98B}
\bxce@do{cactus}{1F335}
\bxce@do{cake}{1F370}
\bxce@do{calendar}{1F4C6}
\bxce@do{calendar_spiral}{1F5D3}
\bxce@do{call_me}{1F919}
\bxce@do{call_me_tone1}{1F919 1F3FB}
\bxce@do{call_me_tone2}{1F919 1F3FC}
\bxce@do{call_me_tone3}{1F919 1F3FD}
\bxce@do{call_me_tone4}{1F919 1F3FE}
\bxce@do{call_me_tone5}{1F919 1F3FF}
\bxce@do{calling}{1F4F2}
\bxce@do{camel}{1F42B}
\bxce@do{camera}{1F4F7}
\bxce@do{camera_with_flash}{1F4F8}
\bxce@do{camping}{1F3D5}
\bxce@do{cancer}{264B}
\bxce@do{candle}{1F56F}
\bxce@do{candy}{1F36C}
\bxce@do{canned_food}{1F96B}
\bxce@do{canoe}{1F6F6}
\bxce@do{capital_abcd}{1F520}
\bxce@do{capricorn}{2651}
\bxce@do{card_box}{1F5C3}
\bxce@do{card_index}{1F4C7}
\bxce@do{carousel_horse}{1F3A0}
\bxce@do{carpentry_saw}{1FA9A}
\bxce@do{carrot}{1F955}
\bxce@do{cat}{1F431}
\bxce@do{cat2}{1F408}
\bxce@do{cd}{1F4BF}
\bxce@do{chains}{26D3}
\bxce@do{chair}{1FA91}
\bxce@do{champagne}{1F37E}
\bxce@do{champagne_glass}{1F942}
\bxce@do{chart}{1F4B9}
\bxce@do{chart_with_downwards_trend}{1F4C9}
\bxce@do{chart_with_upwards_trend}{1F4C8}
\bxce@do{checkered_flag}{1F3C1}
\bxce@do{cheese}{1F9C0}
\bxce@do{cherries}{1F352}
\bxce@do{cherry_blossom}{1F338}
\bxce@do{chess_pawn}{265F}
\bxce@do{chestnut}{1F330}
\bxce@do{chicken}{1F414}
\bxce@do{child}{1F9D2}
\bxce@do{child_tone1}{1F9D2 1F3FB}
\bxce@do{child_tone2}{1F9D2 1F3FC}
\bxce@do{child_tone3}{1F9D2 1F3FD}
\bxce@do{child_tone4}{1F9D2 1F3FE}
\bxce@do{child_tone5}{1F9D2 1F3FF}
\bxce@do{children_crossing}{1F6B8}
\bxce@do{chipmunk}{1F43F}
\bxce@do{chocolate_bar}{1F36B}
\bxce@do{chopsticks}{1F962}
\bxce@do{christmas_tree}{1F384}
\bxce@do{church}{26EA}
\bxce@do{cinema}{1F3A6}
\bxce@do{circus_tent}{1F3AA}
\bxce@do{city_dusk}{1F306}
\bxce@do{city_sunset}{1F307}
\bxce@do{cityscape}{1F3D9}
\bxce@do{cl}{1F191}
\bxce@do{clap}{1F44F}
\bxce@do{clap_tone1}{1F44F 1F3FB}
\bxce@do{clap_tone2}{1F44F 1F3FC}
\bxce@do{clap_tone3}{1F44F 1F3FD}
\bxce@do{clap_tone4}{1F44F 1F3FE}
\bxce@do{clap_tone5}{1F44F 1F3FF}
\bxce@do{clapper}{1F3AC}
\bxce@do{classical_building}{1F3DB}
\bxce@do{clipboard}{1F4CB}
\bxce@do{clock}{1F570}
\bxce@do{clock1}{1F550}
\bxce@do{clock10}{1F559}
\bxce@do{clock1030}{1F565}
\bxce@do{clock11}{1F55A}
\bxce@do{clock1130}{1F566}
\bxce@do{clock12}{1F55B}
\bxce@do{clock1230}{1F567}
\bxce@do{clock130}{1F55C}
\bxce@do{clock2}{1F551}
\bxce@do{clock230}{1F55D}
\bxce@do{clock3}{1F552}
\bxce@do{clock330}{1F55E}
\bxce@do{clock4}{1F553}
\bxce@do{clock430}{1F55F}
\bxce@do{clock5}{1F554}
\bxce@do{clock530}{1F560}
\bxce@do{clock6}{1F555}
\bxce@do{clock630}{1F561}
\bxce@do{clock7}{1F556}
\bxce@do{clock730}{1F562}
\bxce@do{clock8}{1F557}
\bxce@do{clock830}{1F563}
\bxce@do{clock9}{1F558}
\bxce@do{clock930}{1F564}
\bxce@do{closed_book}{1F4D5}
\bxce@do{closed_lock_with_key}{1F510}
\bxce@do{closed_umbrella}{1F302}
\bxce@do{cloud}{2601}
\bxce@do{cloud_lightning}{1F329}
\bxce@do{cloud_rain}{1F327}
\bxce@do{cloud_snow}{1F328}
\bxce@do{cloud_tornado}{1F32A}
\bxce@do{clown}{1F921}
\bxce@do{clubs}{2663}
\bxce@do{coat}{1F9E5}
\bxce@do{cockroach}{1FAB3}
\bxce@do{cocktail}{1F378}
\bxce@do{coconut}{1F965}
\bxce@do{coffee}{2615}
\bxce@do{coffin}{26B0}
\bxce@do{coin}{1FA99}
\bxce@do{cold_face}{1F976}
\bxce@do{cold_sweat}{1F630}
\bxce@do{comet}{2604}
\bxce@do{compass}{1F9ED}
\bxce@do{compression}{1F5DC}
\bxce@do{computer}{1F4BB}
\bxce@do{confetti_ball}{1F38A}
\bxce@do{confounded}{1F616}
\bxce@do{confused}{1F615}
\bxce@do{congratulations}{3297}
\bxce@do{construction}{1F6A7}
\bxce@do{construction_site}{1F3D7}
\bxce@do{construction_worker}{1F477}
\bxce@do{construction_worker_tone1}{1F477 1F3FB}
\bxce@do{construction_worker_tone2}{1F477 1F3FC}
\bxce@do{construction_worker_tone3}{1F477 1F3FD}
\bxce@do{construction_worker_tone4}{1F477 1F3FE}
\bxce@do{construction_worker_tone5}{1F477 1F3FF}
\bxce@do{control_knobs}{1F39B}
\bxce@do{convenience_store}{1F3EA}
\bxce@do{cook}{1F9D1 200D 1F373}
\bxce@do{cook_tone1}{1F9D1 1F3FB 200D 1F373}
\bxce@do{cook_tone2}{1F9D1 1F3FC 200D 1F373}
\bxce@do{cook_tone3}{1F9D1 1F3FD 200D 1F373}
\bxce@do{cook_tone4}{1F9D1 1F3FE 200D 1F373}
\bxce@do{cook_tone5}{1F9D1 1F3FF 200D 1F373}
\bxce@do{cookie}{1F36A}
\bxce@do{cooking}{1F373}
\bxce@do{cool}{1F192}
\bxce@do{copyright}{A9}
\bxce@do{corn}{1F33D}
\bxce@do{couch}{1F6CB}
\bxce@do{couple}{1F46B}
\bxce@do{couple_mm}{1F468 200D 2764 200D 1F468}
\bxce@do{couple_with_heart}{1F491}
\bxce@do{couple_with_heart_man_man}{1F468 200D 2764 200D 1F468}
\bxce@do{couple_with_heart_man_man_tone1}{1F468 1F3FB 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_man_man_tone1_tone2}{1F468 1F3FB 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_man_man_tone1_tone3}{1F468 1F3FB 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_man_man_tone1_tone4}{1F468 1F3FB 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_man_man_tone1_tone5}{1F468 1F3FB 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_man_man_tone2}{1F468 1F3FC 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_man_man_tone2_tone1}{1F468 1F3FC 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_man_man_tone2_tone3}{1F468 1F3FC 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_man_man_tone2_tone4}{1F468 1F3FC 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_man_man_tone2_tone5}{1F468 1F3FC 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_man_man_tone3}{1F468 1F3FD 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_man_man_tone3_tone1}{1F468 1F3FD 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_man_man_tone3_tone2}{1F468 1F3FD 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_man_man_tone3_tone4}{1F468 1F3FD 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_man_man_tone3_tone5}{1F468 1F3FD 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_man_man_tone4}{1F468 1F3FE 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_man_man_tone4_tone1}{1F468 1F3FE 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_man_man_tone4_tone2}{1F468 1F3FE 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_man_man_tone4_tone3}{1F468 1F3FE 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_man_man_tone4_tone5}{1F468 1F3FE 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_man_man_tone5}{1F468 1F3FF 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_man_man_tone5_tone1}{1F468 1F3FF 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_man_man_tone5_tone2}{1F468 1F3FF 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_man_man_tone5_tone3}{1F468 1F3FF 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_man_man_tone5_tone4}{1F468 1F3FF 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_person_person}{1F491}
\bxce@do{couple_with_heart_person_person_tone1}{1F491 1F3FB}
\bxce@do{couple_with_heart_person_person_tone1_tone2}{1F9D1 1F3FB 200D 2764 200D 1F9D1 1F3FC}
\bxce@do{couple_with_heart_person_person_tone1_tone3}{1F9D1 1F3FB 200D 2764 200D 1F9D1 1F3FD}
\bxce@do{couple_with_heart_person_person_tone1_tone4}{1F9D1 1F3FB 200D 2764 200D 1F9D1 1F3FE}
\bxce@do{couple_with_heart_person_person_tone1_tone5}{1F9D1 1F3FB 200D 2764 200D 1F9D1 1F3FF}
\bxce@do{couple_with_heart_person_person_tone2}{1F491 1F3FC}
\bxce@do{couple_with_heart_person_person_tone2_tone1}{1F9D1 1F3FC 200D 2764 200D 1F9D1 1F3FB}
\bxce@do{couple_with_heart_person_person_tone2_tone3}{1F9D1 1F3FC 200D 2764 200D 1F9D1 1F3FD}
\bxce@do{couple_with_heart_person_person_tone2_tone4}{1F9D1 1F3FC 200D 2764 200D 1F9D1 1F3FE}
\bxce@do{couple_with_heart_person_person_tone2_tone5}{1F9D1 1F3FC 200D 2764 200D 1F9D1 1F3FF}
\bxce@do{couple_with_heart_person_person_tone3}{1F491 1F3FD}
\bxce@do{couple_with_heart_person_person_tone3_tone1}{1F9D1 1F3FD 200D 2764 200D 1F9D1 1F3FB}
\bxce@do{couple_with_heart_person_person_tone3_tone2}{1F9D1 1F3FD 200D 2764 200D 1F9D1 1F3FC}
\bxce@do{couple_with_heart_person_person_tone3_tone4}{1F9D1 1F3FD 200D 2764 200D 1F9D1 1F3FE}
\bxce@do{couple_with_heart_person_person_tone3_tone5}{1F9D1 1F3FD 200D 2764 200D 1F9D1 1F3FF}
\bxce@do{couple_with_heart_person_person_tone4}{1F491 1F3FE}
\bxce@do{couple_with_heart_person_person_tone4_tone1}{1F9D1 1F3FE 200D 2764 200D 1F9D1 1F3FB}
\bxce@do{couple_with_heart_person_person_tone4_tone2}{1F9D1 1F3FE 200D 2764 200D 1F9D1 1F3FC}
\bxce@do{couple_with_heart_person_person_tone4_tone3}{1F9D1 1F3FE 200D 2764 200D 1F9D1 1F3FD}
\bxce@do{couple_with_heart_person_person_tone4_tone5}{1F9D1 1F3FE 200D 2764 200D 1F9D1 1F3FF}
\bxce@do{couple_with_heart_person_person_tone5}{1F491 1F3FF}
\bxce@do{couple_with_heart_person_person_tone5_tone1}{1F9D1 1F3FF 200D 2764 200D 1F9D1 1F3FB}
\bxce@do{couple_with_heart_person_person_tone5_tone2}{1F9D1 1F3FF 200D 2764 200D 1F9D1 1F3FC}
\bxce@do{couple_with_heart_person_person_tone5_tone3}{1F9D1 1F3FF 200D 2764 200D 1F9D1 1F3FD}
\bxce@do{couple_with_heart_person_person_tone5_tone4}{1F9D1 1F3FF 200D 2764 200D 1F9D1 1F3FE}
\bxce@do{couple_with_heart_tone1}{1F491 1F3FB}
\bxce@do{couple_with_heart_tone2}{1F491 1F3FC}
\bxce@do{couple_with_heart_tone3}{1F491 1F3FD}
\bxce@do{couple_with_heart_tone4}{1F491 1F3FE}
\bxce@do{couple_with_heart_tone5}{1F491 1F3FF}
\bxce@do{couple_with_heart_woman_man}{1F469 200D 2764 200D 1F468}
\bxce@do{couple_with_heart_woman_man_tone1}{1F469 1F3FB 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_woman_man_tone1_tone2}{1F469 1F3FB 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_woman_man_tone1_tone3}{1F469 1F3FB 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_woman_man_tone1_tone4}{1F469 1F3FB 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_woman_man_tone1_tone5}{1F469 1F3FB 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_woman_man_tone2}{1F469 1F3FC 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_woman_man_tone2_tone1}{1F469 1F3FC 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_woman_man_tone2_tone3}{1F469 1F3FC 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_woman_man_tone2_tone4}{1F469 1F3FC 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_woman_man_tone2_tone5}{1F469 1F3FC 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_woman_man_tone3}{1F469 1F3FD 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_woman_man_tone3_tone1}{1F469 1F3FD 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_woman_man_tone3_tone2}{1F469 1F3FD 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_woman_man_tone3_tone4}{1F469 1F3FD 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_woman_man_tone3_tone5}{1F469 1F3FD 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_woman_man_tone4}{1F469 1F3FE 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_woman_man_tone4_tone1}{1F469 1F3FE 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_woman_man_tone4_tone2}{1F469 1F3FE 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_woman_man_tone4_tone3}{1F469 1F3FE 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_woman_man_tone4_tone5}{1F469 1F3FE 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_woman_man_tone5}{1F469 1F3FF 200D 2764 200D 1F468 1F3FF}
\bxce@do{couple_with_heart_woman_man_tone5_tone1}{1F469 1F3FF 200D 2764 200D 1F468 1F3FB}
\bxce@do{couple_with_heart_woman_man_tone5_tone2}{1F469 1F3FF 200D 2764 200D 1F468 1F3FC}
\bxce@do{couple_with_heart_woman_man_tone5_tone3}{1F469 1F3FF 200D 2764 200D 1F468 1F3FD}
\bxce@do{couple_with_heart_woman_man_tone5_tone4}{1F469 1F3FF 200D 2764 200D 1F468 1F3FE}
\bxce@do{couple_with_heart_woman_woman}{1F469 200D 2764 200D 1F469}
\bxce@do{couple_with_heart_woman_woman_tone1}{1F469 1F3FB 200D 2764 200D 1F469 1F3FB}
\bxce@do{couple_with_heart_woman_woman_tone1_tone2}{1F469 1F3FB 200D 2764 200D 1F469 1F3FC}
\bxce@do{couple_with_heart_woman_woman_tone1_tone3}{1F469 1F3FB 200D 2764 200D 1F469 1F3FD}
\bxce@do{couple_with_heart_woman_woman_tone1_tone4}{1F469 1F3FB 200D 2764 200D 1F469 1F3FE}
\bxce@do{couple_with_heart_woman_woman_tone1_tone5}{1F469 1F3FB 200D 2764 200D 1F469 1F3FF}
\bxce@do{couple_with_heart_woman_woman_tone2}{1F469 1F3FC 200D 2764 200D 1F469 1F3FC}
\bxce@do{couple_with_heart_woman_woman_tone2_tone1}{1F469 1F3FC 200D 2764 200D 1F469 1F3FB}
\bxce@do{couple_with_heart_woman_woman_tone2_tone3}{1F469 1F3FC 200D 2764 200D 1F469 1F3FD}
\bxce@do{couple_with_heart_woman_woman_tone2_tone4}{1F469 1F3FC 200D 2764 200D 1F469 1F3FE}
\bxce@do{couple_with_heart_woman_woman_tone2_tone5}{1F469 1F3FC 200D 2764 200D 1F469 1F3FF}
\bxce@do{couple_with_heart_woman_woman_tone3}{1F469 1F3FD 200D 2764 200D 1F469 1F3FD}
\bxce@do{couple_with_heart_woman_woman_tone3_tone1}{1F469 1F3FD 200D 2764 200D 1F469 1F3FB}
\bxce@do{couple_with_heart_woman_woman_tone3_tone2}{1F469 1F3FD 200D 2764 200D 1F469 1F3FC}
\bxce@do{couple_with_heart_woman_woman_tone3_tone4}{1F469 1F3FD 200D 2764 200D 1F469 1F3FE}
\bxce@do{couple_with_heart_woman_woman_tone3_tone5}{1F469 1F3FD 200D 2764 200D 1F469 1F3FF}
\bxce@do{couple_with_heart_woman_woman_tone4}{1F469 1F3FE 200D 2764 200D 1F469 1F3FE}
\bxce@do{couple_with_heart_woman_woman_tone4_tone1}{1F469 1F3FE 200D 2764 200D 1F469 1F3FB}
\bxce@do{couple_with_heart_woman_woman_tone4_tone2}{1F469 1F3FE 200D 2764 200D 1F469 1F3FC}
\bxce@do{couple_with_heart_woman_woman_tone4_tone3}{1F469 1F3FE 200D 2764 200D 1F469 1F3FD}
\bxce@do{couple_with_heart_woman_woman_tone4_tone5}{1F469 1F3FE 200D 2764 200D 1F469 1F3FF}
\bxce@do{couple_with_heart_woman_woman_tone5}{1F469 1F3FF 200D 2764 200D 1F469 1F3FF}
\bxce@do{couple_with_heart_woman_woman_tone5_tone1}{1F469 1F3FF 200D 2764 200D 1F469 1F3FB}
\bxce@do{couple_with_heart_woman_woman_tone5_tone2}{1F469 1F3FF 200D 2764 200D 1F469 1F3FC}
\bxce@do{couple_with_heart_woman_woman_tone5_tone3}{1F469 1F3FF 200D 2764 200D 1F469 1F3FD}
\bxce@do{couple_with_heart_woman_woman_tone5_tone4}{1F469 1F3FF 200D 2764 200D 1F469 1F3FE}
\bxce@do{couple_ww}{1F469 200D 2764 200D 1F469}
\bxce@do{couplekiss}{1F48F}
\bxce@do{cow}{1F42E}
\bxce@do{cow2}{1F404}
\bxce@do{cowboy}{1F920}
\bxce@do{crab}{1F980}
\bxce@do{crayon}{1F58D}
\bxce@do{credit_card}{1F4B3}
\bxce@do{crescent_moon}{1F319}
\bxce@do{cricket}{1F997}
\bxce@do{cricket_game}{1F3CF}
\bxce@do{crocodile}{1F40A}
\bxce@do{croissant}{1F950}
\bxce@do{cross}{271D}
\bxce@do{crossed_flags}{1F38C}
\bxce@do{crossed_swords}{2694}
\bxce@do{crown}{1F451}
\bxce@do{cruise_ship}{1F6F3}
\bxce@do{cry}{1F622}
\bxce@do{crying_cat_face}{1F63F}
\bxce@do{crystal_ball}{1F52E}
\bxce@do{cucumber}{1F952}
\bxce@do{cup_with_straw}{1F964}
\bxce@do{cupcake}{1F9C1}
\bxce@do{cupid}{1F498}
\bxce@do{curling_stone}{1F94C}
\bxce@do{curly_haired}{1F9B1}
\bxce@do{curly_loop}{27B0}
\bxce@do{currency_exchange}{1F4B1}
\bxce@do{curry}{1F35B}
\bxce@do{custard}{1F36E}
\bxce@do{customs}{1F6C3}
\bxce@do{cut_of_meat}{1F969}
\bxce@do{cyclone}{1F300}
\or %[1]
\bxce@do{dagger}{1F5E1}
\bxce@do{dancer}{1F483}
\bxce@do{dancer_tone1}{1F483 1F3FB}
\bxce@do{dancer_tone2}{1F483 1F3FC}
\bxce@do{dancer_tone3}{1F483 1F3FD}
\bxce@do{dancer_tone4}{1F483 1F3FE}
\bxce@do{dancer_tone5}{1F483 1F3FF}
\bxce@do{dango}{1F361}
\bxce@do{dark_sunglasses}{1F576}
\bxce@do{dart}{1F3AF}
\bxce@do{dash}{1F4A8}
\bxce@do{date}{1F4C5}
\bxce@do{deaf_man}{1F9CF 200D 2642}
\bxce@do{deaf_man_tone1}{1F9CF 1F3FB 200D 2642}
\bxce@do{deaf_man_tone2}{1F9CF 1F3FC 200D 2642}
\bxce@do{deaf_man_tone3}{1F9CF 1F3FD 200D 2642}
\bxce@do{deaf_man_tone4}{1F9CF 1F3FE 200D 2642}
\bxce@do{deaf_man_tone5}{1F9CF 1F3FF 200D 2642}
\bxce@do{deaf_person}{1F9CF}
\bxce@do{deaf_person_tone1}{1F9CF 1F3FB}
\bxce@do{deaf_person_tone2}{1F9CF 1F3FC}
\bxce@do{deaf_person_tone3}{1F9CF 1F3FD}
\bxce@do{deaf_person_tone4}{1F9CF 1F3FE}
\bxce@do{deaf_person_tone5}{1F9CF 1F3FF}
\bxce@do{deaf_woman}{1F9CF 200D 2640}
\bxce@do{deaf_woman_tone1}{1F9CF 1F3FB 200D 2640}
\bxce@do{deaf_woman_tone2}{1F9CF 1F3FC 200D 2640}
\bxce@do{deaf_woman_tone3}{1F9CF 1F3FD 200D 2640}
\bxce@do{deaf_woman_tone4}{1F9CF 1F3FE 200D 2640}
\bxce@do{deaf_woman_tone5}{1F9CF 1F3FF 200D 2640}
\bxce@do{deciduous_tree}{1F333}
\bxce@do{deer}{1F98C}
\bxce@do{department_store}{1F3EC}
\bxce@do{desert}{1F3DC}
\bxce@do{desktop}{1F5A5}
\bxce@do{detective}{1F575}
\bxce@do{detective_tone1}{1F575 1F3FB}
\bxce@do{detective_tone2}{1F575 1F3FC}
\bxce@do{detective_tone3}{1F575 1F3FD}
\bxce@do{detective_tone4}{1F575 1F3FE}
\bxce@do{detective_tone5}{1F575 1F3FF}
\bxce@do{diamond_shape_with_a_dot_inside}{1F4A0}
\bxce@do{diamonds}{2666}
\bxce@do{digit_eight}{38}%NA
\bxce@do{digit_five}{35}%NA
\bxce@do{digit_four}{34}%NA
\bxce@do{digit_nine}{39}%NA
\bxce@do{digit_one}{31}%NA
\bxce@do{digit_seven}{37}%NA
\bxce@do{digit_six}{36}%NA
\bxce@do{digit_three}{33}%NA
\bxce@do{digit_two}{32}%NA
\bxce@do{digit_zero}{30}%NA
\bxce@do{disappointed}{1F61E}
\bxce@do{disappointed_relieved}{1F625}
\bxce@do{disguised_face}{1F978}
\bxce@do{dividers}{1F5C2}
\bxce@do{diving_mask}{1F93F}
\bxce@do{diya_lamp}{1FA94}
\bxce@do{dizzy}{1F4AB}
\bxce@do{dizzy_face}{1F635}
\bxce@do{dna}{1F9EC}
\bxce@do{do_not_litter}{1F6AF}
\bxce@do{dodo}{1F9A4}
\bxce@do{dog}{1F436}
\bxce@do{dog2}{1F415}
\bxce@do{dollar}{1F4B5}
\bxce@do{dolls}{1F38E}
\bxce@do{dolphin}{1F42C}
\bxce@do{door}{1F6AA}
\bxce@do{doughnut}{1F369}
\bxce@do{dove}{1F54A}
\bxce@do{dragon}{1F409}
\bxce@do{dragon_face}{1F432}
\bxce@do{dress}{1F457}
\bxce@do{dromedary_camel}{1F42A}
\bxce@do{drooling_face}{1F924}
\bxce@do{drop_of_blood}{1FA78}
\bxce@do{droplet}{1F4A7}
\bxce@do{drum}{1F941}
\bxce@do{duck}{1F986}
\bxce@do{dumpling}{1F95F}
\bxce@do{dvd}{1F4C0}
\bxce@do{e-mail}{1F4E7}
\bxce@do{eagle}{1F985}
\bxce@do{ear}{1F442}
\bxce@do{ear_of_rice}{1F33E}
\bxce@do{ear_tone1}{1F442 1F3FB}
\bxce@do{ear_tone2}{1F442 1F3FC}
\bxce@do{ear_tone3}{1F442 1F3FD}
\bxce@do{ear_tone4}{1F442 1F3FE}
\bxce@do{ear_tone5}{1F442 1F3FF}
\bxce@do{ear_with_hearing_aid}{1F9BB}
\bxce@do{ear_with_hearing_aid_tone1}{1F9BB 1F3FB}
\bxce@do{ear_with_hearing_aid_tone2}{1F9BB 1F3FC}
\bxce@do{ear_with_hearing_aid_tone3}{1F9BB 1F3FD}
\bxce@do{ear_with_hearing_aid_tone4}{1F9BB 1F3FE}
\bxce@do{ear_with_hearing_aid_tone5}{1F9BB 1F3FF}
\bxce@do{earth_africa}{1F30D}
\bxce@do{earth_americas}{1F30E}
\bxce@do{earth_asia}{1F30F}
\bxce@do{egg}{1F95A}
\bxce@do{eggplant}{1F346}
\bxce@do{eight}{38 20E3}
\bxce@do{eight_pointed_black_star}{2734}
\bxce@do{eight_spoked_asterisk}{2733}
\bxce@do{eject}{23CF}
\bxce@do{electric_plug}{1F50C}
\bxce@do{elephant}{1F418}
\bxce@do{elevator}{1F6D7}
\bxce@do{elf}{1F9DD}
\bxce@do{elf_tone1}{1F9DD 1F3FB}
\bxce@do{elf_tone2}{1F9DD 1F3FC}
\bxce@do{elf_tone3}{1F9DD 1F3FD}
\bxce@do{elf_tone4}{1F9DD 1F3FE}
\bxce@do{elf_tone5}{1F9DD 1F3FF}
\bxce@do{end}{1F51A}
\bxce@do{england}{1F3F4 E0067 E0062 E0065 E006E E0067 E007F}
\bxce@do{envelope}{2709}
\bxce@do{envelope_with_arrow}{1F4E9}
\bxce@do{euro}{1F4B6}
\bxce@do{european_castle}{1F3F0}
\bxce@do{european_post_office}{1F3E4}
\bxce@do{evergreen_tree}{1F332}
\bxce@do{exclamation}{2757}
\bxce@do{exploding_head}{1F92F}
\bxce@do{expressionless}{1F611}
\bxce@do{eye}{1F441}
\bxce@do{eye_in_speech_bubble}{1F441 200D 1F5E8}
\bxce@do{eyeglasses}{1F453}
\bxce@do{eyes}{1F440}
\bxce@do{face_exhaling}{1F62E 200D 1F4A8}
\bxce@do{face_in_clouds}{1F636 200D 1F32B}
\bxce@do{face_vomiting}{1F92E}
\bxce@do{face_with_hand_over_mouth}{1F92D}
\bxce@do{face_with_monocle}{1F9D0}
\bxce@do{face_with_raised_eyebrow}{1F928}
\bxce@do{face_with_spiral_eyes}{1F635 200D 1F4AB}
\bxce@do{face_with_symbols_over_mouth}{1F92C}
\bxce@do{factory}{1F3ED}
\bxce@do{factory_worker}{1F9D1 200D 1F3ED}
\bxce@do{factory_worker_tone1}{1F9D1 1F3FB 200D 1F3ED}
\bxce@do{factory_worker_tone2}{1F9D1 1F3FC 200D 1F3ED}
\bxce@do{factory_worker_tone3}{1F9D1 1F3FD 200D 1F3ED}
\bxce@do{factory_worker_tone4}{1F9D1 1F3FE 200D 1F3ED}
\bxce@do{factory_worker_tone5}{1F9D1 1F3FF 200D 1F3ED}
\bxce@do{fairy}{1F9DA}
\bxce@do{fairy_tone1}{1F9DA 1F3FB}
\bxce@do{fairy_tone2}{1F9DA 1F3FC}
\bxce@do{fairy_tone3}{1F9DA 1F3FD}
\bxce@do{fairy_tone4}{1F9DA 1F3FE}
\bxce@do{fairy_tone5}{1F9DA 1F3FF}
\bxce@do{falafel}{1F9C6}
\bxce@do{fallen_leaf}{1F342}
\bxce@do{family}{1F46A}
\bxce@do{family_man_boy}{1F468 200D 1F466}
\bxce@do{family_man_boy_boy}{1F468 200D 1F466 200D 1F466}
\bxce@do{family_man_girl}{1F468 200D 1F467}
\bxce@do{family_man_girl_boy}{1F468 200D 1F467 200D 1F466}
\bxce@do{family_man_girl_girl}{1F468 200D 1F467 200D 1F467}
\bxce@do{family_man_woman_boy}{1F468 200D 1F469 200D 1F466}
\bxce@do{family_mmb}{1F468 200D 1F468 200D 1F466}
\bxce@do{family_mmbb}{1F468 200D 1F468 200D 1F466 200D 1F466}
\bxce@do{family_mmg}{1F468 200D 1F468 200D 1F467}
\bxce@do{family_mmgb}{1F468 200D 1F468 200D 1F467 200D 1F466}
\bxce@do{family_mmgg}{1F468 200D 1F468 200D 1F467 200D 1F467}
\bxce@do{family_mwbb}{1F468 200D 1F469 200D 1F466 200D 1F466}
\bxce@do{family_mwg}{1F468 200D 1F469 200D 1F467}
\bxce@do{family_mwgb}{1F468 200D 1F469 200D 1F467 200D 1F466}
\bxce@do{family_mwgg}{1F468 200D 1F469 200D 1F467 200D 1F467}
\bxce@do{family_woman_boy}{1F469 200D 1F466}
\bxce@do{family_woman_boy_boy}{1F469 200D 1F466 200D 1F466}
\bxce@do{family_woman_girl}{1F469 200D 1F467}
\bxce@do{family_woman_girl_boy}{1F469 200D 1F467 200D 1F466}
\bxce@do{family_woman_girl_girl}{1F469 200D 1F467 200D 1F467}
\bxce@do{family_wwb}{1F469 200D 1F469 200D 1F466}
\bxce@do{family_wwbb}{1F469 200D 1F469 200D 1F466 200D 1F466}
\bxce@do{family_wwg}{1F469 200D 1F469 200D 1F467}
\bxce@do{family_wwgb}{1F469 200D 1F469 200D 1F467 200D 1F466}
\bxce@do{family_wwgg}{1F469 200D 1F469 200D 1F467 200D 1F467}
\bxce@do{farmer}{1F9D1 200D 1F33E}
\bxce@do{farmer_tone1}{1F9D1 1F3FB 200D 1F33E}
\bxce@do{farmer_tone2}{1F9D1 1F3FC 200D 1F33E}
\bxce@do{farmer_tone3}{1F9D1 1F3FD 200D 1F33E}
\bxce@do{farmer_tone4}{1F9D1 1F3FE 200D 1F33E}
\bxce@do{farmer_tone5}{1F9D1 1F3FF 200D 1F33E}
\bxce@do{fast_forward}{23E9}
\bxce@do{fax}{1F4E0}
\bxce@do{fearful}{1F628}
\bxce@do{feather}{1FAB6}
\bxce@do{feet}{1F43E}
\bxce@do{female_sign}{2640}
\bxce@do{ferris_wheel}{1F3A1}
\bxce@do{ferry}{26F4}
\bxce@do{field_hockey}{1F3D1}
\bxce@do{file_cabinet}{1F5C4}
\bxce@do{file_folder}{1F4C1}
\bxce@do{film_frames}{1F39E}
\bxce@do{fingers_crossed}{1F91E}
\bxce@do{fingers_crossed_tone1}{1F91E 1F3FB}
\bxce@do{fingers_crossed_tone2}{1F91E 1F3FC}
\bxce@do{fingers_crossed_tone3}{1F91E 1F3FD}
\bxce@do{fingers_crossed_tone4}{1F91E 1F3FE}
\bxce@do{fingers_crossed_tone5}{1F91E 1F3FF}
\bxce@do{fire}{1F525}
\bxce@do{fire_engine}{1F692}
\bxce@do{fire_extinguisher}{1F9EF}
\bxce@do{firecracker}{1F9E8}
\bxce@do{firefighter}{1F9D1 200D 1F692}
\bxce@do{firefighter_tone1}{1F9D1 1F3FB 200D 1F692}
\bxce@do{firefighter_tone2}{1F9D1 1F3FC 200D 1F692}
\bxce@do{firefighter_tone3}{1F9D1 1F3FD 200D 1F692}
\bxce@do{firefighter_tone4}{1F9D1 1F3FE 200D 1F692}
\bxce@do{firefighter_tone5}{1F9D1 1F3FF 200D 1F692}
\bxce@do{fireworks}{1F386}
\bxce@do{first_place}{1F947}
\bxce@do{first_quarter_moon}{1F313}
\bxce@do{first_quarter_moon_with_face}{1F31B}
\bxce@do{fish}{1F41F}
\bxce@do{fish_cake}{1F365}
\bxce@do{fishing_pole_and_fish}{1F3A3}
\bxce@do{fist}{270A}
\bxce@do{fist_tone1}{270A 1F3FB}
\bxce@do{fist_tone2}{270A 1F3FC}
\bxce@do{fist_tone3}{270A 1F3FD}
\bxce@do{fist_tone4}{270A 1F3FE}
\bxce@do{fist_tone5}{270A 1F3FF}
\bxce@do{five}{35 20E3}
\bxce@do{flag_ac}{1F1E6 1F1E8}
\bxce@do{flag_ad}{1F1E6 1F1E9}
\bxce@do{flag_ae}{1F1E6 1F1EA}
\bxce@do{flag_af}{1F1E6 1F1EB}
\bxce@do{flag_ag}{1F1E6 1F1EC}
\bxce@do{flag_ai}{1F1E6 1F1EE}
\bxce@do{flag_al}{1F1E6 1F1F1}
\bxce@do{flag_am}{1F1E6 1F1F2}
\bxce@do{flag_ao}{1F1E6 1F1F4}
\bxce@do{flag_aq}{1F1E6 1F1F6}
\bxce@do{flag_ar}{1F1E6 1F1F7}
\bxce@do{flag_as}{1F1E6 1F1F8}
\bxce@do{flag_at}{1F1E6 1F1F9}
\bxce@do{flag_au}{1F1E6 1F1FA}
\bxce@do{flag_aw}{1F1E6 1F1FC}
\bxce@do{flag_ax}{1F1E6 1F1FD}
\bxce@do{flag_az}{1F1E6 1F1FF}
\bxce@do{flag_ba}{1F1E7 1F1E6}
\bxce@do{flag_bb}{1F1E7 1F1E7}
\bxce@do{flag_bd}{1F1E7 1F1E9}
\bxce@do{flag_be}{1F1E7 1F1EA}
\bxce@do{flag_bf}{1F1E7 1F1EB}
\bxce@do{flag_bg}{1F1E7 1F1EC}
\bxce@do{flag_bh}{1F1E7 1F1ED}
\bxce@do{flag_bi}{1F1E7 1F1EE}
\bxce@do{flag_bj}{1F1E7 1F1EF}
\bxce@do{flag_bl}{1F1E7 1F1F1}
\bxce@do{flag_black}{1F3F4}
\bxce@do{flag_bm}{1F1E7 1F1F2}
\bxce@do{flag_bn}{1F1E7 1F1F3}
\bxce@do{flag_bo}{1F1E7 1F1F4}
\bxce@do{flag_bq}{1F1E7 1F1F6}
\bxce@do{flag_br}{1F1E7 1F1F7}
\bxce@do{flag_bs}{1F1E7 1F1F8}
\bxce@do{flag_bt}{1F1E7 1F1F9}
\bxce@do{flag_bv}{1F1E7 1F1FB}
\bxce@do{flag_bw}{1F1E7 1F1FC}
\bxce@do{flag_by}{1F1E7 1F1FE}
\bxce@do{flag_bz}{1F1E7 1F1FF}
\bxce@do{flag_ca}{1F1E8 1F1E6}
\bxce@do{flag_cc}{1F1E8 1F1E8}
\bxce@do{flag_cd}{1F1E8 1F1E9}
\bxce@do{flag_cf}{1F1E8 1F1EB}
\bxce@do{flag_cg}{1F1E8 1F1EC}
\bxce@do{flag_ch}{1F1E8 1F1ED}
\bxce@do{flag_ci}{1F1E8 1F1EE}
\bxce@do{flag_ck}{1F1E8 1F1F0}
\bxce@do{flag_cl}{1F1E8 1F1F1}
\bxce@do{flag_cm}{1F1E8 1F1F2}
\bxce@do{flag_cn}{1F1E8 1F1F3}
\bxce@do{flag_co}{1F1E8 1F1F4}
\bxce@do{flag_cp}{1F1E8 1F1F5}
\bxce@do{flag_cr}{1F1E8 1F1F7}
\bxce@do{flag_cu}{1F1E8 1F1FA}
\bxce@do{flag_cv}{1F1E8 1F1FB}
\bxce@do{flag_cw}{1F1E8 1F1FC}
\bxce@do{flag_cx}{1F1E8 1F1FD}
\bxce@do{flag_cy}{1F1E8 1F1FE}
\bxce@do{flag_cz}{1F1E8 1F1FF}
\bxce@do{flag_de}{1F1E9 1F1EA}
\bxce@do{flag_dg}{1F1E9 1F1EC}
\bxce@do{flag_dj}{1F1E9 1F1EF}
\bxce@do{flag_dk}{1F1E9 1F1F0}
\bxce@do{flag_dm}{1F1E9 1F1F2}
\bxce@do{flag_do}{1F1E9 1F1F4}
\bxce@do{flag_dz}{1F1E9 1F1FF}
\bxce@do{flag_ea}{1F1EA 1F1E6}
\bxce@do{flag_ec}{1F1EA 1F1E8}
\bxce@do{flag_ee}{1F1EA 1F1EA}
\bxce@do{flag_eg}{1F1EA 1F1EC}
\bxce@do{flag_eh}{1F1EA 1F1ED}
\bxce@do{flag_er}{1F1EA 1F1F7}
\bxce@do{flag_es}{1F1EA 1F1F8}
\bxce@do{flag_et}{1F1EA 1F1F9}
\bxce@do{flag_eu}{1F1EA 1F1FA}
\bxce@do{flag_fi}{1F1EB 1F1EE}
\bxce@do{flag_fj}{1F1EB 1F1EF}
\bxce@do{flag_fk}{1F1EB 1F1F0}
\bxce@do{flag_fm}{1F1EB 1F1F2}
\bxce@do{flag_fo}{1F1EB 1F1F4}
\bxce@do{flag_fr}{1F1EB 1F1F7}
\bxce@do{flag_ga}{1F1EC 1F1E6}
\bxce@do{flag_gb}{1F1EC 1F1E7}
\bxce@do{flag_gd}{1F1EC 1F1E9}
\bxce@do{flag_ge}{1F1EC 1F1EA}
\bxce@do{flag_gf}{1F1EC 1F1EB}
\bxce@do{flag_gg}{1F1EC 1F1EC}
\bxce@do{flag_gh}{1F1EC 1F1ED}
\bxce@do{flag_gi}{1F1EC 1F1EE}
\bxce@do{flag_gl}{1F1EC 1F1F1}
\bxce@do{flag_gm}{1F1EC 1F1F2}
\bxce@do{flag_gn}{1F1EC 1F1F3}
\bxce@do{flag_gp}{1F1EC 1F1F5}
\bxce@do{flag_gq}{1F1EC 1F1F6}
\bxce@do{flag_gr}{1F1EC 1F1F7}
\bxce@do{flag_gs}{1F1EC 1F1F8}
\bxce@do{flag_gt}{1F1EC 1F1F9}
\bxce@do{flag_gu}{1F1EC 1F1FA}
\bxce@do{flag_gw}{1F1EC 1F1FC}
\bxce@do{flag_gy}{1F1EC 1F1FE}
\bxce@do{flag_hk}{1F1ED 1F1F0}
\bxce@do{flag_hm}{1F1ED 1F1F2}
\bxce@do{flag_hn}{1F1ED 1F1F3}
\bxce@do{flag_hr}{1F1ED 1F1F7}
\bxce@do{flag_ht}{1F1ED 1F1F9}
\bxce@do{flag_hu}{1F1ED 1F1FA}
\bxce@do{flag_ic}{1F1EE 1F1E8}
\bxce@do{flag_id}{1F1EE 1F1E9}
\bxce@do{flag_ie}{1F1EE 1F1EA}
\bxce@do{flag_il}{1F1EE 1F1F1}
\bxce@do{flag_im}{1F1EE 1F1F2}
\bxce@do{flag_in}{1F1EE 1F1F3}
\bxce@do{flag_io}{1F1EE 1F1F4}
\bxce@do{flag_iq}{1F1EE 1F1F6}
\bxce@do{flag_ir}{1F1EE 1F1F7}
\bxce@do{flag_is}{1F1EE 1F1F8}
\bxce@do{flag_it}{1F1EE 1F1F9}
\bxce@do{flag_je}{1F1EF 1F1EA}
\bxce@do{flag_jm}{1F1EF 1F1F2}
\bxce@do{flag_jo}{1F1EF 1F1F4}
\bxce@do{flag_jp}{1F1EF 1F1F5}
\bxce@do{flag_ke}{1F1F0 1F1EA}
\bxce@do{flag_kg}{1F1F0 1F1EC}
\bxce@do{flag_kh}{1F1F0 1F1ED}
\bxce@do{flag_ki}{1F1F0 1F1EE}
\bxce@do{flag_km}{1F1F0 1F1F2}
\bxce@do{flag_kn}{1F1F0 1F1F3}
\bxce@do{flag_kp}{1F1F0 1F1F5}
\bxce@do{flag_kr}{1F1F0 1F1F7}
\bxce@do{flag_kw}{1F1F0 1F1FC}
\bxce@do{flag_ky}{1F1F0 1F1FE}
\bxce@do{flag_kz}{1F1F0 1F1FF}
\bxce@do{flag_la}{1F1F1 1F1E6}
\bxce@do{flag_lb}{1F1F1 1F1E7}
\bxce@do{flag_lc}{1F1F1 1F1E8}
\bxce@do{flag_li}{1F1F1 1F1EE}
\bxce@do{flag_lk}{1F1F1 1F1F0}
\bxce@do{flag_lr}{1F1F1 1F1F7}
\bxce@do{flag_ls}{1F1F1 1F1F8}
\bxce@do{flag_lt}{1F1F1 1F1F9}
\bxce@do{flag_lu}{1F1F1 1F1FA}
\bxce@do{flag_lv}{1F1F1 1F1FB}
\bxce@do{flag_ly}{1F1F1 1F1FE}
\bxce@do{flag_ma}{1F1F2 1F1E6}
\bxce@do{flag_mc}{1F1F2 1F1E8}
\bxce@do{flag_md}{1F1F2 1F1E9}
\bxce@do{flag_me}{1F1F2 1F1EA}
\bxce@do{flag_mf}{1F1F2 1F1EB}
\bxce@do{flag_mg}{1F1F2 1F1EC}
\bxce@do{flag_mh}{1F1F2 1F1ED}
\bxce@do{flag_mk}{1F1F2 1F1F0}
\bxce@do{flag_ml}{1F1F2 1F1F1}
\bxce@do{flag_mm}{1F1F2 1F1F2}
\bxce@do{flag_mn}{1F1F2 1F1F3}
\bxce@do{flag_mo}{1F1F2 1F1F4}
\bxce@do{flag_mp}{1F1F2 1F1F5}
\bxce@do{flag_mq}{1F1F2 1F1F6}
\bxce@do{flag_mr}{1F1F2 1F1F7}
\bxce@do{flag_ms}{1F1F2 1F1F8}
\bxce@do{flag_mt}{1F1F2 1F1F9}
\bxce@do{flag_mu}{1F1F2 1F1FA}
\bxce@do{flag_mv}{1F1F2 1F1FB}
\bxce@do{flag_mw}{1F1F2 1F1FC}
\bxce@do{flag_mx}{1F1F2 1F1FD}
\bxce@do{flag_my}{1F1F2 1F1FE}
\bxce@do{flag_mz}{1F1F2 1F1FF}
\bxce@do{flag_na}{1F1F3 1F1E6}
\bxce@do{flag_nc}{1F1F3 1F1E8}
\bxce@do{flag_ne}{1F1F3 1F1EA}
\bxce@do{flag_nf}{1F1F3 1F1EB}
\bxce@do{flag_ng}{1F1F3 1F1EC}
\bxce@do{flag_ni}{1F1F3 1F1EE}
\bxce@do{flag_nl}{1F1F3 1F1F1}
\bxce@do{flag_no}{1F1F3 1F1F4}
\bxce@do{flag_np}{1F1F3 1F1F5}
\bxce@do{flag_nr}{1F1F3 1F1F7}
\bxce@do{flag_nu}{1F1F3 1F1FA}
\bxce@do{flag_nz}{1F1F3 1F1FF}
\bxce@do{flag_om}{1F1F4 1F1F2}
\bxce@do{flag_pa}{1F1F5 1F1E6}
\bxce@do{flag_pe}{1F1F5 1F1EA}
\bxce@do{flag_pf}{1F1F5 1F1EB}
\bxce@do{flag_pg}{1F1F5 1F1EC}
\bxce@do{flag_ph}{1F1F5 1F1ED}
\bxce@do{flag_pk}{1F1F5 1F1F0}
\bxce@do{flag_pl}{1F1F5 1F1F1}
\bxce@do{flag_pm}{1F1F5 1F1F2}
\bxce@do{flag_pn}{1F1F5 1F1F3}
\bxce@do{flag_pr}{1F1F5 1F1F7}
\bxce@do{flag_ps}{1F1F5 1F1F8}
\bxce@do{flag_pt}{1F1F5 1F1F9}
\bxce@do{flag_pw}{1F1F5 1F1FC}
\bxce@do{flag_py}{1F1F5 1F1FE}
\bxce@do{flag_qa}{1F1F6 1F1E6}
\bxce@do{flag_re}{1F1F7 1F1EA}
\bxce@do{flag_ro}{1F1F7 1F1F4}
\bxce@do{flag_rs}{1F1F7 1F1F8}
\bxce@do{flag_ru}{1F1F7 1F1FA}
\bxce@do{flag_rw}{1F1F7 1F1FC}
\bxce@do{flag_sa}{1F1F8 1F1E6}
\bxce@do{flag_sb}{1F1F8 1F1E7}
\bxce@do{flag_sc}{1F1F8 1F1E8}
\bxce@do{flag_sd}{1F1F8 1F1E9}
\bxce@do{flag_se}{1F1F8 1F1EA}
\bxce@do{flag_sg}{1F1F8 1F1EC}
\bxce@do{flag_sh}{1F1F8 1F1ED}
\bxce@do{flag_si}{1F1F8 1F1EE}
\bxce@do{flag_sj}{1F1F8 1F1EF}
\bxce@do{flag_sk}{1F1F8 1F1F0}
\bxce@do{flag_sl}{1F1F8 1F1F1}
\bxce@do{flag_sm}{1F1F8 1F1F2}
\bxce@do{flag_sn}{1F1F8 1F1F3}
\bxce@do{flag_so}{1F1F8 1F1F4}
\bxce@do{flag_sr}{1F1F8 1F1F7}
\bxce@do{flag_ss}{1F1F8 1F1F8}
\bxce@do{flag_st}{1F1F8 1F1F9}
\bxce@do{flag_sv}{1F1F8 1F1FB}
\bxce@do{flag_sx}{1F1F8 1F1FD}
\bxce@do{flag_sy}{1F1F8 1F1FE}
\bxce@do{flag_sz}{1F1F8 1F1FF}
\bxce@do{flag_ta}{1F1F9 1F1E6}
\bxce@do{flag_tc}{1F1F9 1F1E8}
\bxce@do{flag_td}{1F1F9 1F1E9}
\bxce@do{flag_tf}{1F1F9 1F1EB}
\bxce@do{flag_tg}{1F1F9 1F1EC}
\bxce@do{flag_th}{1F1F9 1F1ED}
\bxce@do{flag_tj}{1F1F9 1F1EF}
\bxce@do{flag_tk}{1F1F9 1F1F0}
\bxce@do{flag_tl}{1F1F9 1F1F1}
\bxce@do{flag_tm}{1F1F9 1F1F2}
\bxce@do{flag_tn}{1F1F9 1F1F3}
\bxce@do{flag_to}{1F1F9 1F1F4}
\bxce@do{flag_tr}{1F1F9 1F1F7}
\bxce@do{flag_tt}{1F1F9 1F1F9}
\bxce@do{flag_tv}{1F1F9 1F1FB}
\bxce@do{flag_tw}{1F1F9 1F1FC}
\bxce@do{flag_tz}{1F1F9 1F1FF}
\bxce@do{flag_ua}{1F1FA 1F1E6}
\bxce@do{flag_ug}{1F1FA 1F1EC}
\bxce@do{flag_um}{1F1FA 1F1F2}
\bxce@do{flag_us}{1F1FA 1F1F8}
\bxce@do{flag_uy}{1F1FA 1F1FE}
\bxce@do{flag_uz}{1F1FA 1F1FF}
\bxce@do{flag_va}{1F1FB 1F1E6}
\bxce@do{flag_vc}{1F1FB 1F1E8}
\bxce@do{flag_ve}{1F1FB 1F1EA}
\bxce@do{flag_vg}{1F1FB 1F1EC}
\bxce@do{flag_vi}{1F1FB 1F1EE}
\bxce@do{flag_vn}{1F1FB 1F1F3}
\bxce@do{flag_vu}{1F1FB 1F1FA}
\bxce@do{flag_wf}{1F1FC 1F1EB}
\bxce@do{flag_white}{1F3F3}
\bxce@do{flag_ws}{1F1FC 1F1F8}
\bxce@do{flag_xk}{1F1FD 1F1F0}
\bxce@do{flag_ye}{1F1FE 1F1EA}
\bxce@do{flag_yt}{1F1FE 1F1F9}
\bxce@do{flag_za}{1F1FF 1F1E6}
\bxce@do{flag_zm}{1F1FF 1F1F2}
\bxce@do{flag_zw}{1F1FF 1F1FC}
\bxce@do{flags}{1F38F}
\bxce@do{flamingo}{1F9A9}
\bxce@do{flashlight}{1F526}
\bxce@do{flatbread}{1FAD3}
\bxce@do{fleur-de-lis}{269C}
\bxce@do{floppy_disk}{1F4BE}
\bxce@do{flower_playing_cards}{1F3B4}
\bxce@do{flushed}{1F633}
\bxce@do{fly}{1FAB0}
\bxce@do{flying_disc}{1F94F}
\bxce@do{flying_saucer}{1F6F8}
\bxce@do{fog}{1F32B}
\bxce@do{foggy}{1F301}
\bxce@do{fondue}{1FAD5}
\bxce@do{foot}{1F9B6}
\bxce@do{foot_tone1}{1F9B6 1F3FB}
\bxce@do{foot_tone2}{1F9B6 1F3FC}
\bxce@do{foot_tone3}{1F9B6 1F3FD}
\bxce@do{foot_tone4}{1F9B6 1F3FE}
\bxce@do{foot_tone5}{1F9B6 1F3FF}
\bxce@do{football}{1F3C8}
\bxce@do{footprints}{1F463}
\bxce@do{fork_and_knife}{1F374}
\bxce@do{fork_knife_plate}{1F37D}
\bxce@do{fortune_cookie}{1F960}
\bxce@do{fountain}{26F2}
\bxce@do{four}{34 20E3}
\bxce@do{four_leaf_clover}{1F340}
\bxce@do{fox}{1F98A}
\bxce@do{frame_photo}{1F5BC}
\bxce@do{free}{1F193}
\bxce@do{french_bread}{1F956}
\bxce@do{fried_shrimp}{1F364}
\bxce@do{fries}{1F35F}
\bxce@do{frog}{1F438}
\bxce@do{frowning}{1F626}
\bxce@do{frowning2}{2639}
\bxce@do{fuelpump}{26FD}
\bxce@do{full_moon}{1F315}
\bxce@do{full_moon_with_face}{1F31D}
\or %[2]
\bxce@do{game_die}{1F3B2}
\bxce@do{garlic}{1F9C4}
\bxce@do{gear}{2699}
\bxce@do{gem}{1F48E}
\bxce@do{gemini}{264A}
\bxce@do{genie}{1F9DE}
\bxce@do{ghost}{1F47B}
\bxce@do{gift}{1F381}
\bxce@do{gift_heart}{1F49D}
\bxce@do{giraffe}{1F992}
\bxce@do{girl}{1F467}
\bxce@do{girl_tone1}{1F467 1F3FB}
\bxce@do{girl_tone2}{1F467 1F3FC}
\bxce@do{girl_tone3}{1F467 1F3FD}
\bxce@do{girl_tone4}{1F467 1F3FE}
\bxce@do{girl_tone5}{1F467 1F3FF}
\bxce@do{globe_with_meridians}{1F310}
\bxce@do{gloves}{1F9E4}
\bxce@do{goal}{1F945}
\bxce@do{goat}{1F410}
\bxce@do{goggles}{1F97D}
\bxce@do{golf}{26F3}
\bxce@do{gorilla}{1F98D}
\bxce@do{grapes}{1F347}
\bxce@do{green_apple}{1F34F}
\bxce@do{green_book}{1F4D7}
\bxce@do{green_circle}{1F7E2}
\bxce@do{green_heart}{1F49A}
\bxce@do{green_square}{1F7E9}
\bxce@do{grey_exclamation}{2755}
\bxce@do{grey_question}{2754}
\bxce@do{grimacing}{1F62C}
\bxce@do{grin}{1F601}
\bxce@do{grinning}{1F600}
\bxce@do{guard}{1F482}
\bxce@do{guard_tone1}{1F482 1F3FB}
\bxce@do{guard_tone2}{1F482 1F3FC}
\bxce@do{guard_tone3}{1F482 1F3FD}
\bxce@do{guard_tone4}{1F482 1F3FE}
\bxce@do{guard_tone5}{1F482 1F3FF}
\bxce@do{guide_dog}{1F9AE}
\bxce@do{guitar}{1F3B8}
\bxce@do{gun}{1F52B}
\bxce@do{hamburger}{1F354}
\bxce@do{hammer}{1F528}
\bxce@do{hammer_pick}{2692}
\bxce@do{hamster}{1F439}
\bxce@do{hand_splayed}{1F590}
\bxce@do{hand_splayed_tone1}{1F590 1F3FB}
\bxce@do{hand_splayed_tone2}{1F590 1F3FC}
\bxce@do{hand_splayed_tone3}{1F590 1F3FD}
\bxce@do{hand_splayed_tone4}{1F590 1F3FE}
\bxce@do{hand_splayed_tone5}{1F590 1F3FF}
\bxce@do{handbag}{1F45C}
\bxce@do{handshake}{1F91D}
\bxce@do{hash}{23 20E3}
\bxce@do{hatched_chick}{1F425}
\bxce@do{hatching_chick}{1F423}
\bxce@do{head_bandage}{1F915}
\bxce@do{headphones}{1F3A7}
\bxce@do{headstone}{1FAA6}
\bxce@do{health_worker}{1F9D1 200D 2695}
\bxce@do{health_worker_tone1}{1F9D1 1F3FB 200D 2695}
\bxce@do{health_worker_tone2}{1F9D1 1F3FC 200D 2695}
\bxce@do{health_worker_tone3}{1F9D1 1F3FD 200D 2695}
\bxce@do{health_worker_tone4}{1F9D1 1F3FE 200D 2695}
\bxce@do{health_worker_tone5}{1F9D1 1F3FF 200D 2695}
\bxce@do{hear_no_evil}{1F649}
\bxce@do{heart}{2764}
\bxce@do{heart_decoration}{1F49F}
\bxce@do{heart_exclamation}{2763}
\bxce@do{heart_eyes}{1F60D}
\bxce@do{heart_eyes_cat}{1F63B}
\bxce@do{heart_on_fire}{2764 200D 1F525}
\bxce@do{heartbeat}{1F493}
\bxce@do{heartpulse}{1F497}
\bxce@do{hearts}{2665}
\bxce@do{heavy_check_mark}{2714}
\bxce@do{heavy_division_sign}{2797}
\bxce@do{heavy_dollar_sign}{1F4B2}
\bxce@do{heavy_minus_sign}{2796}
\bxce@do{heavy_multiplication_x}{2716}
\bxce@do{heavy_plus_sign}{2795}
\bxce@do{hedgehog}{1F994}
\bxce@do{helicopter}{1F681}
\bxce@do{helmet_with_cross}{26D1}
\bxce@do{herb}{1F33F}
\bxce@do{hibiscus}{1F33A}
\bxce@do{high_brightness}{1F506}
\bxce@do{high_heel}{1F460}
\bxce@do{hiking_boot}{1F97E}
\bxce@do{hindu_temple}{1F6D5}
\bxce@do{hippopotamus}{1F99B}
\bxce@do{hockey}{1F3D2}
\bxce@do{hole}{1F573}
\bxce@do{homes}{1F3D8}
\bxce@do{honey_pot}{1F36F}
\bxce@do{hook}{1FA9D}
\bxce@do{horse}{1F434}
\bxce@do{horse_racing}{1F3C7}
\bxce@do{horse_racing_tone1}{1F3C7 1F3FB}
\bxce@do{horse_racing_tone2}{1F3C7 1F3FC}
\bxce@do{horse_racing_tone3}{1F3C7 1F3FD}
\bxce@do{horse_racing_tone4}{1F3C7 1F3FE}
\bxce@do{horse_racing_tone5}{1F3C7 1F3FF}
\bxce@do{hospital}{1F3E5}
\bxce@do{hot_face}{1F975}
\bxce@do{hot_pepper}{1F336}
\bxce@do{hotdog}{1F32D}
\bxce@do{hotel}{1F3E8}
\bxce@do{hotsprings}{2668}
\bxce@do{hourglass}{231B}
\bxce@do{hourglass_flowing_sand}{23F3}
\bxce@do{house}{1F3E0}
\bxce@do{house_abandoned}{1F3DA}
\bxce@do{house_with_garden}{1F3E1}
\bxce@do{hugging}{1F917}
\bxce@do{hushed}{1F62F}
\bxce@do{hut}{1F6D6}
\bxce@do{ice_cream}{1F368}
\bxce@do{ice_cube}{1F9CA}
\bxce@do{ice_skate}{26F8}
\bxce@do{icecream}{1F366}
\bxce@do{id}{1F194}
\bxce@do{ideograph_advantage}{1F250}
\bxce@do{imp}{1F47F}
\bxce@do{inbox_tray}{1F4E5}
\bxce@do{incoming_envelope}{1F4E8}
\bxce@do{infinity}{267E}
\bxce@do{information_source}{2139}
\bxce@do{innocent}{1F607}
\bxce@do{interrobang}{2049}
\bxce@do{island}{1F3DD}
\bxce@do{izakaya_lantern}{1F3EE}
\bxce@do{jack_o_lantern}{1F383}
\bxce@do{japan}{1F5FE}
\bxce@do{japanese_castle}{1F3EF}
\bxce@do{japanese_goblin}{1F47A}
\bxce@do{japanese_ogre}{1F479}
\bxce@do{jeans}{1F456}
\bxce@do{jigsaw}{1F9E9}
\bxce@do{joy}{1F602}
\bxce@do{joy_cat}{1F639}
\bxce@do{joystick}{1F579}
\bxce@do{judge}{1F9D1 200D 2696}
\bxce@do{judge_tone1}{1F9D1 1F3FB 200D 2696}
\bxce@do{judge_tone2}{1F9D1 1F3FC 200D 2696}
\bxce@do{judge_tone3}{1F9D1 1F3FD 200D 2696}
\bxce@do{judge_tone4}{1F9D1 1F3FE 200D 2696}
\bxce@do{judge_tone5}{1F9D1 1F3FF 200D 2696}
\bxce@do{kaaba}{1F54B}
\bxce@do{kangaroo}{1F998}
\bxce@do{key}{1F511}
\bxce@do{key2}{1F5DD}
\bxce@do{keyboard}{2328}
\bxce@do{keycap_ten}{1F51F}
\bxce@do{kimono}{1F458}
\bxce@do{kiss}{1F48B}
\bxce@do{kiss_man_man}{1F468 200D 2764 200D 1F48B 200D 1F468}
\bxce@do{kiss_man_man_tone1}{1F468 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_man_man_tone1_tone2}{1F468 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_man_man_tone1_tone3}{1F468 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_man_man_tone1_tone4}{1F468 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_man_man_tone1_tone5}{1F468 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_man_man_tone2}{1F468 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_man_man_tone2_tone1}{1F468 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_man_man_tone2_tone3}{1F468 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_man_man_tone2_tone4}{1F468 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_man_man_tone2_tone5}{1F468 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_man_man_tone3}{1F468 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_man_man_tone3_tone1}{1F468 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_man_man_tone3_tone2}{1F468 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_man_man_tone3_tone4}{1F468 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_man_man_tone3_tone5}{1F468 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_man_man_tone4}{1F468 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_man_man_tone4_tone1}{1F468 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_man_man_tone4_tone2}{1F468 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_man_man_tone4_tone3}{1F468 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_man_man_tone4_tone5}{1F468 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_man_man_tone5}{1F468 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_man_man_tone5_tone1}{1F468 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_man_man_tone5_tone2}{1F468 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_man_man_tone5_tone3}{1F468 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_man_man_tone5_tone4}{1F468 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_mm}{1F468 200D 2764 200D 1F48B 200D 1F468}
\bxce@do{kiss_person_person}{1F48F}
\bxce@do{kiss_person_person_tone1}{1F48F 1F3FB}
\bxce@do{kiss_person_person_tone1_tone2}{1F9D1 1F3FB 200D 2764 200D 1F48B 200D 1F9D1 1F3FC}
\bxce@do{kiss_person_person_tone1_tone3}{1F9D1 1F3FB 200D 2764 200D 1F48B 200D 1F9D1 1F3FD}
\bxce@do{kiss_person_person_tone1_tone4}{1F9D1 1F3FB 200D 2764 200D 1F48B 200D 1F9D1 1F3FE}
\bxce@do{kiss_person_person_tone1_tone5}{1F9D1 1F3FB 200D 2764 200D 1F48B 200D 1F9D1 1F3FF}
\bxce@do{kiss_person_person_tone2}{1F48F 1F3FC}
\bxce@do{kiss_person_person_tone2_tone1}{1F9D1 1F3FC 200D 2764 200D 1F48B 200D 1F9D1 1F3FB}
\bxce@do{kiss_person_person_tone2_tone3}{1F9D1 1F3FC 200D 2764 200D 1F48B 200D 1F9D1 1F3FD}
\bxce@do{kiss_person_person_tone2_tone4}{1F9D1 1F3FC 200D 2764 200D 1F48B 200D 1F9D1 1F3FE}
\bxce@do{kiss_person_person_tone2_tone5}{1F9D1 1F3FC 200D 2764 200D 1F48B 200D 1F9D1 1F3FF}
\bxce@do{kiss_person_person_tone3}{1F48F 1F3FD}
\bxce@do{kiss_person_person_tone3_tone1}{1F9D1 1F3FD 200D 2764 200D 1F48B 200D 1F9D1 1F3FB}
\bxce@do{kiss_person_person_tone3_tone2}{1F9D1 1F3FD 200D 2764 200D 1F48B 200D 1F9D1 1F3FC}
\bxce@do{kiss_person_person_tone3_tone4}{1F9D1 1F3FD 200D 2764 200D 1F48B 200D 1F9D1 1F3FE}
\bxce@do{kiss_person_person_tone3_tone5}{1F9D1 1F3FD 200D 2764 200D 1F48B 200D 1F9D1 1F3FF}
\bxce@do{kiss_person_person_tone4}{1F48F 1F3FE}
\bxce@do{kiss_person_person_tone4_tone1}{1F9D1 1F3FE 200D 2764 200D 1F48B 200D 1F9D1 1F3FB}
\bxce@do{kiss_person_person_tone4_tone2}{1F9D1 1F3FE 200D 2764 200D 1F48B 200D 1F9D1 1F3FC}
\bxce@do{kiss_person_person_tone4_tone3}{1F9D1 1F3FE 200D 2764 200D 1F48B 200D 1F9D1 1F3FD}
\bxce@do{kiss_person_person_tone4_tone5}{1F9D1 1F3FE 200D 2764 200D 1F48B 200D 1F9D1 1F3FF}
\bxce@do{kiss_person_person_tone5}{1F48F 1F3FF}
\bxce@do{kiss_person_person_tone5_tone1}{1F9D1 1F3FF 200D 2764 200D 1F48B 200D 1F9D1 1F3FB}
\bxce@do{kiss_person_person_tone5_tone2}{1F9D1 1F3FF 200D 2764 200D 1F48B 200D 1F9D1 1F3FC}
\bxce@do{kiss_person_person_tone5_tone3}{1F9D1 1F3FF 200D 2764 200D 1F48B 200D 1F9D1 1F3FD}
\bxce@do{kiss_person_person_tone5_tone4}{1F9D1 1F3FF 200D 2764 200D 1F48B 200D 1F9D1 1F3FE}
\bxce@do{kiss_tone1}{1F48F 1F3FB}
\bxce@do{kiss_tone2}{1F48F 1F3FC}
\bxce@do{kiss_tone3}{1F48F 1F3FD}
\bxce@do{kiss_tone4}{1F48F 1F3FE}
\bxce@do{kiss_tone5}{1F48F 1F3FF}
\bxce@do{kiss_woman_man}{1F469 200D 2764 200D 1F48B 200D 1F468}
\bxce@do{kiss_woman_man_tone1}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_woman_man_tone1_tone2}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_woman_man_tone1_tone3}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_woman_man_tone1_tone4}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_woman_man_tone1_tone5}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_woman_man_tone2}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_woman_man_tone2_tone1}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_woman_man_tone2_tone3}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_woman_man_tone2_tone4}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_woman_man_tone2_tone5}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_woman_man_tone3}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_woman_man_tone3_tone1}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_woman_man_tone3_tone2}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_woman_man_tone3_tone4}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_woman_man_tone3_tone5}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_woman_man_tone4}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_woman_man_tone4_tone1}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_woman_man_tone4_tone2}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_woman_man_tone4_tone3}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_woman_man_tone4_tone5}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_woman_man_tone5}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FF}
\bxce@do{kiss_woman_man_tone5_tone1}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FB}
\bxce@do{kiss_woman_man_tone5_tone2}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FC}
\bxce@do{kiss_woman_man_tone5_tone3}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FD}
\bxce@do{kiss_woman_man_tone5_tone4}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F468 1F3FE}
\bxce@do{kiss_woman_woman}{1F469 200D 2764 200D 1F48B 200D 1F469}
\bxce@do{kiss_woman_woman_tone1}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F469 1F3FB}
\bxce@do{kiss_woman_woman_tone1_tone2}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F469 1F3FC}
\bxce@do{kiss_woman_woman_tone1_tone3}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F469 1F3FD}
\bxce@do{kiss_woman_woman_tone1_tone4}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F469 1F3FE}
\bxce@do{kiss_woman_woman_tone1_tone5}{1F469 1F3FB 200D 2764 200D 1F48B 200D 1F469 1F3FF}
\bxce@do{kiss_woman_woman_tone2}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F469 1F3FC}
\bxce@do{kiss_woman_woman_tone2_tone1}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F469 1F3FB}
\bxce@do{kiss_woman_woman_tone2_tone3}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F469 1F3FD}
\bxce@do{kiss_woman_woman_tone2_tone4}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F469 1F3FE}
\bxce@do{kiss_woman_woman_tone2_tone5}{1F469 1F3FC 200D 2764 200D 1F48B 200D 1F469 1F3FF}
\bxce@do{kiss_woman_woman_tone3}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F469 1F3FD}
\bxce@do{kiss_woman_woman_tone3_tone1}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F469 1F3FB}
\bxce@do{kiss_woman_woman_tone3_tone2}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F469 1F3FC}
\bxce@do{kiss_woman_woman_tone3_tone4}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F469 1F3FE}
\bxce@do{kiss_woman_woman_tone3_tone5}{1F469 1F3FD 200D 2764 200D 1F48B 200D 1F469 1F3FF}
\bxce@do{kiss_woman_woman_tone4}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F469 1F3FE}
\bxce@do{kiss_woman_woman_tone4_tone1}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F469 1F3FB}
\bxce@do{kiss_woman_woman_tone4_tone2}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F469 1F3FC}
\bxce@do{kiss_woman_woman_tone4_tone3}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F469 1F3FD}
\bxce@do{kiss_woman_woman_tone4_tone5}{1F469 1F3FE 200D 2764 200D 1F48B 200D 1F469 1F3FF}
\bxce@do{kiss_woman_woman_tone5}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F469 1F3FF}
\bxce@do{kiss_woman_woman_tone5_tone1}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F469 1F3FB}
\bxce@do{kiss_woman_woman_tone5_tone2}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F469 1F3FC}
\bxce@do{kiss_woman_woman_tone5_tone3}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F469 1F3FD}
\bxce@do{kiss_woman_woman_tone5_tone4}{1F469 1F3FF 200D 2764 200D 1F48B 200D 1F469 1F3FE}
\bxce@do{kiss_ww}{1F469 200D 2764 200D 1F48B 200D 1F469}
\bxce@do{kissing}{1F617}
\bxce@do{kissing_cat}{1F63D}
\bxce@do{kissing_closed_eyes}{1F61A}
\bxce@do{kissing_heart}{1F618}
\bxce@do{kissing_smiling_eyes}{1F619}
\bxce@do{kite}{1FA81}
\bxce@do{kiwi}{1F95D}
\bxce@do{knife}{1F52A}
\bxce@do{knot}{1FAA2}
\bxce@do{koala}{1F428}
\bxce@do{koko}{1F201}
\bxce@do{lab_coat}{1F97C}
\bxce@do{label}{1F3F7}
\bxce@do{lacrosse}{1F94D}
\bxce@do{ladder}{1FA9C}
\bxce@do{lady_beetle}{1F41E}
\bxce@do{large_blue_diamond}{1F537}
\bxce@do{large_orange_diamond}{1F536}
\bxce@do{last_quarter_moon}{1F317}
\bxce@do{last_quarter_moon_with_face}{1F31C}
\bxce@do{laughing}{1F606}
\bxce@do{leafy_green}{1F96C}
\bxce@do{leaves}{1F343}
\bxce@do{ledger}{1F4D2}
\bxce@do{left_facing_fist}{1F91B}
\bxce@do{left_facing_fist_tone1}{1F91B 1F3FB}
\bxce@do{left_facing_fist_tone2}{1F91B 1F3FC}
\bxce@do{left_facing_fist_tone3}{1F91B 1F3FD}
\bxce@do{left_facing_fist_tone4}{1F91B 1F3FE}
\bxce@do{left_facing_fist_tone5}{1F91B 1F3FF}
\bxce@do{left_luggage}{1F6C5}
\bxce@do{left_right_arrow}{2194}
\bxce@do{leftwards_arrow_with_hook}{21A9}
\bxce@do{leg}{1F9B5}
\bxce@do{leg_tone1}{1F9B5 1F3FB}
\bxce@do{leg_tone2}{1F9B5 1F3FC}
\bxce@do{leg_tone3}{1F9B5 1F3FD}
\bxce@do{leg_tone4}{1F9B5 1F3FE}
\bxce@do{leg_tone5}{1F9B5 1F3FF}
\bxce@do{lemon}{1F34B}
\bxce@do{leo}{264C}
\bxce@do{leopard}{1F406}
\bxce@do{level_slider}{1F39A}
\bxce@do{levitate}{1F574}
\bxce@do{levitate_tone1}{1F574 1F3FB}
\bxce@do{levitate_tone2}{1F574 1F3FC}
\bxce@do{levitate_tone3}{1F574 1F3FD}
\bxce@do{levitate_tone4}{1F574 1F3FE}
\bxce@do{levitate_tone5}{1F574 1F3FF}
\bxce@do{libra}{264E}
\bxce@do{light_rail}{1F688}
\bxce@do{link}{1F517}
\bxce@do{lion_face}{1F981}
\bxce@do{lips}{1F444}
\bxce@do{lipstick}{1F484}
\bxce@do{lizard}{1F98E}
\bxce@do{llama}{1F999}
\bxce@do{lobster}{1F99E}
\bxce@do{lock}{1F512}
\bxce@do{lock_with_ink_pen}{1F50F}
\bxce@do{lollipop}{1F36D}
\bxce@do{long_drum}{1FA98}
\bxce@do{loop}{27BF}
\bxce@do{loud_sound}{1F50A}
\bxce@do{loudspeaker}{1F4E2}
\bxce@do{love_hotel}{1F3E9}
\bxce@do{love_letter}{1F48C}
\bxce@do{love_you_gesture}{1F91F}
\bxce@do{love_you_gesture_tone1}{1F91F 1F3FB}
\bxce@do{love_you_gesture_tone2}{1F91F 1F3FC}
\bxce@do{love_you_gesture_tone3}{1F91F 1F3FD}
\bxce@do{love_you_gesture_tone4}{1F91F 1F3FE}
\bxce@do{love_you_gesture_tone5}{1F91F 1F3FF}
\bxce@do{low_brightness}{1F505}
\bxce@do{luggage}{1F9F3}
\bxce@do{lungs}{1FAC1}
\bxce@do{lying_face}{1F925}
\or %[3]
\bxce@do{m}{24C2}
\bxce@do{mag}{1F50D}
\bxce@do{mag_right}{1F50E}
\bxce@do{mage}{1F9D9}
\bxce@do{mage_tone1}{1F9D9 1F3FB}
\bxce@do{mage_tone2}{1F9D9 1F3FC}
\bxce@do{mage_tone3}{1F9D9 1F3FD}
\bxce@do{mage_tone4}{1F9D9 1F3FE}
\bxce@do{mage_tone5}{1F9D9 1F3FF}
\bxce@do{magic_wand}{1FA84}
\bxce@do{magnet}{1F9F2}
\bxce@do{mahjong}{1F004}
\bxce@do{mailbox}{1F4EB}
\bxce@do{mailbox_closed}{1F4EA}
\bxce@do{mailbox_with_mail}{1F4EC}
\bxce@do{mailbox_with_no_mail}{1F4ED}
\bxce@do{male_sign}{2642}
\bxce@do{mammoth}{1F9A3}
\bxce@do{man}{1F468}
\bxce@do{man_artist}{1F468 200D 1F3A8}
\bxce@do{man_artist_tone1}{1F468 1F3FB 200D 1F3A8}
\bxce@do{man_artist_tone2}{1F468 1F3FC 200D 1F3A8}
\bxce@do{man_artist_tone3}{1F468 1F3FD 200D 1F3A8}
\bxce@do{man_artist_tone4}{1F468 1F3FE 200D 1F3A8}
\bxce@do{man_artist_tone5}{1F468 1F3FF 200D 1F3A8}
\bxce@do{man_astronaut}{1F468 200D 1F680}
\bxce@do{man_astronaut_tone1}{1F468 1F3FB 200D 1F680}
\bxce@do{man_astronaut_tone2}{1F468 1F3FC 200D 1F680}
\bxce@do{man_astronaut_tone3}{1F468 1F3FD 200D 1F680}
\bxce@do{man_astronaut_tone4}{1F468 1F3FE 200D 1F680}
\bxce@do{man_astronaut_tone5}{1F468 1F3FF 200D 1F680}
\bxce@do{man_bald}{1F468 200D 1F9B2}
\bxce@do{man_bald_tone1}{1F468 1F3FB 200D 1F9B2}
\bxce@do{man_bald_tone2}{1F468 1F3FC 200D 1F9B2}
\bxce@do{man_bald_tone3}{1F468 1F3FD 200D 1F9B2}
\bxce@do{man_bald_tone4}{1F468 1F3FE 200D 1F9B2}
\bxce@do{man_bald_tone5}{1F468 1F3FF 200D 1F9B2}
\bxce@do{man_beard}{1F9D4 200D 2642}
\bxce@do{man_biking}{1F6B4 200D 2642}
\bxce@do{man_biking_tone1}{1F6B4 1F3FB 200D 2642}
\bxce@do{man_biking_tone2}{1F6B4 1F3FC 200D 2642}
\bxce@do{man_biking_tone3}{1F6B4 1F3FD 200D 2642}
\bxce@do{man_biking_tone4}{1F6B4 1F3FE 200D 2642}
\bxce@do{man_biking_tone5}{1F6B4 1F3FF 200D 2642}
\bxce@do{man_bouncing_ball}{26F9 200D 2642}
\bxce@do{man_bouncing_ball_tone1}{26F9 1F3FB 200D 2642}
\bxce@do{man_bouncing_ball_tone2}{26F9 1F3FC 200D 2642}
\bxce@do{man_bouncing_ball_tone3}{26F9 1F3FD 200D 2642}
\bxce@do{man_bouncing_ball_tone4}{26F9 1F3FE 200D 2642}
\bxce@do{man_bouncing_ball_tone5}{26F9 1F3FF 200D 2642}
\bxce@do{man_bowing}{1F647 200D 2642}
\bxce@do{man_bowing_tone1}{1F647 1F3FB 200D 2642}
\bxce@do{man_bowing_tone2}{1F647 1F3FC 200D 2642}
\bxce@do{man_bowing_tone3}{1F647 1F3FD 200D 2642}
\bxce@do{man_bowing_tone4}{1F647 1F3FE 200D 2642}
\bxce@do{man_bowing_tone5}{1F647 1F3FF 200D 2642}
\bxce@do{man_cartwheeling}{1F938 200D 2642}
\bxce@do{man_cartwheeling_tone1}{1F938 1F3FB 200D 2642}
\bxce@do{man_cartwheeling_tone2}{1F938 1F3FC 200D 2642}
\bxce@do{man_cartwheeling_tone3}{1F938 1F3FD 200D 2642}
\bxce@do{man_cartwheeling_tone4}{1F938 1F3FE 200D 2642}
\bxce@do{man_cartwheeling_tone5}{1F938 1F3FF 200D 2642}
\bxce@do{man_climbing}{1F9D7 200D 2642}
\bxce@do{man_climbing_tone1}{1F9D7 1F3FB 200D 2642}
\bxce@do{man_climbing_tone2}{1F9D7 1F3FC 200D 2642}
\bxce@do{man_climbing_tone3}{1F9D7 1F3FD 200D 2642}
\bxce@do{man_climbing_tone4}{1F9D7 1F3FE 200D 2642}
\bxce@do{man_climbing_tone5}{1F9D7 1F3FF 200D 2642}
\bxce@do{man_construction_worker}{1F477 200D 2642}
\bxce@do{man_construction_worker_tone1}{1F477 1F3FB 200D 2642}
\bxce@do{man_construction_worker_tone2}{1F477 1F3FC 200D 2642}
\bxce@do{man_construction_worker_tone3}{1F477 1F3FD 200D 2642}
\bxce@do{man_construction_worker_tone4}{1F477 1F3FE 200D 2642}
\bxce@do{man_construction_worker_tone5}{1F477 1F3FF 200D 2642}
\bxce@do{man_cook}{1F468 200D 1F373}
\bxce@do{man_cook_tone1}{1F468 1F3FB 200D 1F373}
\bxce@do{man_cook_tone2}{1F468 1F3FC 200D 1F373}
\bxce@do{man_cook_tone3}{1F468 1F3FD 200D 1F373}
\bxce@do{man_cook_tone4}{1F468 1F3FE 200D 1F373}
\bxce@do{man_cook_tone5}{1F468 1F3FF 200D 1F373}
\bxce@do{man_curly_haired}{1F468 200D 1F9B1}
\bxce@do{man_curly_haired_tone1}{1F468 1F3FB 200D 1F9B1}
\bxce@do{man_curly_haired_tone2}{1F468 1F3FC 200D 1F9B1}
\bxce@do{man_curly_haired_tone3}{1F468 1F3FD 200D 1F9B1}
\bxce@do{man_curly_haired_tone4}{1F468 1F3FE 200D 1F9B1}
\bxce@do{man_curly_haired_tone5}{1F468 1F3FF 200D 1F9B1}
\bxce@do{man_dancing}{1F57A}
\bxce@do{man_dancing_tone1}{1F57A 1F3FB}
\bxce@do{man_dancing_tone2}{1F57A 1F3FC}
\bxce@do{man_dancing_tone3}{1F57A 1F3FD}
\bxce@do{man_dancing_tone4}{1F57A 1F3FE}
\bxce@do{man_dancing_tone5}{1F57A 1F3FF}
\bxce@do{man_detective}{1F575 200D 2642}
\bxce@do{man_detective_tone1}{1F575 1F3FB 200D 2642}
\bxce@do{man_detective_tone2}{1F575 1F3FC 200D 2642}
\bxce@do{man_detective_tone3}{1F575 1F3FD 200D 2642}
\bxce@do{man_detective_tone4}{1F575 1F3FE 200D 2642}
\bxce@do{man_detective_tone5}{1F575 1F3FF 200D 2642}
\bxce@do{man_elf}{1F9DD 200D 2642}
\bxce@do{man_elf_tone1}{1F9DD 1F3FB 200D 2642}
\bxce@do{man_elf_tone2}{1F9DD 1F3FC 200D 2642}
\bxce@do{man_elf_tone3}{1F9DD 1F3FD 200D 2642}
\bxce@do{man_elf_tone4}{1F9DD 1F3FE 200D 2642}
\bxce@do{man_elf_tone5}{1F9DD 1F3FF 200D 2642}
\bxce@do{man_facepalming}{1F926 200D 2642}
\bxce@do{man_facepalming_tone1}{1F926 1F3FB 200D 2642}
\bxce@do{man_facepalming_tone2}{1F926 1F3FC 200D 2642}
\bxce@do{man_facepalming_tone3}{1F926 1F3FD 200D 2642}
\bxce@do{man_facepalming_tone4}{1F926 1F3FE 200D 2642}
\bxce@do{man_facepalming_tone5}{1F926 1F3FF 200D 2642}
\bxce@do{man_factory_worker}{1F468 200D 1F3ED}
\bxce@do{man_factory_worker_tone1}{1F468 1F3FB 200D 1F3ED}
\bxce@do{man_factory_worker_tone2}{1F468 1F3FC 200D 1F3ED}
\bxce@do{man_factory_worker_tone3}{1F468 1F3FD 200D 1F3ED}
\bxce@do{man_factory_worker_tone4}{1F468 1F3FE 200D 1F3ED}
\bxce@do{man_factory_worker_tone5}{1F468 1F3FF 200D 1F3ED}
\bxce@do{man_fairy}{1F9DA 200D 2642}
\bxce@do{man_fairy_tone1}{1F9DA 1F3FB 200D 2642}
\bxce@do{man_fairy_tone2}{1F9DA 1F3FC 200D 2642}
\bxce@do{man_fairy_tone3}{1F9DA 1F3FD 200D 2642}
\bxce@do{man_fairy_tone4}{1F9DA 1F3FE 200D 2642}
\bxce@do{man_fairy_tone5}{1F9DA 1F3FF 200D 2642}
\bxce@do{man_farmer}{1F468 200D 1F33E}
\bxce@do{man_farmer_tone1}{1F468 1F3FB 200D 1F33E}
\bxce@do{man_farmer_tone2}{1F468 1F3FC 200D 1F33E}
\bxce@do{man_farmer_tone3}{1F468 1F3FD 200D 1F33E}
\bxce@do{man_farmer_tone4}{1F468 1F3FE 200D 1F33E}
\bxce@do{man_farmer_tone5}{1F468 1F3FF 200D 1F33E}
\bxce@do{man_feeding_baby}{1F468 200D 1F37C}
\bxce@do{man_feeding_baby_tone1}{1F468 1F3FB 200D 1F37C}
\bxce@do{man_feeding_baby_tone2}{1F468 1F3FC 200D 1F37C}
\bxce@do{man_feeding_baby_tone3}{1F468 1F3FD 200D 1F37C}
\bxce@do{man_feeding_baby_tone4}{1F468 1F3FE 200D 1F37C}
\bxce@do{man_feeding_baby_tone5}{1F468 1F3FF 200D 1F37C}
\bxce@do{man_firefighter}{1F468 200D 1F692}
\bxce@do{man_firefighter_tone1}{1F468 1F3FB 200D 1F692}
\bxce@do{man_firefighter_tone2}{1F468 1F3FC 200D 1F692}
\bxce@do{man_firefighter_tone3}{1F468 1F3FD 200D 1F692}
\bxce@do{man_firefighter_tone4}{1F468 1F3FE 200D 1F692}
\bxce@do{man_firefighter_tone5}{1F468 1F3FF 200D 1F692}
\bxce@do{man_frowning}{1F64D 200D 2642}
\bxce@do{man_frowning_tone1}{1F64D 1F3FB 200D 2642}
\bxce@do{man_frowning_tone2}{1F64D 1F3FC 200D 2642}
\bxce@do{man_frowning_tone3}{1F64D 1F3FD 200D 2642}
\bxce@do{man_frowning_tone4}{1F64D 1F3FE 200D 2642}
\bxce@do{man_frowning_tone5}{1F64D 1F3FF 200D 2642}
\bxce@do{man_genie}{1F9DE 200D 2642}
\bxce@do{man_gesturing_no}{1F645 200D 2642}
\bxce@do{man_gesturing_no_tone1}{1F645 1F3FB 200D 2642}
\bxce@do{man_gesturing_no_tone2}{1F645 1F3FC 200D 2642}
\bxce@do{man_gesturing_no_tone3}{1F645 1F3FD 200D 2642}
\bxce@do{man_gesturing_no_tone4}{1F645 1F3FE 200D 2642}
\bxce@do{man_gesturing_no_tone5}{1F645 1F3FF 200D 2642}
\bxce@do{man_gesturing_ok}{1F646 200D 2642}
\bxce@do{man_gesturing_ok_tone1}{1F646 1F3FB 200D 2642}
\bxce@do{man_gesturing_ok_tone2}{1F646 1F3FC 200D 2642}
\bxce@do{man_gesturing_ok_tone3}{1F646 1F3FD 200D 2642}
\bxce@do{man_gesturing_ok_tone4}{1F646 1F3FE 200D 2642}
\bxce@do{man_gesturing_ok_tone5}{1F646 1F3FF 200D 2642}
\bxce@do{man_getting_face_massage}{1F486 200D 2642}
\bxce@do{man_getting_face_massage_tone1}{1F486 1F3FB 200D 2642}
\bxce@do{man_getting_face_massage_tone2}{1F486 1F3FC 200D 2642}
\bxce@do{man_getting_face_massage_tone3}{1F486 1F3FD 200D 2642}
\bxce@do{man_getting_face_massage_tone4}{1F486 1F3FE 200D 2642}
\bxce@do{man_getting_face_massage_tone5}{1F486 1F3FF 200D 2642}
\bxce@do{man_getting_haircut}{1F487 200D 2642}
\bxce@do{man_getting_haircut_tone1}{1F487 1F3FB 200D 2642}
\bxce@do{man_getting_haircut_tone2}{1F487 1F3FC 200D 2642}
\bxce@do{man_getting_haircut_tone3}{1F487 1F3FD 200D 2642}
\bxce@do{man_getting_haircut_tone4}{1F487 1F3FE 200D 2642}
\bxce@do{man_getting_haircut_tone5}{1F487 1F3FF 200D 2642}
\bxce@do{man_golfing}{1F3CC 200D 2642}
\bxce@do{man_golfing_tone1}{1F3CC 1F3FB 200D 2642}
\bxce@do{man_golfing_tone2}{1F3CC 1F3FC 200D 2642}
\bxce@do{man_golfing_tone3}{1F3CC 1F3FD 200D 2642}
\bxce@do{man_golfing_tone4}{1F3CC 1F3FE 200D 2642}
\bxce@do{man_golfing_tone5}{1F3CC 1F3FF 200D 2642}
\bxce@do{man_guard}{1F482 200D 2642}
\bxce@do{man_guard_tone1}{1F482 1F3FB 200D 2642}
\bxce@do{man_guard_tone2}{1F482 1F3FC 200D 2642}
\bxce@do{man_guard_tone3}{1F482 1F3FD 200D 2642}
\bxce@do{man_guard_tone4}{1F482 1F3FE 200D 2642}
\bxce@do{man_guard_tone5}{1F482 1F3FF 200D 2642}
\bxce@do{man_health_worker}{1F468 200D 2695}
\bxce@do{man_health_worker_tone1}{1F468 1F3FB 200D 2695}
\bxce@do{man_health_worker_tone2}{1F468 1F3FC 200D 2695}
\bxce@do{man_health_worker_tone3}{1F468 1F3FD 200D 2695}
\bxce@do{man_health_worker_tone4}{1F468 1F3FE 200D 2695}
\bxce@do{man_health_worker_tone5}{1F468 1F3FF 200D 2695}
\bxce@do{man_in_lotus_position}{1F9D8 200D 2642}
\bxce@do{man_in_lotus_position_tone1}{1F9D8 1F3FB 200D 2642}
\bxce@do{man_in_lotus_position_tone2}{1F9D8 1F3FC 200D 2642}
\bxce@do{man_in_lotus_position_tone3}{1F9D8 1F3FD 200D 2642}
\bxce@do{man_in_lotus_position_tone4}{1F9D8 1F3FE 200D 2642}
\bxce@do{man_in_lotus_position_tone5}{1F9D8 1F3FF 200D 2642}
\bxce@do{man_in_manual_wheelchair}{1F468 200D 1F9BD}
\bxce@do{man_in_manual_wheelchair_tone1}{1F468 1F3FB 200D 1F9BD}
\bxce@do{man_in_manual_wheelchair_tone2}{1F468 1F3FC 200D 1F9BD}
\bxce@do{man_in_manual_wheelchair_tone3}{1F468 1F3FD 200D 1F9BD}
\bxce@do{man_in_manual_wheelchair_tone4}{1F468 1F3FE 200D 1F9BD}
\bxce@do{man_in_manual_wheelchair_tone5}{1F468 1F3FF 200D 1F9BD}
\bxce@do{man_in_motorized_wheelchair}{1F468 200D 1F9BC}
\bxce@do{man_in_motorized_wheelchair_tone1}{1F468 1F3FB 200D 1F9BC}
\bxce@do{man_in_motorized_wheelchair_tone2}{1F468 1F3FC 200D 1F9BC}
\bxce@do{man_in_motorized_wheelchair_tone3}{1F468 1F3FD 200D 1F9BC}
\bxce@do{man_in_motorized_wheelchair_tone4}{1F468 1F3FE 200D 1F9BC}
\bxce@do{man_in_motorized_wheelchair_tone5}{1F468 1F3FF 200D 1F9BC}
\bxce@do{man_in_steamy_room}{1F9D6 200D 2642}
\bxce@do{man_in_steamy_room_tone1}{1F9D6 1F3FB 200D 2642}
\bxce@do{man_in_steamy_room_tone2}{1F9D6 1F3FC 200D 2642}
\bxce@do{man_in_steamy_room_tone3}{1F9D6 1F3FD 200D 2642}
\bxce@do{man_in_steamy_room_tone4}{1F9D6 1F3FE 200D 2642}
\bxce@do{man_in_steamy_room_tone5}{1F9D6 1F3FF 200D 2642}
\bxce@do{man_in_tuxedo}{1F935 200D 2642}
\bxce@do{man_in_tuxedo_tone1}{1F935 1F3FB 200D 2642}
\bxce@do{man_in_tuxedo_tone2}{1F935 1F3FC 200D 2642}
\bxce@do{man_in_tuxedo_tone3}{1F935 1F3FD 200D 2642}
\bxce@do{man_in_tuxedo_tone4}{1F935 1F3FE 200D 2642}
\bxce@do{man_in_tuxedo_tone5}{1F935 1F3FF 200D 2642}
\bxce@do{man_judge}{1F468 200D 2696}
\bxce@do{man_judge_tone1}{1F468 1F3FB 200D 2696}
\bxce@do{man_judge_tone2}{1F468 1F3FC 200D 2696}
\bxce@do{man_judge_tone3}{1F468 1F3FD 200D 2696}
\bxce@do{man_judge_tone4}{1F468 1F3FE 200D 2696}
\bxce@do{man_judge_tone5}{1F468 1F3FF 200D 2696}
\bxce@do{man_juggling}{1F939 200D 2642}
\bxce@do{man_juggling_tone1}{1F939 1F3FB 200D 2642}
\bxce@do{man_juggling_tone2}{1F939 1F3FC 200D 2642}
\bxce@do{man_juggling_tone3}{1F939 1F3FD 200D 2642}
\bxce@do{man_juggling_tone4}{1F939 1F3FE 200D 2642}
\bxce@do{man_juggling_tone5}{1F939 1F3FF 200D 2642}
\bxce@do{man_kneeling}{1F9CE 200D 2642}
\bxce@do{man_kneeling_tone1}{1F9CE 1F3FB 200D 2642}
\bxce@do{man_kneeling_tone2}{1F9CE 1F3FC 200D 2642}
\bxce@do{man_kneeling_tone3}{1F9CE 1F3FD 200D 2642}
\bxce@do{man_kneeling_tone4}{1F9CE 1F3FE 200D 2642}
\bxce@do{man_kneeling_tone5}{1F9CE 1F3FF 200D 2642}
\bxce@do{man_lifting_weights}{1F3CB 200D 2642}
\bxce@do{man_lifting_weights_tone1}{1F3CB 1F3FB 200D 2642}
\bxce@do{man_lifting_weights_tone2}{1F3CB 1F3FC 200D 2642}
\bxce@do{man_lifting_weights_tone3}{1F3CB 1F3FD 200D 2642}
\bxce@do{man_lifting_weights_tone4}{1F3CB 1F3FE 200D 2642}
\bxce@do{man_lifting_weights_tone5}{1F3CB 1F3FF 200D 2642}
\bxce@do{man_mage}{1F9D9 200D 2642}
\bxce@do{man_mage_tone1}{1F9D9 1F3FB 200D 2642}
\bxce@do{man_mage_tone2}{1F9D9 1F3FC 200D 2642}
\bxce@do{man_mage_tone3}{1F9D9 1F3FD 200D 2642}
\bxce@do{man_mage_tone4}{1F9D9 1F3FE 200D 2642}
\bxce@do{man_mage_tone5}{1F9D9 1F3FF 200D 2642}
\bxce@do{man_mechanic}{1F468 200D 1F527}
\bxce@do{man_mechanic_tone1}{1F468 1F3FB 200D 1F527}
\bxce@do{man_mechanic_tone2}{1F468 1F3FC 200D 1F527}
\bxce@do{man_mechanic_tone3}{1F468 1F3FD 200D 1F527}
\bxce@do{man_mechanic_tone4}{1F468 1F3FE 200D 1F527}
\bxce@do{man_mechanic_tone5}{1F468 1F3FF 200D 1F527}
\bxce@do{man_mountain_biking}{1F6B5 200D 2642}
\bxce@do{man_mountain_biking_tone1}{1F6B5 1F3FB 200D 2642}
\bxce@do{man_mountain_biking_tone2}{1F6B5 1F3FC 200D 2642}
\bxce@do{man_mountain_biking_tone3}{1F6B5 1F3FD 200D 2642}
\bxce@do{man_mountain_biking_tone4}{1F6B5 1F3FE 200D 2642}
\bxce@do{man_mountain_biking_tone5}{1F6B5 1F3FF 200D 2642}
\bxce@do{man_office_worker}{1F468 200D 1F4BC}
\bxce@do{man_office_worker_tone1}{1F468 1F3FB 200D 1F4BC}
\bxce@do{man_office_worker_tone2}{1F468 1F3FC 200D 1F4BC}
\bxce@do{man_office_worker_tone3}{1F468 1F3FD 200D 1F4BC}
\bxce@do{man_office_worker_tone4}{1F468 1F3FE 200D 1F4BC}
\bxce@do{man_office_worker_tone5}{1F468 1F3FF 200D 1F4BC}
\bxce@do{man_pilot}{1F468 200D 2708}
\bxce@do{man_pilot_tone1}{1F468 1F3FB 200D 2708}
\bxce@do{man_pilot_tone2}{1F468 1F3FC 200D 2708}
\bxce@do{man_pilot_tone3}{1F468 1F3FD 200D 2708}
\bxce@do{man_pilot_tone4}{1F468 1F3FE 200D 2708}
\bxce@do{man_pilot_tone5}{1F468 1F3FF 200D 2708}
\bxce@do{man_playing_handball}{1F93E 200D 2642}
\bxce@do{man_playing_handball_tone1}{1F93E 1F3FB 200D 2642}
\bxce@do{man_playing_handball_tone2}{1F93E 1F3FC 200D 2642}
\bxce@do{man_playing_handball_tone3}{1F93E 1F3FD 200D 2642}
\bxce@do{man_playing_handball_tone4}{1F93E 1F3FE 200D 2642}
\bxce@do{man_playing_handball_tone5}{1F93E 1F3FF 200D 2642}
\bxce@do{man_playing_water_polo}{1F93D 200D 2642}
\bxce@do{man_playing_water_polo_tone1}{1F93D 1F3FB 200D 2642}
\bxce@do{man_playing_water_polo_tone2}{1F93D 1F3FC 200D 2642}
\bxce@do{man_playing_water_polo_tone3}{1F93D 1F3FD 200D 2642}
\bxce@do{man_playing_water_polo_tone4}{1F93D 1F3FE 200D 2642}
\bxce@do{man_playing_water_polo_tone5}{1F93D 1F3FF 200D 2642}
\bxce@do{man_police_officer}{1F46E 200D 2642}
\bxce@do{man_police_officer_tone1}{1F46E 1F3FB 200D 2642}
\bxce@do{man_police_officer_tone2}{1F46E 1F3FC 200D 2642}
\bxce@do{man_police_officer_tone3}{1F46E 1F3FD 200D 2642}
\bxce@do{man_police_officer_tone4}{1F46E 1F3FE 200D 2642}
\bxce@do{man_police_officer_tone5}{1F46E 1F3FF 200D 2642}
\bxce@do{man_pouting}{1F64E 200D 2642}
\bxce@do{man_pouting_tone1}{1F64E 1F3FB 200D 2642}
\bxce@do{man_pouting_tone2}{1F64E 1F3FC 200D 2642}
\bxce@do{man_pouting_tone3}{1F64E 1F3FD 200D 2642}
\bxce@do{man_pouting_tone4}{1F64E 1F3FE 200D 2642}
\bxce@do{man_pouting_tone5}{1F64E 1F3FF 200D 2642}
\bxce@do{man_raising_hand}{1F64B 200D 2642}
\bxce@do{man_raising_hand_tone1}{1F64B 1F3FB 200D 2642}
\bxce@do{man_raising_hand_tone2}{1F64B 1F3FC 200D 2642}
\bxce@do{man_raising_hand_tone3}{1F64B 1F3FD 200D 2642}
\bxce@do{man_raising_hand_tone4}{1F64B 1F3FE 200D 2642}
\bxce@do{man_raising_hand_tone5}{1F64B 1F3FF 200D 2642}
\bxce@do{man_red_haired}{1F468 200D 1F9B0}
\bxce@do{man_red_haired_tone1}{1F468 1F3FB 200D 1F9B0}
\bxce@do{man_red_haired_tone2}{1F468 1F3FC 200D 1F9B0}
\bxce@do{man_red_haired_tone3}{1F468 1F3FD 200D 1F9B0}
\bxce@do{man_red_haired_tone4}{1F468 1F3FE 200D 1F9B0}
\bxce@do{man_red_haired_tone5}{1F468 1F3FF 200D 1F9B0}
\bxce@do{man_rowing_boat}{1F6A3 200D 2642}
\bxce@do{man_rowing_boat_tone1}{1F6A3 1F3FB 200D 2642}
\bxce@do{man_rowing_boat_tone2}{1F6A3 1F3FC 200D 2642}
\bxce@do{man_rowing_boat_tone3}{1F6A3 1F3FD 200D 2642}
\bxce@do{man_rowing_boat_tone4}{1F6A3 1F3FE 200D 2642}
\bxce@do{man_rowing_boat_tone5}{1F6A3 1F3FF 200D 2642}
\bxce@do{man_running}{1F3C3 200D 2642}
\bxce@do{man_running_tone1}{1F3C3 1F3FB 200D 2642}
\bxce@do{man_running_tone2}{1F3C3 1F3FC 200D 2642}
\bxce@do{man_running_tone3}{1F3C3 1F3FD 200D 2642}
\bxce@do{man_running_tone4}{1F3C3 1F3FE 200D 2642}
\bxce@do{man_running_tone5}{1F3C3 1F3FF 200D 2642}
\bxce@do{man_scientist}{1F468 200D 1F52C}
\bxce@do{man_scientist_tone1}{1F468 1F3FB 200D 1F52C}
\bxce@do{man_scientist_tone2}{1F468 1F3FC 200D 1F52C}
\bxce@do{man_scientist_tone3}{1F468 1F3FD 200D 1F52C}
\bxce@do{man_scientist_tone4}{1F468 1F3FE 200D 1F52C}
\bxce@do{man_scientist_tone5}{1F468 1F3FF 200D 1F52C}
\bxce@do{man_shrugging}{1F937 200D 2642}
\bxce@do{man_shrugging_tone1}{1F937 1F3FB 200D 2642}
\bxce@do{man_shrugging_tone2}{1F937 1F3FC 200D 2642}
\bxce@do{man_shrugging_tone3}{1F937 1F3FD 200D 2642}
\bxce@do{man_shrugging_tone4}{1F937 1F3FE 200D 2642}
\bxce@do{man_shrugging_tone5}{1F937 1F3FF 200D 2642}
\bxce@do{man_singer}{1F468 200D 1F3A4}
\bxce@do{man_singer_tone1}{1F468 1F3FB 200D 1F3A4}
\bxce@do{man_singer_tone2}{1F468 1F3FC 200D 1F3A4}
\bxce@do{man_singer_tone3}{1F468 1F3FD 200D 1F3A4}
\bxce@do{man_singer_tone4}{1F468 1F3FE 200D 1F3A4}
\bxce@do{man_singer_tone5}{1F468 1F3FF 200D 1F3A4}
\bxce@do{man_standing}{1F9CD 200D 2642}
\bxce@do{man_standing_tone1}{1F9CD 1F3FB 200D 2642}
\bxce@do{man_standing_tone2}{1F9CD 1F3FC 200D 2642}
\bxce@do{man_standing_tone3}{1F9CD 1F3FD 200D 2642}
\bxce@do{man_standing_tone4}{1F9CD 1F3FE 200D 2642}
\bxce@do{man_standing_tone5}{1F9CD 1F3FF 200D 2642}
\bxce@do{man_student}{1F468 200D 1F393}
\bxce@do{man_student_tone1}{1F468 1F3FB 200D 1F393}
\bxce@do{man_student_tone2}{1F468 1F3FC 200D 1F393}
\bxce@do{man_student_tone3}{1F468 1F3FD 200D 1F393}
\bxce@do{man_student_tone4}{1F468 1F3FE 200D 1F393}
\bxce@do{man_student_tone5}{1F468 1F3FF 200D 1F393}
\bxce@do{man_superhero}{1F9B8 200D 2642}
\bxce@do{man_superhero_tone1}{1F9B8 1F3FB 200D 2642}
\bxce@do{man_superhero_tone2}{1F9B8 1F3FC 200D 2642}
\bxce@do{man_superhero_tone3}{1F9B8 1F3FD 200D 2642}
\bxce@do{man_superhero_tone4}{1F9B8 1F3FE 200D 2642}
\bxce@do{man_superhero_tone5}{1F9B8 1F3FF 200D 2642}
\bxce@do{man_supervillain}{1F9B9 200D 2642}
\bxce@do{man_supervillain_tone1}{1F9B9 1F3FB 200D 2642}
\bxce@do{man_supervillain_tone2}{1F9B9 1F3FC 200D 2642}
\bxce@do{man_supervillain_tone3}{1F9B9 1F3FD 200D 2642}
\bxce@do{man_supervillain_tone4}{1F9B9 1F3FE 200D 2642}
\bxce@do{man_supervillain_tone5}{1F9B9 1F3FF 200D 2642}
\bxce@do{man_surfing}{1F3C4 200D 2642}
\bxce@do{man_surfing_tone1}{1F3C4 1F3FB 200D 2642}
\bxce@do{man_surfing_tone2}{1F3C4 1F3FC 200D 2642}
\bxce@do{man_surfing_tone3}{1F3C4 1F3FD 200D 2642}
\bxce@do{man_surfing_tone4}{1F3C4 1F3FE 200D 2642}
\bxce@do{man_surfing_tone5}{1F3C4 1F3FF 200D 2642}
\bxce@do{man_swimming}{1F3CA 200D 2642}
\bxce@do{man_swimming_tone1}{1F3CA 1F3FB 200D 2642}
\bxce@do{man_swimming_tone2}{1F3CA 1F3FC 200D 2642}
\bxce@do{man_swimming_tone3}{1F3CA 1F3FD 200D 2642}
\bxce@do{man_swimming_tone4}{1F3CA 1F3FE 200D 2642}
\bxce@do{man_swimming_tone5}{1F3CA 1F3FF 200D 2642}
\bxce@do{man_teacher}{1F468 200D 1F3EB}
\bxce@do{man_teacher_tone1}{1F468 1F3FB 200D 1F3EB}
\bxce@do{man_teacher_tone2}{1F468 1F3FC 200D 1F3EB}
\bxce@do{man_teacher_tone3}{1F468 1F3FD 200D 1F3EB}
\bxce@do{man_teacher_tone4}{1F468 1F3FE 200D 1F3EB}
\bxce@do{man_teacher_tone5}{1F468 1F3FF 200D 1F3EB}
\bxce@do{man_technologist}{1F468 200D 1F4BB}
\bxce@do{man_technologist_tone1}{1F468 1F3FB 200D 1F4BB}
\bxce@do{man_technologist_tone2}{1F468 1F3FC 200D 1F4BB}
\bxce@do{man_technologist_tone3}{1F468 1F3FD 200D 1F4BB}
\bxce@do{man_technologist_tone4}{1F468 1F3FE 200D 1F4BB}
\bxce@do{man_technologist_tone5}{1F468 1F3FF 200D 1F4BB}
\bxce@do{man_tipping_hand}{1F481 200D 2642}
\bxce@do{man_tipping_hand_tone1}{1F481 1F3FB 200D 2642}
\bxce@do{man_tipping_hand_tone2}{1F481 1F3FC 200D 2642}
\bxce@do{man_tipping_hand_tone3}{1F481 1F3FD 200D 2642}
\bxce@do{man_tipping_hand_tone4}{1F481 1F3FE 200D 2642}
\bxce@do{man_tipping_hand_tone5}{1F481 1F3FF 200D 2642}
\bxce@do{man_tone1}{1F468 1F3FB}
\bxce@do{man_tone1_beard}{1F9D4 1F3FB 200D 2642}
\bxce@do{man_tone2}{1F468 1F3FC}
\bxce@do{man_tone2_beard}{1F9D4 1F3FC 200D 2642}
\bxce@do{man_tone3}{1F468 1F3FD}
\bxce@do{man_tone3_beard}{1F9D4 1F3FD 200D 2642}
\bxce@do{man_tone4}{1F468 1F3FE}
\bxce@do{man_tone4_beard}{1F9D4 1F3FE 200D 2642}
\bxce@do{man_tone5}{1F468 1F3FF}
\bxce@do{man_tone5_beard}{1F9D4 1F3FF 200D 2642}
\bxce@do{man_vampire}{1F9DB 200D 2642}
\bxce@do{man_vampire_tone1}{1F9DB 1F3FB 200D 2642}
\bxce@do{man_vampire_tone2}{1F9DB 1F3FC 200D 2642}
\bxce@do{man_vampire_tone3}{1F9DB 1F3FD 200D 2642}
\bxce@do{man_vampire_tone4}{1F9DB 1F3FE 200D 2642}
\bxce@do{man_vampire_tone5}{1F9DB 1F3FF 200D 2642}
\bxce@do{man_walking}{1F6B6 200D 2642}
\bxce@do{man_walking_tone1}{1F6B6 1F3FB 200D 2642}
\bxce@do{man_walking_tone2}{1F6B6 1F3FC 200D 2642}
\bxce@do{man_walking_tone3}{1F6B6 1F3FD 200D 2642}
\bxce@do{man_walking_tone4}{1F6B6 1F3FE 200D 2642}
\bxce@do{man_walking_tone5}{1F6B6 1F3FF 200D 2642}
\bxce@do{man_wearing_turban}{1F473 200D 2642}
\bxce@do{man_wearing_turban_tone1}{1F473 1F3FB 200D 2642}
\bxce@do{man_wearing_turban_tone2}{1F473 1F3FC 200D 2642}
\bxce@do{man_wearing_turban_tone3}{1F473 1F3FD 200D 2642}
\bxce@do{man_wearing_turban_tone4}{1F473 1F3FE 200D 2642}
\bxce@do{man_wearing_turban_tone5}{1F473 1F3FF 200D 2642}
\bxce@do{man_white_haired}{1F468 200D 1F9B3}
\bxce@do{man_white_haired_tone1}{1F468 1F3FB 200D 1F9B3}
\bxce@do{man_white_haired_tone2}{1F468 1F3FC 200D 1F9B3}
\bxce@do{man_white_haired_tone3}{1F468 1F3FD 200D 1F9B3}
\bxce@do{man_white_haired_tone4}{1F468 1F3FE 200D 1F9B3}
\bxce@do{man_white_haired_tone5}{1F468 1F3FF 200D 1F9B3}
\bxce@do{man_with_chinese_cap}{1F472}
\bxce@do{man_with_chinese_cap_tone1}{1F472 1F3FB}
\bxce@do{man_with_chinese_cap_tone2}{1F472 1F3FC}
\bxce@do{man_with_chinese_cap_tone3}{1F472 1F3FD}
\bxce@do{man_with_chinese_cap_tone4}{1F472 1F3FE}
\bxce@do{man_with_chinese_cap_tone5}{1F472 1F3FF}
\bxce@do{man_with_probing_cane}{1F468 200D 1F9AF}
\bxce@do{man_with_probing_cane_tone1}{1F468 1F3FB 200D 1F9AF}
\bxce@do{man_with_probing_cane_tone2}{1F468 1F3FC 200D 1F9AF}
\bxce@do{man_with_probing_cane_tone3}{1F468 1F3FD 200D 1F9AF}
\bxce@do{man_with_probing_cane_tone4}{1F468 1F3FE 200D 1F9AF}
\bxce@do{man_with_probing_cane_tone5}{1F468 1F3FF 200D 1F9AF}
\bxce@do{man_with_veil}{1F470 200D 2642}
\bxce@do{man_with_veil_tone1}{1F470 1F3FB 200D 2642}
\bxce@do{man_with_veil_tone2}{1F470 1F3FC 200D 2642}
\bxce@do{man_with_veil_tone3}{1F470 1F3FD 200D 2642}
\bxce@do{man_with_veil_tone4}{1F470 1F3FE 200D 2642}
\bxce@do{man_with_veil_tone5}{1F470 1F3FF 200D 2642}
\bxce@do{man_zombie}{1F9DF 200D 2642}
\bxce@do{mango}{1F96D}
\bxce@do{mans_shoe}{1F45E}
\bxce@do{manual_wheelchair}{1F9BD}
\bxce@do{map}{1F5FA}
\bxce@do{maple_leaf}{1F341}
\bxce@do{martial_arts_uniform}{1F94B}
\bxce@do{mask}{1F637}
\bxce@do{mate}{1F9C9}
\bxce@do{meat_on_bone}{1F356}
\bxce@do{mechanic}{1F9D1 200D 1F527}
\bxce@do{mechanic_tone1}{1F9D1 1F3FB 200D 1F527}
\bxce@do{mechanic_tone2}{1F9D1 1F3FC 200D 1F527}
\bxce@do{mechanic_tone3}{1F9D1 1F3FD 200D 1F527}
\bxce@do{mechanic_tone4}{1F9D1 1F3FE 200D 1F527}
\bxce@do{mechanic_tone5}{1F9D1 1F3FF 200D 1F527}
\bxce@do{mechanical_arm}{1F9BE}
\bxce@do{mechanical_leg}{1F9BF}
\bxce@do{medal}{1F3C5}
\bxce@do{medical_symbol}{2695}
\bxce@do{mega}{1F4E3}
\bxce@do{melon}{1F348}
\bxce@do{men_holding_hands}{1F46C}
\bxce@do{men_holding_hands_tone1}{1F46C 1F3FB}
\bxce@do{men_holding_hands_tone1_tone2}{1F468 1F3FB 200D 1F91D 200D 1F468 1F3FC}
\bxce@do{men_holding_hands_tone1_tone3}{1F468 1F3FB 200D 1F91D 200D 1F468 1F3FD}
\bxce@do{men_holding_hands_tone1_tone4}{1F468 1F3FB 200D 1F91D 200D 1F468 1F3FE}
\bxce@do{men_holding_hands_tone1_tone5}{1F468 1F3FB 200D 1F91D 200D 1F468 1F3FF}
\bxce@do{men_holding_hands_tone2}{1F46C 1F3FC}
\bxce@do{men_holding_hands_tone2_tone1}{1F468 1F3FC 200D 1F91D 200D 1F468 1F3FB}
\bxce@do{men_holding_hands_tone2_tone3}{1F468 1F3FC 200D 1F91D 200D 1F468 1F3FD}
\bxce@do{men_holding_hands_tone2_tone4}{1F468 1F3FC 200D 1F91D 200D 1F468 1F3FE}
\bxce@do{men_holding_hands_tone2_tone5}{1F468 1F3FC 200D 1F91D 200D 1F468 1F3FF}
\bxce@do{men_holding_hands_tone3}{1F46C 1F3FD}
\bxce@do{men_holding_hands_tone3_tone1}{1F468 1F3FD 200D 1F91D 200D 1F468 1F3FB}
\bxce@do{men_holding_hands_tone3_tone2}{1F468 1F3FD 200D 1F91D 200D 1F468 1F3FC}
\bxce@do{men_holding_hands_tone3_tone4}{1F468 1F3FD 200D 1F91D 200D 1F468 1F3FE}
\bxce@do{men_holding_hands_tone3_tone5}{1F468 1F3FD 200D 1F91D 200D 1F468 1F3FF}
\bxce@do{men_holding_hands_tone4}{1F46C 1F3FE}
\bxce@do{men_holding_hands_tone4_tone1}{1F468 1F3FE 200D 1F91D 200D 1F468 1F3FB}
\bxce@do{men_holding_hands_tone4_tone2}{1F468 1F3FE 200D 1F91D 200D 1F468 1F3FC}
\bxce@do{men_holding_hands_tone4_tone3}{1F468 1F3FE 200D 1F91D 200D 1F468 1F3FD}
\bxce@do{men_holding_hands_tone4_tone5}{1F468 1F3FE 200D 1F91D 200D 1F468 1F3FF}
\bxce@do{men_holding_hands_tone5}{1F46C 1F3FF}
\bxce@do{men_holding_hands_tone5_tone1}{1F468 1F3FF 200D 1F91D 200D 1F468 1F3FB}
\bxce@do{men_holding_hands_tone5_tone2}{1F468 1F3FF 200D 1F91D 200D 1F468 1F3FC}
\bxce@do{men_holding_hands_tone5_tone3}{1F468 1F3FF 200D 1F91D 200D 1F468 1F3FD}
\bxce@do{men_holding_hands_tone5_tone4}{1F468 1F3FF 200D 1F91D 200D 1F468 1F3FE}
\bxce@do{men_with_bunny_ears_partying}{1F46F 200D 2642}
\bxce@do{men_wrestling}{1F93C 200D 2642}
\bxce@do{mending_heart}{2764 200D 1FA79}
\bxce@do{menorah}{1F54E}
\bxce@do{mens}{1F6B9}
\bxce@do{mermaid}{1F9DC 200D 2640}
\bxce@do{mermaid_tone1}{1F9DC 1F3FB 200D 2640}
\bxce@do{mermaid_tone2}{1F9DC 1F3FC 200D 2640}
\bxce@do{mermaid_tone3}{1F9DC 1F3FD 200D 2640}
\bxce@do{mermaid_tone4}{1F9DC 1F3FE 200D 2640}
\bxce@do{mermaid_tone5}{1F9DC 1F3FF 200D 2640}
\bxce@do{merman}{1F9DC 200D 2642}
\bxce@do{merman_tone1}{1F9DC 1F3FB 200D 2642}
\bxce@do{merman_tone2}{1F9DC 1F3FC 200D 2642}
\bxce@do{merman_tone3}{1F9DC 1F3FD 200D 2642}
\bxce@do{merman_tone4}{1F9DC 1F3FE 200D 2642}
\bxce@do{merman_tone5}{1F9DC 1F3FF 200D 2642}
\bxce@do{merperson}{1F9DC}
\bxce@do{merperson_tone1}{1F9DC 1F3FB}
\bxce@do{merperson_tone2}{1F9DC 1F3FC}
\bxce@do{merperson_tone3}{1F9DC 1F3FD}
\bxce@do{merperson_tone4}{1F9DC 1F3FE}
\bxce@do{merperson_tone5}{1F9DC 1F3FF}
\bxce@do{metal}{1F918}
\bxce@do{metal_tone1}{1F918 1F3FB}
\bxce@do{metal_tone2}{1F918 1F3FC}
\bxce@do{metal_tone3}{1F918 1F3FD}
\bxce@do{metal_tone4}{1F918 1F3FE}
\bxce@do{metal_tone5}{1F918 1F3FF}
\bxce@do{metro}{1F687}
\bxce@do{microbe}{1F9A0}
\bxce@do{microphone}{1F3A4}
\bxce@do{microphone2}{1F399}
\bxce@do{microscope}{1F52C}
\bxce@do{middle_finger}{1F595}
\bxce@do{middle_finger_tone1}{1F595 1F3FB}
\bxce@do{middle_finger_tone2}{1F595 1F3FC}
\bxce@do{middle_finger_tone3}{1F595 1F3FD}
\bxce@do{middle_finger_tone4}{1F595 1F3FE}
\bxce@do{middle_finger_tone5}{1F595 1F3FF}
\bxce@do{military_helmet}{1FA96}
\bxce@do{military_medal}{1F396}
\bxce@do{milk}{1F95B}
\bxce@do{milky_way}{1F30C}
\bxce@do{minibus}{1F690}
\bxce@do{minidisc}{1F4BD}
\bxce@do{mirror}{1FA9E}
\bxce@do{mobile_phone}{1F4F1}
\bxce@do{mobile_phone_off}{1F4F4}
\bxce@do{money_mouth}{1F911}
\bxce@do{money_with_wings}{1F4B8}
\bxce@do{moneybag}{1F4B0}
\bxce@do{monkey}{1F412}
\bxce@do{monkey_face}{1F435}
\bxce@do{monorail}{1F69D}
\bxce@do{moon_cake}{1F96E}
\bxce@do{mortar_board}{1F393}
\bxce@do{mosque}{1F54C}
\bxce@do{mosquito}{1F99F}
\bxce@do{motor_scooter}{1F6F5}
\bxce@do{motorboat}{1F6E5}
\bxce@do{motorcycle}{1F3CD}
\bxce@do{motorized_wheelchair}{1F9BC}
\bxce@do{motorway}{1F6E3}
\bxce@do{mount_fuji}{1F5FB}
\bxce@do{mountain}{26F0}
\bxce@do{mountain_cableway}{1F6A0}
\bxce@do{mountain_railway}{1F69E}
\bxce@do{mountain_snow}{1F3D4}
\bxce@do{mouse}{1F42D}
\bxce@do{mouse2}{1F401}
\bxce@do{mouse_three_button}{1F5B1}
\bxce@do{mouse_trap}{1FAA4}
\bxce@do{movie_camera}{1F3A5}
\bxce@do{moyai}{1F5FF}
\bxce@do{mrs_claus}{1F936}
\bxce@do{mrs_claus_tone1}{1F936 1F3FB}
\bxce@do{mrs_claus_tone2}{1F936 1F3FC}
\bxce@do{mrs_claus_tone3}{1F936 1F3FD}
\bxce@do{mrs_claus_tone4}{1F936 1F3FE}
\bxce@do{mrs_claus_tone5}{1F936 1F3FF}
\bxce@do{muscle}{1F4AA}
\bxce@do{muscle_tone1}{1F4AA 1F3FB}
\bxce@do{muscle_tone2}{1F4AA 1F3FC}
\bxce@do{muscle_tone3}{1F4AA 1F3FD}
\bxce@do{muscle_tone4}{1F4AA 1F3FE}
\bxce@do{muscle_tone5}{1F4AA 1F3FF}
\bxce@do{mushroom}{1F344}
\bxce@do{musical_keyboard}{1F3B9}
\bxce@do{musical_note}{1F3B5}
\bxce@do{musical_score}{1F3BC}
\bxce@do{mute}{1F507}
\bxce@do{mx_claus}{1F9D1 200D 1F384}
\bxce@do{mx_claus_tone1}{1F9D1 1F3FB 200D 1F384}
\bxce@do{mx_claus_tone2}{1F9D1 1F3FC 200D 1F384}
\bxce@do{mx_claus_tone3}{1F9D1 1F3FD 200D 1F384}
\bxce@do{mx_claus_tone4}{1F9D1 1F3FE 200D 1F384}
\bxce@do{mx_claus_tone5}{1F9D1 1F3FF 200D 1F384}
\or %[4]
\bxce@do{nail_care}{1F485}
\bxce@do{nail_care_tone1}{1F485 1F3FB}
\bxce@do{nail_care_tone2}{1F485 1F3FC}
\bxce@do{nail_care_tone3}{1F485 1F3FD}
\bxce@do{nail_care_tone4}{1F485 1F3FE}
\bxce@do{nail_care_tone5}{1F485 1F3FF}
\bxce@do{name_badge}{1F4DB}
\bxce@do{nauseated_face}{1F922}
\bxce@do{nazar_amulet}{1F9FF}
\bxce@do{necktie}{1F454}
\bxce@do{negative_squared_cross_mark}{274E}
\bxce@do{nerd}{1F913}
\bxce@do{nesting_dolls}{1FA86}
\bxce@do{neutral_face}{1F610}
\bxce@do{new}{1F195}
\bxce@do{new_moon}{1F311}
\bxce@do{new_moon_with_face}{1F31A}
\bxce@do{newspaper}{1F4F0}
\bxce@do{newspaper2}{1F5DE}
\bxce@do{ng}{1F196}
\bxce@do{night_with_stars}{1F303}
\bxce@do{nine}{39 20E3}
\bxce@do{ninja}{1F977}
\bxce@do{ninja_tone1}{1F977 1F3FB}
\bxce@do{ninja_tone2}{1F977 1F3FC}
\bxce@do{ninja_tone3}{1F977 1F3FD}
\bxce@do{ninja_tone4}{1F977 1F3FE}
\bxce@do{ninja_tone5}{1F977 1F3FF}
\bxce@do{no_bell}{1F515}
\bxce@do{no_bicycles}{1F6B3}
\bxce@do{no_entry}{26D4}
\bxce@do{no_entry_sign}{1F6AB}
\bxce@do{no_mobile_phones}{1F4F5}
\bxce@do{no_mouth}{1F636}
\bxce@do{no_pedestrians}{1F6B7}
\bxce@do{no_smoking}{1F6AD}
\bxce@do{non-potable_water}{1F6B1}
\bxce@do{nose}{1F443}
\bxce@do{nose_tone1}{1F443 1F3FB}
\bxce@do{nose_tone2}{1F443 1F3FC}
\bxce@do{nose_tone3}{1F443 1F3FD}
\bxce@do{nose_tone4}{1F443 1F3FE}
\bxce@do{nose_tone5}{1F443 1F3FF}
\bxce@do{notebook}{1F4D3}
\bxce@do{notebook_with_decorative_cover}{1F4D4}
\bxce@do{notepad_spiral}{1F5D2}
\bxce@do{notes}{1F3B6}
\bxce@do{nut_and_bolt}{1F529}
\bxce@do{o}{2B55}
\bxce@do{o2}{1F17E}
\bxce@do{ocean}{1F30A}
\bxce@do{octagonal_sign}{1F6D1}
\bxce@do{octopus}{1F419}
\bxce@do{oden}{1F362}
\bxce@do{office}{1F3E2}
\bxce@do{office_worker}{1F9D1 200D 1F4BC}
\bxce@do{office_worker_tone1}{1F9D1 1F3FB 200D 1F4BC}
\bxce@do{office_worker_tone2}{1F9D1 1F3FC 200D 1F4BC}
\bxce@do{office_worker_tone3}{1F9D1 1F3FD 200D 1F4BC}
\bxce@do{office_worker_tone4}{1F9D1 1F3FE 200D 1F4BC}
\bxce@do{office_worker_tone5}{1F9D1 1F3FF 200D 1F4BC}
\bxce@do{oil}{1F6E2}
\bxce@do{ok}{1F197}
\bxce@do{ok_hand}{1F44C}
\bxce@do{ok_hand_tone1}{1F44C 1F3FB}
\bxce@do{ok_hand_tone2}{1F44C 1F3FC}
\bxce@do{ok_hand_tone3}{1F44C 1F3FD}
\bxce@do{ok_hand_tone4}{1F44C 1F3FE}
\bxce@do{ok_hand_tone5}{1F44C 1F3FF}
\bxce@do{older_adult}{1F9D3}
\bxce@do{older_adult_tone1}{1F9D3 1F3FB}
\bxce@do{older_adult_tone2}{1F9D3 1F3FC}
\bxce@do{older_adult_tone3}{1F9D3 1F3FD}
\bxce@do{older_adult_tone4}{1F9D3 1F3FE}
\bxce@do{older_adult_tone5}{1F9D3 1F3FF}
\bxce@do{older_man}{1F474}
\bxce@do{older_man_tone1}{1F474 1F3FB}
\bxce@do{older_man_tone2}{1F474 1F3FC}
\bxce@do{older_man_tone3}{1F474 1F3FD}
\bxce@do{older_man_tone4}{1F474 1F3FE}
\bxce@do{older_man_tone5}{1F474 1F3FF}
\bxce@do{older_woman}{1F475}
\bxce@do{older_woman_tone1}{1F475 1F3FB}
\bxce@do{older_woman_tone2}{1F475 1F3FC}
\bxce@do{older_woman_tone3}{1F475 1F3FD}
\bxce@do{older_woman_tone4}{1F475 1F3FE}
\bxce@do{older_woman_tone5}{1F475 1F3FF}
\bxce@do{olive}{1FAD2}
\bxce@do{om_symbol}{1F549}
\bxce@do{on}{1F51B}
\bxce@do{oncoming_automobile}{1F698}
\bxce@do{oncoming_bus}{1F68D}
\bxce@do{oncoming_police_car}{1F694}
\bxce@do{oncoming_taxi}{1F696}
\bxce@do{one}{31 20E3}
\bxce@do{one_piece_swimsuit}{1FA71}
\bxce@do{onion}{1F9C5}
\bxce@do{open_file_folder}{1F4C2}
\bxce@do{open_hands}{1F450}
\bxce@do{open_hands_tone1}{1F450 1F3FB}
\bxce@do{open_hands_tone2}{1F450 1F3FC}
\bxce@do{open_hands_tone3}{1F450 1F3FD}
\bxce@do{open_hands_tone4}{1F450 1F3FE}
\bxce@do{open_hands_tone5}{1F450 1F3FF}
\bxce@do{open_mouth}{1F62E}
\bxce@do{ophiuchus}{26CE}
\bxce@do{orange_book}{1F4D9}
\bxce@do{orange_circle}{1F7E0}
\bxce@do{orange_heart}{1F9E1}
\bxce@do{orange_square}{1F7E7}
\bxce@do{orangutan}{1F9A7}
\bxce@do{orthodox_cross}{2626}
\bxce@do{otter}{1F9A6}
\bxce@do{outbox_tray}{1F4E4}
\bxce@do{owl}{1F989}
\bxce@do{ox}{1F402}
\bxce@do{oyster}{1F9AA}
\bxce@do{package}{1F4E6}
\bxce@do{page_facing_up}{1F4C4}
\bxce@do{page_with_curl}{1F4C3}
\bxce@do{pager}{1F4DF}
\bxce@do{paintbrush}{1F58C}
\bxce@do{palm_tree}{1F334}
\bxce@do{palms_up_together}{1F932}
\bxce@do{palms_up_together_tone1}{1F932 1F3FB}
\bxce@do{palms_up_together_tone2}{1F932 1F3FC}
\bxce@do{palms_up_together_tone3}{1F932 1F3FD}
\bxce@do{palms_up_together_tone4}{1F932 1F3FE}
\bxce@do{palms_up_together_tone5}{1F932 1F3FF}
\bxce@do{pancakes}{1F95E}
\bxce@do{panda_face}{1F43C}
\bxce@do{paperclip}{1F4CE}
\bxce@do{paperclips}{1F587}
\bxce@do{parachute}{1FA82}
\bxce@do{park}{1F3DE}
\bxce@do{parking}{1F17F}
\bxce@do{parrot}{1F99C}
\bxce@do{part_alternation_mark}{303D}
\bxce@do{partly_sunny}{26C5}
\bxce@do{partying_face}{1F973}
\bxce@do{passport_control}{1F6C2}
\bxce@do{pause_button}{23F8}
\bxce@do{peace}{262E}
\bxce@do{peach}{1F351}
\bxce@do{peacock}{1F99A}
\bxce@do{peanuts}{1F95C}
\bxce@do{pear}{1F350}
\bxce@do{pen_ballpoint}{1F58A}
\bxce@do{pen_fountain}{1F58B}
\bxce@do{pencil}{1F4DD}
\bxce@do{pencil2}{270F}
\bxce@do{penguin}{1F427}
\bxce@do{pensive}{1F614}
\bxce@do{people_holding_hands}{1F9D1 200D 1F91D 200D 1F9D1}
\bxce@do{people_holding_hands_tone1}{1F9D1 1F3FB 200D 1F91D 200D 1F9D1 1F3FB}
\bxce@do{people_holding_hands_tone1_tone2}{1F9D1 1F3FB 200D 1F91D 200D 1F9D1 1F3FC}
\bxce@do{people_holding_hands_tone1_tone3}{1F9D1 1F3FB 200D 1F91D 200D 1F9D1 1F3FD}
\bxce@do{people_holding_hands_tone1_tone4}{1F9D1 1F3FB 200D 1F91D 200D 1F9D1 1F3FE}
\bxce@do{people_holding_hands_tone1_tone5}{1F9D1 1F3FB 200D 1F91D 200D 1F9D1 1F3FF}
\bxce@do{people_holding_hands_tone2}{1F9D1 1F3FC 200D 1F91D 200D 1F9D1 1F3FC}
\bxce@do{people_holding_hands_tone2_tone1}{1F9D1 1F3FC 200D 1F91D 200D 1F9D1 1F3FB}
\bxce@do{people_holding_hands_tone2_tone3}{1F9D1 1F3FC 200D 1F91D 200D 1F9D1 1F3FD}
\bxce@do{people_holding_hands_tone2_tone4}{1F9D1 1F3FC 200D 1F91D 200D 1F9D1 1F3FE}
\bxce@do{people_holding_hands_tone2_tone5}{1F9D1 1F3FC 200D 1F91D 200D 1F9D1 1F3FF}
\bxce@do{people_holding_hands_tone3}{1F9D1 1F3FD 200D 1F91D 200D 1F9D1 1F3FD}
\bxce@do{people_holding_hands_tone3_tone1}{1F9D1 1F3FD 200D 1F91D 200D 1F9D1 1F3FB}
\bxce@do{people_holding_hands_tone3_tone2}{1F9D1 1F3FD 200D 1F91D 200D 1F9D1 1F3FC}
\bxce@do{people_holding_hands_tone3_tone4}{1F9D1 1F3FD 200D 1F91D 200D 1F9D1 1F3FE}
\bxce@do{people_holding_hands_tone3_tone5}{1F9D1 1F3FD 200D 1F91D 200D 1F9D1 1F3FF}
\bxce@do{people_holding_hands_tone4}{1F9D1 1F3FE 200D 1F91D 200D 1F9D1 1F3FE}
\bxce@do{people_holding_hands_tone4_tone1}{1F9D1 1F3FE 200D 1F91D 200D 1F9D1 1F3FB}
\bxce@do{people_holding_hands_tone4_tone2}{1F9D1 1F3FE 200D 1F91D 200D 1F9D1 1F3FC}
\bxce@do{people_holding_hands_tone4_tone3}{1F9D1 1F3FE 200D 1F91D 200D 1F9D1 1F3FD}
\bxce@do{people_holding_hands_tone4_tone5}{1F9D1 1F3FE 200D 1F91D 200D 1F9D1 1F3FF}
\bxce@do{people_holding_hands_tone5}{1F9D1 1F3FF 200D 1F91D 200D 1F9D1 1F3FF}
\bxce@do{people_holding_hands_tone5_tone1}{1F9D1 1F3FF 200D 1F91D 200D 1F9D1 1F3FB}
\bxce@do{people_holding_hands_tone5_tone2}{1F9D1 1F3FF 200D 1F91D 200D 1F9D1 1F3FC}
\bxce@do{people_holding_hands_tone5_tone3}{1F9D1 1F3FF 200D 1F91D 200D 1F9D1 1F3FD}
\bxce@do{people_holding_hands_tone5_tone4}{1F9D1 1F3FF 200D 1F91D 200D 1F9D1 1F3FE}
\bxce@do{people_hugging}{1FAC2}
\bxce@do{people_with_bunny_ears_partying}{1F46F}
\bxce@do{people_wrestling}{1F93C}
\bxce@do{performing_arts}{1F3AD}
\bxce@do{persevere}{1F623}
\bxce@do{person_bald}{1F9D1 200D 1F9B2}
\bxce@do{person_biking}{1F6B4}
\bxce@do{person_biking_tone1}{1F6B4 1F3FB}
\bxce@do{person_biking_tone2}{1F6B4 1F3FC}
\bxce@do{person_biking_tone3}{1F6B4 1F3FD}
\bxce@do{person_biking_tone4}{1F6B4 1F3FE}
\bxce@do{person_biking_tone5}{1F6B4 1F3FF}
\bxce@do{person_bouncing_ball}{26F9}
\bxce@do{person_bouncing_ball_tone1}{26F9 1F3FB}
\bxce@do{person_bouncing_ball_tone2}{26F9 1F3FC}
\bxce@do{person_bouncing_ball_tone3}{26F9 1F3FD}
\bxce@do{person_bouncing_ball_tone4}{26F9 1F3FE}
\bxce@do{person_bouncing_ball_tone5}{26F9 1F3FF}
\bxce@do{person_bowing}{1F647}
\bxce@do{person_bowing_tone1}{1F647 1F3FB}
\bxce@do{person_bowing_tone2}{1F647 1F3FC}
\bxce@do{person_bowing_tone3}{1F647 1F3FD}
\bxce@do{person_bowing_tone4}{1F647 1F3FE}
\bxce@do{person_bowing_tone5}{1F647 1F3FF}
\bxce@do{person_climbing}{1F9D7}
\bxce@do{person_climbing_tone1}{1F9D7 1F3FB}
\bxce@do{person_climbing_tone2}{1F9D7 1F3FC}
\bxce@do{person_climbing_tone3}{1F9D7 1F3FD}
\bxce@do{person_climbing_tone4}{1F9D7 1F3FE}
\bxce@do{person_climbing_tone5}{1F9D7 1F3FF}
\bxce@do{person_curly_hair}{1F9D1 200D 1F9B1}
\bxce@do{person_doing_cartwheel}{1F938}
\bxce@do{person_doing_cartwheel_tone1}{1F938 1F3FB}
\bxce@do{person_doing_cartwheel_tone2}{1F938 1F3FC}
\bxce@do{person_doing_cartwheel_tone3}{1F938 1F3FD}
\bxce@do{person_doing_cartwheel_tone4}{1F938 1F3FE}
\bxce@do{person_doing_cartwheel_tone5}{1F938 1F3FF}
\bxce@do{person_facepalming}{1F926}
\bxce@do{person_facepalming_tone1}{1F926 1F3FB}
\bxce@do{person_facepalming_tone2}{1F926 1F3FC}
\bxce@do{person_facepalming_tone3}{1F926 1F3FD}
\bxce@do{person_facepalming_tone4}{1F926 1F3FE}
\bxce@do{person_facepalming_tone5}{1F926 1F3FF}
\bxce@do{person_feeding_baby}{1F9D1 200D 1F37C}
\bxce@do{person_feeding_baby_tone1}{1F9D1 1F3FB 200D 1F37C}
\bxce@do{person_feeding_baby_tone2}{1F9D1 1F3FC 200D 1F37C}
\bxce@do{person_feeding_baby_tone3}{1F9D1 1F3FD 200D 1F37C}
\bxce@do{person_feeding_baby_tone4}{1F9D1 1F3FE 200D 1F37C}
\bxce@do{person_feeding_baby_tone5}{1F9D1 1F3FF 200D 1F37C}
\bxce@do{person_fencing}{1F93A}
\bxce@do{person_frowning}{1F64D}
\bxce@do{person_frowning_tone1}{1F64D 1F3FB}
\bxce@do{person_frowning_tone2}{1F64D 1F3FC}
\bxce@do{person_frowning_tone3}{1F64D 1F3FD}
\bxce@do{person_frowning_tone4}{1F64D 1F3FE}
\bxce@do{person_frowning_tone5}{1F64D 1F3FF}
\bxce@do{person_gesturing_no}{1F645}
\bxce@do{person_gesturing_no_tone1}{1F645 1F3FB}
\bxce@do{person_gesturing_no_tone2}{1F645 1F3FC}
\bxce@do{person_gesturing_no_tone3}{1F645 1F3FD}
\bxce@do{person_gesturing_no_tone4}{1F645 1F3FE}
\bxce@do{person_gesturing_no_tone5}{1F645 1F3FF}
\bxce@do{person_gesturing_ok}{1F646}
\bxce@do{person_gesturing_ok_tone1}{1F646 1F3FB}
\bxce@do{person_gesturing_ok_tone2}{1F646 1F3FC}
\bxce@do{person_gesturing_ok_tone3}{1F646 1F3FD}
\bxce@do{person_gesturing_ok_tone4}{1F646 1F3FE}
\bxce@do{person_gesturing_ok_tone5}{1F646 1F3FF}
\bxce@do{person_getting_haircut}{1F487}
\bxce@do{person_getting_haircut_tone1}{1F487 1F3FB}
\bxce@do{person_getting_haircut_tone2}{1F487 1F3FC}
\bxce@do{person_getting_haircut_tone3}{1F487 1F3FD}
\bxce@do{person_getting_haircut_tone4}{1F487 1F3FE}
\bxce@do{person_getting_haircut_tone5}{1F487 1F3FF}
\bxce@do{person_getting_massage}{1F486}
\bxce@do{person_getting_massage_tone1}{1F486 1F3FB}
\bxce@do{person_getting_massage_tone2}{1F486 1F3FC}
\bxce@do{person_getting_massage_tone3}{1F486 1F3FD}
\bxce@do{person_getting_massage_tone4}{1F486 1F3FE}
\bxce@do{person_getting_massage_tone5}{1F486 1F3FF}
\bxce@do{person_golfing}{1F3CC}
\bxce@do{person_golfing_tone1}{1F3CC 1F3FB}
\bxce@do{person_golfing_tone2}{1F3CC 1F3FC}
\bxce@do{person_golfing_tone3}{1F3CC 1F3FD}
\bxce@do{person_golfing_tone4}{1F3CC 1F3FE}
\bxce@do{person_golfing_tone5}{1F3CC 1F3FF}
\bxce@do{person_in_bed}{1F6CC}
\bxce@do{person_in_bed_tone1}{1F6CC 1F3FB}
\bxce@do{person_in_bed_tone2}{1F6CC 1F3FC}
\bxce@do{person_in_bed_tone3}{1F6CC 1F3FD}
\bxce@do{person_in_bed_tone4}{1F6CC 1F3FE}
\bxce@do{person_in_bed_tone5}{1F6CC 1F3FF}
\bxce@do{person_in_lotus_position}{1F9D8}
\bxce@do{person_in_lotus_position_tone1}{1F9D8 1F3FB}
\bxce@do{person_in_lotus_position_tone2}{1F9D8 1F3FC}
\bxce@do{person_in_lotus_position_tone3}{1F9D8 1F3FD}
\bxce@do{person_in_lotus_position_tone4}{1F9D8 1F3FE}
\bxce@do{person_in_lotus_position_tone5}{1F9D8 1F3FF}
\bxce@do{person_in_manual_wheelchair}{1F9D1 200D 1F9BD}
\bxce@do{person_in_manual_wheelchair_tone1}{1F9D1 1F3FB 200D 1F9BD}
\bxce@do{person_in_manual_wheelchair_tone2}{1F9D1 1F3FC 200D 1F9BD}
\bxce@do{person_in_manual_wheelchair_tone3}{1F9D1 1F3FD 200D 1F9BD}
\bxce@do{person_in_manual_wheelchair_tone4}{1F9D1 1F3FE 200D 1F9BD}
\bxce@do{person_in_manual_wheelchair_tone5}{1F9D1 1F3FF 200D 1F9BD}
\bxce@do{person_in_motorized_wheelchair}{1F9D1 200D 1F9BC}
\bxce@do{person_in_motorized_wheelchair_tone1}{1F9D1 1F3FB 200D 1F9BC}
\bxce@do{person_in_motorized_wheelchair_tone2}{1F9D1 1F3FC 200D 1F9BC}
\bxce@do{person_in_motorized_wheelchair_tone3}{1F9D1 1F3FD 200D 1F9BC}
\bxce@do{person_in_motorized_wheelchair_tone4}{1F9D1 1F3FE 200D 1F9BC}
\bxce@do{person_in_motorized_wheelchair_tone5}{1F9D1 1F3FF 200D 1F9BC}
\bxce@do{person_in_steamy_room}{1F9D6}
\bxce@do{person_in_steamy_room_tone1}{1F9D6 1F3FB}
\bxce@do{person_in_steamy_room_tone2}{1F9D6 1F3FC}
\bxce@do{person_in_steamy_room_tone3}{1F9D6 1F3FD}
\bxce@do{person_in_steamy_room_tone4}{1F9D6 1F3FE}
\bxce@do{person_in_steamy_room_tone5}{1F9D6 1F3FF}
\bxce@do{person_in_tuxedo}{1F935}
\bxce@do{person_in_tuxedo_tone1}{1F935 1F3FB}
\bxce@do{person_in_tuxedo_tone2}{1F935 1F3FC}
\bxce@do{person_in_tuxedo_tone3}{1F935 1F3FD}
\bxce@do{person_in_tuxedo_tone4}{1F935 1F3FE}
\bxce@do{person_in_tuxedo_tone5}{1F935 1F3FF}
\bxce@do{person_juggling}{1F939}
\bxce@do{person_juggling_tone1}{1F939 1F3FB}
\bxce@do{person_juggling_tone2}{1F939 1F3FC}
\bxce@do{person_juggling_tone3}{1F939 1F3FD}
\bxce@do{person_juggling_tone4}{1F939 1F3FE}
\bxce@do{person_juggling_tone5}{1F939 1F3FF}
\bxce@do{person_kneeling}{1F9CE}
\bxce@do{person_kneeling_tone1}{1F9CE 1F3FB}
\bxce@do{person_kneeling_tone2}{1F9CE 1F3FC}
\bxce@do{person_kneeling_tone3}{1F9CE 1F3FD}
\bxce@do{person_kneeling_tone4}{1F9CE 1F3FE}
\bxce@do{person_kneeling_tone5}{1F9CE 1F3FF}
\bxce@do{person_lifting_weights}{1F3CB}
\bxce@do{person_lifting_weights_tone1}{1F3CB 1F3FB}
\bxce@do{person_lifting_weights_tone2}{1F3CB 1F3FC}
\bxce@do{person_lifting_weights_tone3}{1F3CB 1F3FD}
\bxce@do{person_lifting_weights_tone4}{1F3CB 1F3FE}
\bxce@do{person_lifting_weights_tone5}{1F3CB 1F3FF}
\bxce@do{person_mountain_biking}{1F6B5}
\bxce@do{person_mountain_biking_tone1}{1F6B5 1F3FB}
\bxce@do{person_mountain_biking_tone2}{1F6B5 1F3FC}
\bxce@do{person_mountain_biking_tone3}{1F6B5 1F3FD}
\bxce@do{person_mountain_biking_tone4}{1F6B5 1F3FE}
\bxce@do{person_mountain_biking_tone5}{1F6B5 1F3FF}
\bxce@do{person_playing_handball}{1F93E}
\bxce@do{person_playing_handball_tone1}{1F93E 1F3FB}
\bxce@do{person_playing_handball_tone2}{1F93E 1F3FC}
\bxce@do{person_playing_handball_tone3}{1F93E 1F3FD}
\bxce@do{person_playing_handball_tone4}{1F93E 1F3FE}
\bxce@do{person_playing_handball_tone5}{1F93E 1F3FF}
\bxce@do{person_playing_water_polo}{1F93D}
\bxce@do{person_playing_water_polo_tone1}{1F93D 1F3FB}
\bxce@do{person_playing_water_polo_tone2}{1F93D 1F3FC}
\bxce@do{person_playing_water_polo_tone3}{1F93D 1F3FD}
\bxce@do{person_playing_water_polo_tone4}{1F93D 1F3FE}
\bxce@do{person_playing_water_polo_tone5}{1F93D 1F3FF}
\bxce@do{person_pouting}{1F64E}
\bxce@do{person_pouting_tone1}{1F64E 1F3FB}
\bxce@do{person_pouting_tone2}{1F64E 1F3FC}
\bxce@do{person_pouting_tone3}{1F64E 1F3FD}
\bxce@do{person_pouting_tone4}{1F64E 1F3FE}
\bxce@do{person_pouting_tone5}{1F64E 1F3FF}
\bxce@do{person_raising_hand}{1F64B}
\bxce@do{person_raising_hand_tone1}{1F64B 1F3FB}
\bxce@do{person_raising_hand_tone2}{1F64B 1F3FC}
\bxce@do{person_raising_hand_tone3}{1F64B 1F3FD}
\bxce@do{person_raising_hand_tone4}{1F64B 1F3FE}
\bxce@do{person_raising_hand_tone5}{1F64B 1F3FF}
\bxce@do{person_red_hair}{1F9D1 200D 1F9B0}
\bxce@do{person_rowing_boat}{1F6A3}
\bxce@do{person_rowing_boat_tone1}{1F6A3 1F3FB}
\bxce@do{person_rowing_boat_tone2}{1F6A3 1F3FC}
\bxce@do{person_rowing_boat_tone3}{1F6A3 1F3FD}
\bxce@do{person_rowing_boat_tone4}{1F6A3 1F3FE}
\bxce@do{person_rowing_boat_tone5}{1F6A3 1F3FF}
\bxce@do{person_running}{1F3C3}
\bxce@do{person_running_tone1}{1F3C3 1F3FB}
\bxce@do{person_running_tone2}{1F3C3 1F3FC}
\bxce@do{person_running_tone3}{1F3C3 1F3FD}
\bxce@do{person_running_tone4}{1F3C3 1F3FE}
\bxce@do{person_running_tone5}{1F3C3 1F3FF}
\bxce@do{person_shrugging}{1F937}
\bxce@do{person_shrugging_tone1}{1F937 1F3FB}
\bxce@do{person_shrugging_tone2}{1F937 1F3FC}
\bxce@do{person_shrugging_tone3}{1F937 1F3FD}
\bxce@do{person_shrugging_tone4}{1F937 1F3FE}
\bxce@do{person_shrugging_tone5}{1F937 1F3FF}
\bxce@do{person_standing}{1F9CD}
\bxce@do{person_standing_tone1}{1F9CD 1F3FB}
\bxce@do{person_standing_tone2}{1F9CD 1F3FC}
\bxce@do{person_standing_tone3}{1F9CD 1F3FD}
\bxce@do{person_standing_tone4}{1F9CD 1F3FE}
\bxce@do{person_standing_tone5}{1F9CD 1F3FF}
\bxce@do{person_surfing}{1F3C4}
\bxce@do{person_surfing_tone1}{1F3C4 1F3FB}
\bxce@do{person_surfing_tone2}{1F3C4 1F3FC}
\bxce@do{person_surfing_tone3}{1F3C4 1F3FD}
\bxce@do{person_surfing_tone4}{1F3C4 1F3FE}
\bxce@do{person_surfing_tone5}{1F3C4 1F3FF}
\bxce@do{person_swimming}{1F3CA}
\bxce@do{person_swimming_tone1}{1F3CA 1F3FB}
\bxce@do{person_swimming_tone2}{1F3CA 1F3FC}
\bxce@do{person_swimming_tone3}{1F3CA 1F3FD}
\bxce@do{person_swimming_tone4}{1F3CA 1F3FE}
\bxce@do{person_swimming_tone5}{1F3CA 1F3FF}
\bxce@do{person_tipping_hand}{1F481}
\bxce@do{person_tipping_hand_tone1}{1F481 1F3FB}
\bxce@do{person_tipping_hand_tone2}{1F481 1F3FC}
\bxce@do{person_tipping_hand_tone3}{1F481 1F3FD}
\bxce@do{person_tipping_hand_tone4}{1F481 1F3FE}
\bxce@do{person_tipping_hand_tone5}{1F481 1F3FF}
\bxce@do{person_tone1_bald}{1F9D1 1F3FB 200D 1F9B2}
\bxce@do{person_tone1_curly_hair}{1F9D1 1F3FB 200D 1F9B1}
\bxce@do{person_tone1_red_hair}{1F9D1 1F3FB 200D 1F9B0}
\bxce@do{person_tone1_white_hair}{1F9D1 1F3FB 200D 1F9B3}
\bxce@do{person_tone2_bald}{1F9D1 1F3FC 200D 1F9B2}
\bxce@do{person_tone2_curly_hair}{1F9D1 1F3FC 200D 1F9B1}
\bxce@do{person_tone2_red_hair}{1F9D1 1F3FC 200D 1F9B0}
\bxce@do{person_tone2_white_hair}{1F9D1 1F3FC 200D 1F9B3}
\bxce@do{person_tone3_bald}{1F9D1 1F3FD 200D 1F9B2}
\bxce@do{person_tone3_curly_hair}{1F9D1 1F3FD 200D 1F9B1}
\bxce@do{person_tone3_red_hair}{1F9D1 1F3FD 200D 1F9B0}
\bxce@do{person_tone3_white_hair}{1F9D1 1F3FD 200D 1F9B3}
\bxce@do{person_tone4_bald}{1F9D1 1F3FE 200D 1F9B2}
\bxce@do{person_tone4_curly_hair}{1F9D1 1F3FE 200D 1F9B1}
\bxce@do{person_tone4_red_hair}{1F9D1 1F3FE 200D 1F9B0}
\bxce@do{person_tone4_white_hair}{1F9D1 1F3FE 200D 1F9B3}
\bxce@do{person_tone5_bald}{1F9D1 1F3FF 200D 1F9B2}
\bxce@do{person_tone5_curly_hair}{1F9D1 1F3FF 200D 1F9B1}
\bxce@do{person_tone5_red_hair}{1F9D1 1F3FF 200D 1F9B0}
\bxce@do{person_tone5_white_hair}{1F9D1 1F3FF 200D 1F9B3}
\bxce@do{person_walking}{1F6B6}
\bxce@do{person_walking_tone1}{1F6B6 1F3FB}
\bxce@do{person_walking_tone2}{1F6B6 1F3FC}
\bxce@do{person_walking_tone3}{1F6B6 1F3FD}
\bxce@do{person_walking_tone4}{1F6B6 1F3FE}
\bxce@do{person_walking_tone5}{1F6B6 1F3FF}
\bxce@do{person_wearing_turban}{1F473}
\bxce@do{person_wearing_turban_tone1}{1F473 1F3FB}
\bxce@do{person_wearing_turban_tone2}{1F473 1F3FC}
\bxce@do{person_wearing_turban_tone3}{1F473 1F3FD}
\bxce@do{person_wearing_turban_tone4}{1F473 1F3FE}
\bxce@do{person_wearing_turban_tone5}{1F473 1F3FF}
\bxce@do{person_white_hair}{1F9D1 200D 1F9B3}
\bxce@do{person_with_probing_cane}{1F9D1 200D 1F9AF}
\bxce@do{person_with_probing_cane_tone1}{1F9D1 1F3FB 200D 1F9AF}
\bxce@do{person_with_probing_cane_tone2}{1F9D1 1F3FC 200D 1F9AF}
\bxce@do{person_with_probing_cane_tone3}{1F9D1 1F3FD 200D 1F9AF}
\bxce@do{person_with_probing_cane_tone4}{1F9D1 1F3FE 200D 1F9AF}
\bxce@do{person_with_probing_cane_tone5}{1F9D1 1F3FF 200D 1F9AF}
\bxce@do{person_with_veil}{1F470}
\bxce@do{person_with_veil_tone1}{1F470 1F3FB}
\bxce@do{person_with_veil_tone2}{1F470 1F3FC}
\bxce@do{person_with_veil_tone3}{1F470 1F3FD}
\bxce@do{person_with_veil_tone4}{1F470 1F3FE}
\bxce@do{person_with_veil_tone5}{1F470 1F3FF}
\bxce@do{petri_dish}{1F9EB}
\bxce@do{pick}{26CF}
\bxce@do{pickup_truck}{1F6FB}
\bxce@do{pie}{1F967}
\bxce@do{pig}{1F437}
\bxce@do{pig2}{1F416}
\bxce@do{pig_nose}{1F43D}
\bxce@do{pill}{1F48A}
\bxce@do{pilot}{1F9D1 200D 2708}
\bxce@do{pilot_tone1}{1F9D1 1F3FB 200D 2708}
\bxce@do{pilot_tone2}{1F9D1 1F3FC 200D 2708}
\bxce@do{pilot_tone3}{1F9D1 1F3FD 200D 2708}
\bxce@do{pilot_tone4}{1F9D1 1F3FE 200D 2708}
\bxce@do{pilot_tone5}{1F9D1 1F3FF 200D 2708}
\bxce@do{pinched_fingers}{1F90C}
\bxce@do{pinched_fingers_tone1}{1F90C 1F3FB}
\bxce@do{pinched_fingers_tone2}{1F90C 1F3FC}
\bxce@do{pinched_fingers_tone3}{1F90C 1F3FD}
\bxce@do{pinched_fingers_tone4}{1F90C 1F3FE}
\bxce@do{pinched_fingers_tone5}{1F90C 1F3FF}
\bxce@do{pinching_hand}{1F90F}
\bxce@do{pinching_hand_tone1}{1F90F 1F3FB}
\bxce@do{pinching_hand_tone2}{1F90F 1F3FC}
\bxce@do{pinching_hand_tone3}{1F90F 1F3FD}
\bxce@do{pinching_hand_tone4}{1F90F 1F3FE}
\bxce@do{pinching_hand_tone5}{1F90F 1F3FF}
\bxce@do{pineapple}{1F34D}
\bxce@do{ping_pong}{1F3D3}
\bxce@do{pirate_flag}{1F3F4 200D 2620}
\bxce@do{pisces}{2653}
\bxce@do{pizza}{1F355}
\bxce@do{pinata}{1FA85}
\bxce@do{placard}{1FAA7}
\bxce@do{place_of_worship}{1F6D0}
\bxce@do{play_pause}{23EF}
\bxce@do{pleading_face}{1F97A}
\bxce@do{plunger}{1FAA0}
\bxce@do{point_down}{1F447}
\bxce@do{point_down_tone1}{1F447 1F3FB}
\bxce@do{point_down_tone2}{1F447 1F3FC}
\bxce@do{point_down_tone3}{1F447 1F3FD}
\bxce@do{point_down_tone4}{1F447 1F3FE}
\bxce@do{point_down_tone5}{1F447 1F3FF}
\bxce@do{point_left}{1F448}
\bxce@do{point_left_tone1}{1F448 1F3FB}
\bxce@do{point_left_tone2}{1F448 1F3FC}
\bxce@do{point_left_tone3}{1F448 1F3FD}
\bxce@do{point_left_tone4}{1F448 1F3FE}
\bxce@do{point_left_tone5}{1F448 1F3FF}
\bxce@do{point_right}{1F449}
\bxce@do{point_right_tone1}{1F449 1F3FB}
\bxce@do{point_right_tone2}{1F449 1F3FC}
\bxce@do{point_right_tone3}{1F449 1F3FD}
\bxce@do{point_right_tone4}{1F449 1F3FE}
\bxce@do{point_right_tone5}{1F449 1F3FF}
\bxce@do{point_up}{261D}
\bxce@do{point_up_2}{1F446}
\bxce@do{point_up_2_tone1}{1F446 1F3FB}
\bxce@do{point_up_2_tone2}{1F446 1F3FC}
\bxce@do{point_up_2_tone3}{1F446 1F3FD}
\bxce@do{point_up_2_tone4}{1F446 1F3FE}
\bxce@do{point_up_2_tone5}{1F446 1F3FF}
\bxce@do{point_up_tone1}{261D 1F3FB}
\bxce@do{point_up_tone2}{261D 1F3FC}
\bxce@do{point_up_tone3}{261D 1F3FD}
\bxce@do{point_up_tone4}{261D 1F3FE}
\bxce@do{point_up_tone5}{261D 1F3FF}
\bxce@do{polar_bear}{1F43B 200D 2744}
\bxce@do{police_car}{1F693}
\bxce@do{police_officer}{1F46E}
\bxce@do{police_officer_tone1}{1F46E 1F3FB}
\bxce@do{police_officer_tone2}{1F46E 1F3FC}
\bxce@do{police_officer_tone3}{1F46E 1F3FD}
\bxce@do{police_officer_tone4}{1F46E 1F3FE}
\bxce@do{police_officer_tone5}{1F46E 1F3FF}
\bxce@do{poodle}{1F429}
\bxce@do{poop}{1F4A9}
\bxce@do{popcorn}{1F37F}
\bxce@do{post_office}{1F3E3}
\bxce@do{postal_horn}{1F4EF}
\bxce@do{postbox}{1F4EE}
\bxce@do{potable_water}{1F6B0}
\bxce@do{potato}{1F954}
\bxce@do{potted_plant}{1FAB4}
\bxce@do{pouch}{1F45D}
\bxce@do{poultry_leg}{1F357}
\bxce@do{pound}{1F4B7}
\bxce@do{pound_symbol}{23}%NA
\bxce@do{pouting_cat}{1F63E}
\bxce@do{pray}{1F64F}
\bxce@do{pray_tone1}{1F64F 1F3FB}
\bxce@do{pray_tone2}{1F64F 1F3FC}
\bxce@do{pray_tone3}{1F64F 1F3FD}
\bxce@do{pray_tone4}{1F64F 1F3FE}
\bxce@do{pray_tone5}{1F64F 1F3FF}
\bxce@do{prayer_beads}{1F4FF}
\bxce@do{pregnant_woman}{1F930}
\bxce@do{pregnant_woman_tone1}{1F930 1F3FB}
\bxce@do{pregnant_woman_tone2}{1F930 1F3FC}
\bxce@do{pregnant_woman_tone3}{1F930 1F3FD}
\bxce@do{pregnant_woman_tone4}{1F930 1F3FE}
\bxce@do{pregnant_woman_tone5}{1F930 1F3FF}
\bxce@do{pretzel}{1F968}
\bxce@do{prince}{1F934}
\bxce@do{prince_tone1}{1F934 1F3FB}
\bxce@do{prince_tone2}{1F934 1F3FC}
\bxce@do{prince_tone3}{1F934 1F3FD}
\bxce@do{prince_tone4}{1F934 1F3FE}
\bxce@do{prince_tone5}{1F934 1F3FF}
\bxce@do{princess}{1F478}
\bxce@do{princess_tone1}{1F478 1F3FB}
\bxce@do{princess_tone2}{1F478 1F3FC}
\bxce@do{princess_tone3}{1F478 1F3FD}
\bxce@do{princess_tone4}{1F478 1F3FE}
\bxce@do{princess_tone5}{1F478 1F3FF}
\bxce@do{printer}{1F5A8}
\bxce@do{probing_cane}{1F9AF}
\bxce@do{projector}{1F4FD}
\bxce@do{punch}{1F44A}
\bxce@do{punch_tone1}{1F44A 1F3FB}
\bxce@do{punch_tone2}{1F44A 1F3FC}
\bxce@do{punch_tone3}{1F44A 1F3FD}
\bxce@do{punch_tone4}{1F44A 1F3FE}
\bxce@do{punch_tone5}{1F44A 1F3FF}
\bxce@do{purple_circle}{1F7E3}
\bxce@do{purple_heart}{1F49C}
\bxce@do{purple_square}{1F7EA}
\bxce@do{purse}{1F45B}
\bxce@do{pushpin}{1F4CC}
\bxce@do{put_litter_in_its_place}{1F6AE}
\or %[5]
\bxce@do{question}{2753}
\bxce@do{rabbit}{1F430}
\bxce@do{rabbit2}{1F407}
\bxce@do{raccoon}{1F99D}
\bxce@do{race_car}{1F3CE}
\bxce@do{racehorse}{1F40E}
\bxce@do{radio}{1F4FB}
\bxce@do{radio_button}{1F518}
\bxce@do{radioactive}{2622}
\bxce@do{rage}{1F621}
\bxce@do{railway_car}{1F683}
\bxce@do{railway_track}{1F6E4}
\bxce@do{rainbow}{1F308}
\bxce@do{rainbow_flag}{1F3F3 200D 1F308}
\bxce@do{raised_back_of_hand}{1F91A}
\bxce@do{raised_back_of_hand_tone1}{1F91A 1F3FB}
\bxce@do{raised_back_of_hand_tone2}{1F91A 1F3FC}
\bxce@do{raised_back_of_hand_tone3}{1F91A 1F3FD}
\bxce@do{raised_back_of_hand_tone4}{1F91A 1F3FE}
\bxce@do{raised_back_of_hand_tone5}{1F91A 1F3FF}
\bxce@do{raised_hand}{270B}
\bxce@do{raised_hand_tone1}{270B 1F3FB}
\bxce@do{raised_hand_tone2}{270B 1F3FC}
\bxce@do{raised_hand_tone3}{270B 1F3FD}
\bxce@do{raised_hand_tone4}{270B 1F3FE}
\bxce@do{raised_hand_tone5}{270B 1F3FF}
\bxce@do{raised_hands}{1F64C}
\bxce@do{raised_hands_tone1}{1F64C 1F3FB}
\bxce@do{raised_hands_tone2}{1F64C 1F3FC}
\bxce@do{raised_hands_tone3}{1F64C 1F3FD}
\bxce@do{raised_hands_tone4}{1F64C 1F3FE}
\bxce@do{raised_hands_tone5}{1F64C 1F3FF}
\bxce@do{ram}{1F40F}
\bxce@do{ramen}{1F35C}
\bxce@do{rat}{1F400}
\bxce@do{razor}{1FA92}
\bxce@do{receipt}{1F9FE}
\bxce@do{record_button}{23FA}
\bxce@do{recycle}{267B}
\bxce@do{red_car}{1F697}
\bxce@do{red_circle}{1F534}
\bxce@do{red_envelope}{1F9E7}
\bxce@do{red_haired}{1F9B0}
\bxce@do{red_square}{1F7E5}
\bxce@do{regional_indicator_a}{1F1E6}
\bxce@do{regional_indicator_b}{1F1E7}
\bxce@do{regional_indicator_c}{1F1E8}
\bxce@do{regional_indicator_d}{1F1E9}
\bxce@do{regional_indicator_e}{1F1EA}
\bxce@do{regional_indicator_f}{1F1EB}
\bxce@do{regional_indicator_g}{1F1EC}
\bxce@do{regional_indicator_h}{1F1ED}
\bxce@do{regional_indicator_i}{1F1EE}
\bxce@do{regional_indicator_j}{1F1EF}
\bxce@do{regional_indicator_k}{1F1F0}
\bxce@do{regional_indicator_l}{1F1F1}
\bxce@do{regional_indicator_m}{1F1F2}
\bxce@do{regional_indicator_n}{1F1F3}
\bxce@do{regional_indicator_o}{1F1F4}
\bxce@do{regional_indicator_p}{1F1F5}
\bxce@do{regional_indicator_q}{1F1F6}
\bxce@do{regional_indicator_r}{1F1F7}
\bxce@do{regional_indicator_s}{1F1F8}
\bxce@do{regional_indicator_t}{1F1F9}
\bxce@do{regional_indicator_u}{1F1FA}
\bxce@do{regional_indicator_v}{1F1FB}
\bxce@do{regional_indicator_w}{1F1FC}
\bxce@do{regional_indicator_x}{1F1FD}
\bxce@do{regional_indicator_y}{1F1FE}
\bxce@do{regional_indicator_z}{1F1FF}
\bxce@do{registered}{AE}
\bxce@do{relaxed}{263A}
\bxce@do{relieved}{1F60C}
\bxce@do{reminder_ribbon}{1F397}
\bxce@do{repeat}{1F501}
\bxce@do{repeat_one}{1F502}
\bxce@do{restroom}{1F6BB}
\bxce@do{revolving_hearts}{1F49E}
\bxce@do{rewind}{23EA}
\bxce@do{rhino}{1F98F}
\bxce@do{ribbon}{1F380}
\bxce@do{rice}{1F35A}
\bxce@do{rice_ball}{1F359}
\bxce@do{rice_cracker}{1F358}
\bxce@do{rice_scene}{1F391}
\bxce@do{right_facing_fist}{1F91C}
\bxce@do{right_facing_fist_tone1}{1F91C 1F3FB}
\bxce@do{right_facing_fist_tone2}{1F91C 1F3FC}
\bxce@do{right_facing_fist_tone3}{1F91C 1F3FD}
\bxce@do{right_facing_fist_tone4}{1F91C 1F3FE}
\bxce@do{right_facing_fist_tone5}{1F91C 1F3FF}
\bxce@do{ring}{1F48D}
\bxce@do{ringed_planet}{1FA90}
\bxce@do{robot}{1F916}
\bxce@do{rock}{1FAA8}
\bxce@do{rocket}{1F680}
\bxce@do{rofl}{1F923}
\bxce@do{roll_of_paper}{1F9FB}
\bxce@do{roller_coaster}{1F3A2}
\bxce@do{roller_skate}{1F6FC}
\bxce@do{rolling_eyes}{1F644}
\bxce@do{rooster}{1F413}
\bxce@do{rose}{1F339}
\bxce@do{rosette}{1F3F5}
\bxce@do{rotating_light}{1F6A8}
\bxce@do{round_pushpin}{1F4CD}
\bxce@do{rugby_football}{1F3C9}
\bxce@do{running_shirt_with_sash}{1F3BD}
\bxce@do{sa}{1F202}
\bxce@do{safety_pin}{1F9F7}
\bxce@do{safety_vest}{1F9BA}
\bxce@do{sagittarius}{2650}
\bxce@do{sailboat}{26F5}
\bxce@do{sake}{1F376}
\bxce@do{salad}{1F957}
\bxce@do{salt}{1F9C2}
\bxce@do{sandal}{1F461}
\bxce@do{sandwich}{1F96A}
\bxce@do{santa}{1F385}
\bxce@do{santa_tone1}{1F385 1F3FB}
\bxce@do{santa_tone2}{1F385 1F3FC}
\bxce@do{santa_tone3}{1F385 1F3FD}
\bxce@do{santa_tone4}{1F385 1F3FE}
\bxce@do{santa_tone5}{1F385 1F3FF}
\bxce@do{sari}{1F97B}
\bxce@do{satellite}{1F4E1}
\bxce@do{satellite_orbital}{1F6F0}
\bxce@do{sauropod}{1F995}
\bxce@do{saxophone}{1F3B7}
\bxce@do{scales}{2696}
\bxce@do{scarf}{1F9E3}
\bxce@do{school}{1F3EB}
\bxce@do{school_satchel}{1F392}
\bxce@do{scientist}{1F9D1 200D 1F52C}
\bxce@do{scientist_tone1}{1F9D1 1F3FB 200D 1F52C}
\bxce@do{scientist_tone2}{1F9D1 1F3FC 200D 1F52C}
\bxce@do{scientist_tone3}{1F9D1 1F3FD 200D 1F52C}
\bxce@do{scientist_tone4}{1F9D1 1F3FE 200D 1F52C}
\bxce@do{scientist_tone5}{1F9D1 1F3FF 200D 1F52C}
\bxce@do{scissors}{2702}
\bxce@do{scooter}{1F6F4}
\bxce@do{scorpion}{1F982}
\bxce@do{scorpius}{264F}
\bxce@do{scotland}{1F3F4 E0067 E0062 E0073 E0063 E0074 E007F}
\bxce@do{scream}{1F631}
\bxce@do{scream_cat}{1F640}
\bxce@do{screwdriver}{1FA9B}
\bxce@do{scroll}{1F4DC}
\bxce@do{seal}{1F9AD}
\bxce@do{seat}{1F4BA}
\bxce@do{second_place}{1F948}
\bxce@do{secret}{3299}
\bxce@do{see_no_evil}{1F648}
\bxce@do{seedling}{1F331}
\bxce@do{selfie}{1F933}
\bxce@do{selfie_tone1}{1F933 1F3FB}
\bxce@do{selfie_tone2}{1F933 1F3FC}
\bxce@do{selfie_tone3}{1F933 1F3FD}
\bxce@do{selfie_tone4}{1F933 1F3FE}
\bxce@do{selfie_tone5}{1F933 1F3FF}
\bxce@do{service_dog}{1F415 200D 1F9BA}
\bxce@do{seven}{37 20E3}
\bxce@do{sewing_needle}{1FAA1}
\bxce@do{shallow_pan_of_food}{1F958}
\bxce@do{shamrock}{2618}
\bxce@do{shark}{1F988}
\bxce@do{shaved_ice}{1F367}
\bxce@do{sheep}{1F411}
\bxce@do{shell}{1F41A}
\bxce@do{shield}{1F6E1}
\bxce@do{shinto_shrine}{26E9}
\bxce@do{ship}{1F6A2}
\bxce@do{shirt}{1F455}
\bxce@do{shopping_bags}{1F6CD}
\bxce@do{shopping_cart}{1F6D2}
\bxce@do{shorts}{1FA73}
\bxce@do{shower}{1F6BF}
\bxce@do{shrimp}{1F990}
\bxce@do{shushing_face}{1F92B}
\bxce@do{signal_strength}{1F4F6}
\bxce@do{singer}{1F9D1 200D 1F3A4}
\bxce@do{singer_tone1}{1F9D1 1F3FB 200D 1F3A4}
\bxce@do{singer_tone2}{1F9D1 1F3FC 200D 1F3A4}
\bxce@do{singer_tone3}{1F9D1 1F3FD 200D 1F3A4}
\bxce@do{singer_tone4}{1F9D1 1F3FE 200D 1F3A4}
\bxce@do{singer_tone5}{1F9D1 1F3FF 200D 1F3A4}
\bxce@do{six}{36 20E3}
\bxce@do{six_pointed_star}{1F52F}
\bxce@do{skateboard}{1F6F9}
\bxce@do{ski}{1F3BF}
\bxce@do{skier}{26F7}
\bxce@do{skull}{1F480}
\bxce@do{skull_crossbones}{2620}
\bxce@do{skunk}{1F9A8}
\bxce@do{sled}{1F6F7}
\bxce@do{sleeping}{1F634}
\bxce@do{sleeping_accommodation}{1F6CC}
\bxce@do{sleepy}{1F62A}
\bxce@do{slight_frown}{1F641}
\bxce@do{slight_smile}{1F642}
\bxce@do{slot_machine}{1F3B0}
\bxce@do{sloth}{1F9A5}
\bxce@do{small_blue_diamond}{1F539}
\bxce@do{small_orange_diamond}{1F538}
\bxce@do{small_red_triangle}{1F53A}
\bxce@do{small_red_triangle_down}{1F53B}
\bxce@do{smile}{1F604}
\bxce@do{smile_cat}{1F638}
\bxce@do{smiley}{1F603}
\bxce@do{smiley_cat}{1F63A}
\bxce@do{smiling_face_with_3_hearts}{1F970}
\bxce@do{smiling_face_with_tear}{1F972}
\bxce@do{smiling_imp}{1F608}
\bxce@do{smirk}{1F60F}
\bxce@do{smirk_cat}{1F63C}
\bxce@do{smoking}{1F6AC}
\bxce@do{snail}{1F40C}
\bxce@do{snake}{1F40D}
\bxce@do{sneezing_face}{1F927}
\bxce@do{snowboarder}{1F3C2}
\bxce@do{snowboarder_tone1}{1F3C2 1F3FB}
\bxce@do{snowboarder_tone2}{1F3C2 1F3FC}
\bxce@do{snowboarder_tone3}{1F3C2 1F3FD}
\bxce@do{snowboarder_tone4}{1F3C2 1F3FE}
\bxce@do{snowboarder_tone5}{1F3C2 1F3FF}
\bxce@do{snowflake}{2744}
\bxce@do{snowman}{26C4}
\bxce@do{snowman2}{2603}
\bxce@do{soap}{1F9FC}
\bxce@do{sob}{1F62D}
\bxce@do{soccer}{26BD}
\bxce@do{socks}{1F9E6}
\bxce@do{softball}{1F94E}
\bxce@do{soon}{1F51C}
\bxce@do{sos}{1F198}
\bxce@do{sound}{1F509}
\bxce@do{space_invader}{1F47E}
\bxce@do{spades}{2660}
\bxce@do{spaghetti}{1F35D}
\bxce@do{sparkle}{2747}
\bxce@do{sparkler}{1F387}
\bxce@do{sparkles}{2728}
\bxce@do{sparkling_heart}{1F496}
\bxce@do{speak_no_evil}{1F64A}
\bxce@do{speaker}{1F508}
\bxce@do{speaking_head}{1F5E3}
\bxce@do{speech_balloon}{1F4AC}
\bxce@do{speech_left}{1F5E8}
\bxce@do{speedboat}{1F6A4}
\bxce@do{spider}{1F577}
\bxce@do{spider_web}{1F578}
\bxce@do{sponge}{1F9FD}
\bxce@do{spoon}{1F944}
\bxce@do{squeeze_bottle}{1F9F4}
\bxce@do{squid}{1F991}
\bxce@do{stadium}{1F3DF}
\bxce@do{star}{2B50}
\bxce@do{star2}{1F31F}
\bxce@do{star_and_crescent}{262A}
\bxce@do{star_of_david}{2721}
\bxce@do{star_struck}{1F929}
\bxce@do{stars}{1F320}
\bxce@do{station}{1F689}
\bxce@do{statue_of_liberty}{1F5FD}
\bxce@do{steam_locomotive}{1F682}
\bxce@do{stethoscope}{1FA7A}
\bxce@do{stew}{1F372}
\bxce@do{stop_button}{23F9}
\bxce@do{stopwatch}{23F1}
\bxce@do{straight_ruler}{1F4CF}
\bxce@do{strawberry}{1F353}
\bxce@do{stuck_out_tongue}{1F61B}
\bxce@do{stuck_out_tongue_closed_eyes}{1F61D}
\bxce@do{stuck_out_tongue_winking_eye}{1F61C}
\bxce@do{student}{1F9D1 200D 1F393}
\bxce@do{student_tone1}{1F9D1 1F3FB 200D 1F393}
\bxce@do{student_tone2}{1F9D1 1F3FC 200D 1F393}
\bxce@do{student_tone3}{1F9D1 1F3FD 200D 1F393}
\bxce@do{student_tone4}{1F9D1 1F3FE 200D 1F393}
\bxce@do{student_tone5}{1F9D1 1F3FF 200D 1F393}
\bxce@do{stuffed_flatbread}{1F959}
\bxce@do{sun_with_face}{1F31E}
\bxce@do{sunflower}{1F33B}
\bxce@do{sunglasses}{1F60E}
\bxce@do{sunny}{2600}
\bxce@do{sunrise}{1F305}
\bxce@do{sunrise_over_mountains}{1F304}
\bxce@do{superhero}{1F9B8}
\bxce@do{superhero_tone1}{1F9B8 1F3FB}
\bxce@do{superhero_tone2}{1F9B8 1F3FC}
\bxce@do{superhero_tone3}{1F9B8 1F3FD}
\bxce@do{superhero_tone4}{1F9B8 1F3FE}
\bxce@do{superhero_tone5}{1F9B8 1F3FF}
\bxce@do{supervillain}{1F9B9}
\bxce@do{supervillain_tone1}{1F9B9 1F3FB}
\bxce@do{supervillain_tone2}{1F9B9 1F3FC}
\bxce@do{supervillain_tone3}{1F9B9 1F3FD}
\bxce@do{supervillain_tone4}{1F9B9 1F3FE}
\bxce@do{supervillain_tone5}{1F9B9 1F3FF}
\bxce@do{sushi}{1F363}
\bxce@do{suspension_railway}{1F69F}
\bxce@do{swan}{1F9A2}
\bxce@do{sweat}{1F613}
\bxce@do{sweat_drops}{1F4A6}
\bxce@do{sweat_smile}{1F605}
\bxce@do{sweet_potato}{1F360}
\bxce@do{symbols}{1F523}
\bxce@do{synagogue}{1F54D}
\bxce@do{syringe}{1F489}
\or %[6]
\bxce@do{t_rex}{1F996}
\bxce@do{taco}{1F32E}
\bxce@do{tada}{1F389}
\bxce@do{takeout_box}{1F961}
\bxce@do{tamale}{1FAD4}
\bxce@do{tanabata_tree}{1F38B}
\bxce@do{tangerine}{1F34A}
\bxce@do{taurus}{2649}
\bxce@do{taxi}{1F695}
\bxce@do{tea}{1F375}
\bxce@do{teacher}{1F9D1 200D 1F3EB}
\bxce@do{teacher_tone1}{1F9D1 1F3FB 200D 1F3EB}
\bxce@do{teacher_tone2}{1F9D1 1F3FC 200D 1F3EB}
\bxce@do{teacher_tone3}{1F9D1 1F3FD 200D 1F3EB}
\bxce@do{teacher_tone4}{1F9D1 1F3FE 200D 1F3EB}
\bxce@do{teacher_tone5}{1F9D1 1F3FF 200D 1F3EB}
\bxce@do{teapot}{1FAD6}
\bxce@do{technologist}{1F9D1 200D 1F4BB}
\bxce@do{technologist_tone1}{1F9D1 1F3FB 200D 1F4BB}
\bxce@do{technologist_tone2}{1F9D1 1F3FC 200D 1F4BB}
\bxce@do{technologist_tone3}{1F9D1 1F3FD 200D 1F4BB}
\bxce@do{technologist_tone4}{1F9D1 1F3FE 200D 1F4BB}
\bxce@do{technologist_tone5}{1F9D1 1F3FF 200D 1F4BB}
\bxce@do{teddy_bear}{1F9F8}
\bxce@do{telephone}{260E}
\bxce@do{telephone_receiver}{1F4DE}
\bxce@do{telescope}{1F52D}
\bxce@do{tennis}{1F3BE}
\bxce@do{tent}{26FA}
\bxce@do{test_tube}{1F9EA}
\bxce@do{thermometer}{1F321}
\bxce@do{thermometer_face}{1F912}
\bxce@do{thinking}{1F914}
\bxce@do{third_place}{1F949}
\bxce@do{thong_sandal}{1FA74}
\bxce@do{thought_balloon}{1F4AD}
\bxce@do{thread}{1F9F5}
\bxce@do{three}{33 20E3}
\bxce@do{thumbsdown}{1F44E}
\bxce@do{thumbsdown_tone1}{1F44E 1F3FB}
\bxce@do{thumbsdown_tone2}{1F44E 1F3FC}
\bxce@do{thumbsdown_tone3}{1F44E 1F3FD}
\bxce@do{thumbsdown_tone4}{1F44E 1F3FE}
\bxce@do{thumbsdown_tone5}{1F44E 1F3FF}
\bxce@do{thumbsup}{1F44D}
\bxce@do{thumbsup_tone1}{1F44D 1F3FB}
\bxce@do{thumbsup_tone2}{1F44D 1F3FC}
\bxce@do{thumbsup_tone3}{1F44D 1F3FD}
\bxce@do{thumbsup_tone4}{1F44D 1F3FE}
\bxce@do{thumbsup_tone5}{1F44D 1F3FF}
\bxce@do{thunder_cloud_rain}{26C8}
\bxce@do{ticket}{1F3AB}
\bxce@do{tickets}{1F39F}
\bxce@do{tiger}{1F42F}
\bxce@do{tiger2}{1F405}
\bxce@do{timer}{23F2}
\bxce@do{tired_face}{1F62B}
\bxce@do{tm}{2122}
\bxce@do{toilet}{1F6BD}
\bxce@do{tokyo_tower}{1F5FC}
\bxce@do{tomato}{1F345}
\bxce@do{tone1}{1F3FB}
\bxce@do{tone2}{1F3FC}
\bxce@do{tone3}{1F3FD}
\bxce@do{tone4}{1F3FE}
\bxce@do{tone5}{1F3FF}
\bxce@do{tongue}{1F445}
\bxce@do{toolbox}{1F9F0}
\bxce@do{tools}{1F6E0}
\bxce@do{tooth}{1F9B7}
\bxce@do{toothbrush}{1FAA5}
\bxce@do{top}{1F51D}
\bxce@do{tophat}{1F3A9}
\bxce@do{track_next}{23ED}
\bxce@do{track_previous}{23EE}
\bxce@do{trackball}{1F5B2}
\bxce@do{tractor}{1F69C}
\bxce@do{traffic_light}{1F6A5}
\bxce@do{train}{1F68B}
\bxce@do{train2}{1F686}
\bxce@do{tram}{1F68A}
\bxce@do{transgender_flag}{1F3F3 200D 26A7}
\bxce@do{transgender_symbol}{26A7}
\bxce@do{triangular_flag_on_post}{1F6A9}
\bxce@do{triangular_ruler}{1F4D0}
\bxce@do{trident}{1F531}
\bxce@do{triumph}{1F624}
\bxce@do{trolleybus}{1F68E}
\bxce@do{trophy}{1F3C6}
\bxce@do{tropical_drink}{1F379}
\bxce@do{tropical_fish}{1F420}
\bxce@do{truck}{1F69A}
\bxce@do{trumpet}{1F3BA}
\bxce@do{tulip}{1F337}
\bxce@do{tumbler_glass}{1F943}
\bxce@do{turkey}{1F983}
\bxce@do{turtle}{1F422}
\bxce@do{tv}{1F4FA}
\bxce@do{twisted_rightwards_arrows}{1F500}
\bxce@do{two}{32 20E3}
\bxce@do{two_hearts}{1F495}
\bxce@do{two_men_holding_hands}{1F46C}
\bxce@do{two_women_holding_hands}{1F46D}
\bxce@do{u5272}{1F239}
\bxce@do{u5408}{1F234}
\bxce@do{u55b6}{1F23A}
\bxce@do{u6307}{1F22F}
\bxce@do{u6708}{1F237}
\bxce@do{u6709}{1F236}
\bxce@do{u6e80}{1F235}
\bxce@do{u7121}{1F21A}
\bxce@do{u7533}{1F238}
\bxce@do{u7981}{1F232}
\bxce@do{u7a7a}{1F233}
\bxce@do{umbrella}{2614}
\bxce@do{umbrella2}{2602}
\bxce@do{unamused}{1F612}
\bxce@do{underage}{1F51E}
\bxce@do{unicorn}{1F984}
\bxce@do{united_nations}{1F1FA 1F1F3}
\bxce@do{unlock}{1F513}
\bxce@do{up}{1F199}
\bxce@do{upside_down}{1F643}
\bxce@do{urn}{26B1}
\bxce@do{v}{270C}
\bxce@do{v_tone1}{270C 1F3FB}
\bxce@do{v_tone2}{270C 1F3FC}
\bxce@do{v_tone3}{270C 1F3FD}
\bxce@do{v_tone4}{270C 1F3FE}
\bxce@do{v_tone5}{270C 1F3FF}
\bxce@do{vampire}{1F9DB}
\bxce@do{vampire_tone1}{1F9DB 1F3FB}
\bxce@do{vampire_tone2}{1F9DB 1F3FC}
\bxce@do{vampire_tone3}{1F9DB 1F3FD}
\bxce@do{vampire_tone4}{1F9DB 1F3FE}
\bxce@do{vampire_tone5}{1F9DB 1F3FF}
\bxce@do{vertical_traffic_light}{1F6A6}
\bxce@do{vhs}{1F4FC}
\bxce@do{vibration_mode}{1F4F3}
\bxce@do{video_camera}{1F4F9}
\bxce@do{video_game}{1F3AE}
\bxce@do{violin}{1F3BB}
\bxce@do{virgo}{264D}
\bxce@do{volcano}{1F30B}
\bxce@do{volleyball}{1F3D0}
\bxce@do{vs}{1F19A}
\bxce@do{vulcan}{1F596}
\bxce@do{vulcan_tone1}{1F596 1F3FB}
\bxce@do{vulcan_tone2}{1F596 1F3FC}
\bxce@do{vulcan_tone3}{1F596 1F3FD}
\bxce@do{vulcan_tone4}{1F596 1F3FE}
\bxce@do{vulcan_tone5}{1F596 1F3FF}
\bxce@do{waffle}{1F9C7}
\bxce@do{wales}{1F3F4 E0067 E0062 E0077 E006C E0073 E007F}
\bxce@do{waning_crescent_moon}{1F318}
\bxce@do{waning_gibbous_moon}{1F316}
\bxce@do{warning}{26A0}
\bxce@do{wastebasket}{1F5D1}
\bxce@do{watch}{231A}
\bxce@do{water_buffalo}{1F403}
\bxce@do{watermelon}{1F349}
\bxce@do{wave}{1F44B}
\bxce@do{wave_tone1}{1F44B 1F3FB}
\bxce@do{wave_tone2}{1F44B 1F3FC}
\bxce@do{wave_tone3}{1F44B 1F3FD}
\bxce@do{wave_tone4}{1F44B 1F3FE}
\bxce@do{wave_tone5}{1F44B 1F3FF}
\bxce@do{wavy_dash}{3030}
\bxce@do{waxing_crescent_moon}{1F312}
\bxce@do{waxing_gibbous_moon}{1F314}
\bxce@do{wc}{1F6BE}
\bxce@do{weary}{1F629}
\bxce@do{wedding}{1F492}
\bxce@do{whale}{1F433}
\bxce@do{whale2}{1F40B}
\bxce@do{wheel_of_dharma}{2638}
\bxce@do{wheelchair}{267F}
\bxce@do{white_check_mark}{2705}
\bxce@do{white_circle}{26AA}
\bxce@do{white_flower}{1F4AE}
\bxce@do{white_haired}{1F9B3}
\bxce@do{white_heart}{1F90D}
\bxce@do{white_large_square}{2B1C}
\bxce@do{white_medium_small_square}{25FD}
\bxce@do{white_medium_square}{25FB}
\bxce@do{white_small_square}{25AB}
\bxce@do{white_square_button}{1F533}
\bxce@do{white_sun_cloud}{1F325}
\bxce@do{white_sun_rain_cloud}{1F326}
\bxce@do{white_sun_small_cloud}{1F324}
\bxce@do{wilted_rose}{1F940}
\bxce@do{wind_blowing_face}{1F32C}
\bxce@do{wind_chime}{1F390}
\bxce@do{window}{1FA9F}
\bxce@do{wine_glass}{1F377}
\bxce@do{wink}{1F609}
\bxce@do{wolf}{1F43A}
\bxce@do{woman}{1F469}
\bxce@do{woman_and_man_holding_hands}{1F46B}
\bxce@do{woman_and_man_holding_hands_tone1}{1F46B 1F3FB}
\bxce@do{woman_and_man_holding_hands_tone1_tone2}{1F469 1F3FB 200D 1F91D 200D 1F468 1F3FC}
\bxce@do{woman_and_man_holding_hands_tone1_tone3}{1F469 1F3FB 200D 1F91D 200D 1F468 1F3FD}
\bxce@do{woman_and_man_holding_hands_tone1_tone4}{1F469 1F3FB 200D 1F91D 200D 1F468 1F3FE}
\bxce@do{woman_and_man_holding_hands_tone1_tone5}{1F469 1F3FB 200D 1F91D 200D 1F468 1F3FF}
\bxce@do{woman_and_man_holding_hands_tone2}{1F46B 1F3FC}
\bxce@do{woman_and_man_holding_hands_tone2_tone1}{1F469 1F3FC 200D 1F91D 200D 1F468 1F3FB}
\bxce@do{woman_and_man_holding_hands_tone2_tone3}{1F469 1F3FC 200D 1F91D 200D 1F468 1F3FD}
\bxce@do{woman_and_man_holding_hands_tone2_tone4}{1F469 1F3FC 200D 1F91D 200D 1F468 1F3FE}
\bxce@do{woman_and_man_holding_hands_tone2_tone5}{1F469 1F3FC 200D 1F91D 200D 1F468 1F3FF}
\bxce@do{woman_and_man_holding_hands_tone3}{1F46B 1F3FD}
\bxce@do{woman_and_man_holding_hands_tone3_tone1}{1F469 1F3FD 200D 1F91D 200D 1F468 1F3FB}
\bxce@do{woman_and_man_holding_hands_tone3_tone2}{1F469 1F3FD 200D 1F91D 200D 1F468 1F3FC}
\bxce@do{woman_and_man_holding_hands_tone3_tone4}{1F469 1F3FD 200D 1F91D 200D 1F468 1F3FE}
\bxce@do{woman_and_man_holding_hands_tone3_tone5}{1F469 1F3FD 200D 1F91D 200D 1F468 1F3FF}
\bxce@do{woman_and_man_holding_hands_tone4}{1F46B 1F3FE}
\bxce@do{woman_and_man_holding_hands_tone4_tone1}{1F469 1F3FE 200D 1F91D 200D 1F468 1F3FB}
\bxce@do{woman_and_man_holding_hands_tone4_tone2}{1F469 1F3FE 200D 1F91D 200D 1F468 1F3FC}
\bxce@do{woman_and_man_holding_hands_tone4_tone3}{1F469 1F3FE 200D 1F91D 200D 1F468 1F3FD}
\bxce@do{woman_and_man_holding_hands_tone4_tone5}{1F469 1F3FE 200D 1F91D 200D 1F468 1F3FF}
\bxce@do{woman_and_man_holding_hands_tone5}{1F46B 1F3FF}
\bxce@do{woman_and_man_holding_hands_tone5_tone1}{1F469 1F3FF 200D 1F91D 200D 1F468 1F3FB}
\bxce@do{woman_and_man_holding_hands_tone5_tone2}{1F469 1F3FF 200D 1F91D 200D 1F468 1F3FC}
\bxce@do{woman_and_man_holding_hands_tone5_tone3}{1F469 1F3FF 200D 1F91D 200D 1F468 1F3FD}
\bxce@do{woman_and_man_holding_hands_tone5_tone4}{1F469 1F3FF 200D 1F91D 200D 1F468 1F3FE}
\bxce@do{woman_artist}{1F469 200D 1F3A8}
\bxce@do{woman_artist_tone1}{1F469 1F3FB 200D 1F3A8}
\bxce@do{woman_artist_tone2}{1F469 1F3FC 200D 1F3A8}
\bxce@do{woman_artist_tone3}{1F469 1F3FD 200D 1F3A8}
\bxce@do{woman_artist_tone4}{1F469 1F3FE 200D 1F3A8}
\bxce@do{woman_artist_tone5}{1F469 1F3FF 200D 1F3A8}
\bxce@do{woman_astronaut}{1F469 200D 1F680}
\bxce@do{woman_astronaut_tone1}{1F469 1F3FB 200D 1F680}
\bxce@do{woman_astronaut_tone2}{1F469 1F3FC 200D 1F680}
\bxce@do{woman_astronaut_tone3}{1F469 1F3FD 200D 1F680}
\bxce@do{woman_astronaut_tone4}{1F469 1F3FE 200D 1F680}
\bxce@do{woman_astronaut_tone5}{1F469 1F3FF 200D 1F680}
\bxce@do{woman_bald}{1F469 200D 1F9B2}
\bxce@do{woman_bald_tone1}{1F469 1F3FB 200D 1F9B2}
\bxce@do{woman_bald_tone2}{1F469 1F3FC 200D 1F9B2}
\bxce@do{woman_bald_tone3}{1F469 1F3FD 200D 1F9B2}
\bxce@do{woman_bald_tone4}{1F469 1F3FE 200D 1F9B2}
\bxce@do{woman_bald_tone5}{1F469 1F3FF 200D 1F9B2}
\bxce@do{woman_beard}{1F9D4 200D 2640}
\bxce@do{woman_biking}{1F6B4 200D 2640}
\bxce@do{woman_biking_tone1}{1F6B4 1F3FB 200D 2640}
\bxce@do{woman_biking_tone2}{1F6B4 1F3FC 200D 2640}
\bxce@do{woman_biking_tone3}{1F6B4 1F3FD 200D 2640}
\bxce@do{woman_biking_tone4}{1F6B4 1F3FE 200D 2640}
\bxce@do{woman_biking_tone5}{1F6B4 1F3FF 200D 2640}
\bxce@do{woman_bouncing_ball}{26F9 200D 2640}
\bxce@do{woman_bouncing_ball_tone1}{26F9 1F3FB 200D 2640}
\bxce@do{woman_bouncing_ball_tone2}{26F9 1F3FC 200D 2640}
\bxce@do{woman_bouncing_ball_tone3}{26F9 1F3FD 200D 2640}
\bxce@do{woman_bouncing_ball_tone4}{26F9 1F3FE 200D 2640}
\bxce@do{woman_bouncing_ball_tone5}{26F9 1F3FF 200D 2640}
\bxce@do{woman_bowing}{1F647 200D 2640}
\bxce@do{woman_bowing_tone1}{1F647 1F3FB 200D 2640}
\bxce@do{woman_bowing_tone2}{1F647 1F3FC 200D 2640}
\bxce@do{woman_bowing_tone3}{1F647 1F3FD 200D 2640}
\bxce@do{woman_bowing_tone4}{1F647 1F3FE 200D 2640}
\bxce@do{woman_bowing_tone5}{1F647 1F3FF 200D 2640}
\bxce@do{woman_cartwheeling}{1F938 200D 2640}
\bxce@do{woman_cartwheeling_tone1}{1F938 1F3FB 200D 2640}
\bxce@do{woman_cartwheeling_tone2}{1F938 1F3FC 200D 2640}
\bxce@do{woman_cartwheeling_tone3}{1F938 1F3FD 200D 2640}
\bxce@do{woman_cartwheeling_tone4}{1F938 1F3FE 200D 2640}
\bxce@do{woman_cartwheeling_tone5}{1F938 1F3FF 200D 2640}
\bxce@do{woman_climbing}{1F9D7 200D 2640}
\bxce@do{woman_climbing_tone1}{1F9D7 1F3FB 200D 2640}
\bxce@do{woman_climbing_tone2}{1F9D7 1F3FC 200D 2640}
\bxce@do{woman_climbing_tone3}{1F9D7 1F3FD 200D 2640}
\bxce@do{woman_climbing_tone4}{1F9D7 1F3FE 200D 2640}
\bxce@do{woman_climbing_tone5}{1F9D7 1F3FF 200D 2640}
\bxce@do{woman_construction_worker}{1F477 200D 2640}
\bxce@do{woman_construction_worker_tone1}{1F477 1F3FB 200D 2640}
\bxce@do{woman_construction_worker_tone2}{1F477 1F3FC 200D 2640}
\bxce@do{woman_construction_worker_tone3}{1F477 1F3FD 200D 2640}
\bxce@do{woman_construction_worker_tone4}{1F477 1F3FE 200D 2640}
\bxce@do{woman_construction_worker_tone5}{1F477 1F3FF 200D 2640}
\bxce@do{woman_cook}{1F469 200D 1F373}
\bxce@do{woman_cook_tone1}{1F469 1F3FB 200D 1F373}
\bxce@do{woman_cook_tone2}{1F469 1F3FC 200D 1F373}
\bxce@do{woman_cook_tone3}{1F469 1F3FD 200D 1F373}
\bxce@do{woman_cook_tone4}{1F469 1F3FE 200D 1F373}
\bxce@do{woman_cook_tone5}{1F469 1F3FF 200D 1F373}
\bxce@do{woman_curly_haired}{1F469 200D 1F9B1}
\bxce@do{woman_curly_haired_tone1}{1F469 1F3FB 200D 1F9B1}
\bxce@do{woman_curly_haired_tone2}{1F469 1F3FC 200D 1F9B1}
\bxce@do{woman_curly_haired_tone3}{1F469 1F3FD 200D 1F9B1}
\bxce@do{woman_curly_haired_tone4}{1F469 1F3FE 200D 1F9B1}
\bxce@do{woman_curly_haired_tone5}{1F469 1F3FF 200D 1F9B1}
\bxce@do{woman_detective}{1F575 200D 2640}
\bxce@do{woman_detective_tone1}{1F575 1F3FB 200D 2640}
\bxce@do{woman_detective_tone2}{1F575 1F3FC 200D 2640}
\bxce@do{woman_detective_tone3}{1F575 1F3FD 200D 2640}
\bxce@do{woman_detective_tone4}{1F575 1F3FE 200D 2640}
\bxce@do{woman_detective_tone5}{1F575 1F3FF 200D 2640}
\bxce@do{woman_elf}{1F9DD 200D 2640}
\bxce@do{woman_elf_tone1}{1F9DD 1F3FB 200D 2640}
\bxce@do{woman_elf_tone2}{1F9DD 1F3FC 200D 2640}
\bxce@do{woman_elf_tone3}{1F9DD 1F3FD 200D 2640}
\bxce@do{woman_elf_tone4}{1F9DD 1F3FE 200D 2640}
\bxce@do{woman_elf_tone5}{1F9DD 1F3FF 200D 2640}
\bxce@do{woman_facepalming}{1F926 200D 2640}
\bxce@do{woman_facepalming_tone1}{1F926 1F3FB 200D 2640}
\bxce@do{woman_facepalming_tone2}{1F926 1F3FC 200D 2640}
\bxce@do{woman_facepalming_tone3}{1F926 1F3FD 200D 2640}
\bxce@do{woman_facepalming_tone4}{1F926 1F3FE 200D 2640}
\bxce@do{woman_facepalming_tone5}{1F926 1F3FF 200D 2640}
\bxce@do{woman_factory_worker}{1F469 200D 1F3ED}
\bxce@do{woman_factory_worker_tone1}{1F469 1F3FB 200D 1F3ED}
\bxce@do{woman_factory_worker_tone2}{1F469 1F3FC 200D 1F3ED}
\bxce@do{woman_factory_worker_tone3}{1F469 1F3FD 200D 1F3ED}
\bxce@do{woman_factory_worker_tone4}{1F469 1F3FE 200D 1F3ED}
\bxce@do{woman_factory_worker_tone5}{1F469 1F3FF 200D 1F3ED}
\bxce@do{woman_fairy}{1F9DA 200D 2640}
\bxce@do{woman_fairy_tone1}{1F9DA 1F3FB 200D 2640}
\bxce@do{woman_fairy_tone2}{1F9DA 1F3FC 200D 2640}
\bxce@do{woman_fairy_tone3}{1F9DA 1F3FD 200D 2640}
\bxce@do{woman_fairy_tone4}{1F9DA 1F3FE 200D 2640}
\bxce@do{woman_fairy_tone5}{1F9DA 1F3FF 200D 2640}
\bxce@do{woman_farmer}{1F469 200D 1F33E}
\bxce@do{woman_farmer_tone1}{1F469 1F3FB 200D 1F33E}
\bxce@do{woman_farmer_tone2}{1F469 1F3FC 200D 1F33E}
\bxce@do{woman_farmer_tone3}{1F469 1F3FD 200D 1F33E}
\bxce@do{woman_farmer_tone4}{1F469 1F3FE 200D 1F33E}
\bxce@do{woman_farmer_tone5}{1F469 1F3FF 200D 1F33E}
\bxce@do{woman_feeding_baby}{1F469 200D 1F37C}
\bxce@do{woman_feeding_baby_tone1}{1F469 1F3FB 200D 1F37C}
\bxce@do{woman_feeding_baby_tone2}{1F469 1F3FC 200D 1F37C}
\bxce@do{woman_feeding_baby_tone3}{1F469 1F3FD 200D 1F37C}
\bxce@do{woman_feeding_baby_tone4}{1F469 1F3FE 200D 1F37C}
\bxce@do{woman_feeding_baby_tone5}{1F469 1F3FF 200D 1F37C}
\bxce@do{woman_firefighter}{1F469 200D 1F692}
\bxce@do{woman_firefighter_tone1}{1F469 1F3FB 200D 1F692}
\bxce@do{woman_firefighter_tone2}{1F469 1F3FC 200D 1F692}
\bxce@do{woman_firefighter_tone3}{1F469 1F3FD 200D 1F692}
\bxce@do{woman_firefighter_tone4}{1F469 1F3FE 200D 1F692}
\bxce@do{woman_firefighter_tone5}{1F469 1F3FF 200D 1F692}
\bxce@do{woman_frowning}{1F64D 200D 2640}
\bxce@do{woman_frowning_tone1}{1F64D 1F3FB 200D 2640}
\bxce@do{woman_frowning_tone2}{1F64D 1F3FC 200D 2640}
\bxce@do{woman_frowning_tone3}{1F64D 1F3FD 200D 2640}
\bxce@do{woman_frowning_tone4}{1F64D 1F3FE 200D 2640}
\bxce@do{woman_frowning_tone5}{1F64D 1F3FF 200D 2640}
\bxce@do{woman_genie}{1F9DE 200D 2640}
\bxce@do{woman_gesturing_no}{1F645 200D 2640}
\bxce@do{woman_gesturing_no_tone1}{1F645 1F3FB 200D 2640}
\bxce@do{woman_gesturing_no_tone2}{1F645 1F3FC 200D 2640}
\bxce@do{woman_gesturing_no_tone3}{1F645 1F3FD 200D 2640}
\bxce@do{woman_gesturing_no_tone4}{1F645 1F3FE 200D 2640}
\bxce@do{woman_gesturing_no_tone5}{1F645 1F3FF 200D 2640}
\bxce@do{woman_gesturing_ok}{1F646 200D 2640}
\bxce@do{woman_gesturing_ok_tone1}{1F646 1F3FB 200D 2640}
\bxce@do{woman_gesturing_ok_tone2}{1F646 1F3FC 200D 2640}
\bxce@do{woman_gesturing_ok_tone3}{1F646 1F3FD 200D 2640}
\bxce@do{woman_gesturing_ok_tone4}{1F646 1F3FE 200D 2640}
\bxce@do{woman_gesturing_ok_tone5}{1F646 1F3FF 200D 2640}
\bxce@do{woman_getting_face_massage}{1F486 200D 2640}
\bxce@do{woman_getting_face_massage_tone1}{1F486 1F3FB 200D 2640}
\bxce@do{woman_getting_face_massage_tone2}{1F486 1F3FC 200D 2640}
\bxce@do{woman_getting_face_massage_tone3}{1F486 1F3FD 200D 2640}
\bxce@do{woman_getting_face_massage_tone4}{1F486 1F3FE 200D 2640}
\bxce@do{woman_getting_face_massage_tone5}{1F486 1F3FF 200D 2640}
\bxce@do{woman_getting_haircut}{1F487 200D 2640}
\bxce@do{woman_getting_haircut_tone1}{1F487 1F3FB 200D 2640}
\bxce@do{woman_getting_haircut_tone2}{1F487 1F3FC 200D 2640}
\bxce@do{woman_getting_haircut_tone3}{1F487 1F3FD 200D 2640}
\bxce@do{woman_getting_haircut_tone4}{1F487 1F3FE 200D 2640}
\bxce@do{woman_getting_haircut_tone5}{1F487 1F3FF 200D 2640}
\bxce@do{woman_golfing}{1F3CC 200D 2640}
\bxce@do{woman_golfing_tone1}{1F3CC 1F3FB 200D 2640}
\bxce@do{woman_golfing_tone2}{1F3CC 1F3FC 200D 2640}
\bxce@do{woman_golfing_tone3}{1F3CC 1F3FD 200D 2640}
\bxce@do{woman_golfing_tone4}{1F3CC 1F3FE 200D 2640}
\bxce@do{woman_golfing_tone5}{1F3CC 1F3FF 200D 2640}
\bxce@do{woman_guard}{1F482 200D 2640}
\bxce@do{woman_guard_tone1}{1F482 1F3FB 200D 2640}
\bxce@do{woman_guard_tone2}{1F482 1F3FC 200D 2640}
\bxce@do{woman_guard_tone3}{1F482 1F3FD 200D 2640}
\bxce@do{woman_guard_tone4}{1F482 1F3FE 200D 2640}
\bxce@do{woman_guard_tone5}{1F482 1F3FF 200D 2640}
\bxce@do{woman_health_worker}{1F469 200D 2695}
\bxce@do{woman_health_worker_tone1}{1F469 1F3FB 200D 2695}
\bxce@do{woman_health_worker_tone2}{1F469 1F3FC 200D 2695}
\bxce@do{woman_health_worker_tone3}{1F469 1F3FD 200D 2695}
\bxce@do{woman_health_worker_tone4}{1F469 1F3FE 200D 2695}
\bxce@do{woman_health_worker_tone5}{1F469 1F3FF 200D 2695}
\bxce@do{woman_in_lotus_position}{1F9D8 200D 2640}
\bxce@do{woman_in_lotus_position_tone1}{1F9D8 1F3FB 200D 2640}
\bxce@do{woman_in_lotus_position_tone2}{1F9D8 1F3FC 200D 2640}
\bxce@do{woman_in_lotus_position_tone3}{1F9D8 1F3FD 200D 2640}
\bxce@do{woman_in_lotus_position_tone4}{1F9D8 1F3FE 200D 2640}
\bxce@do{woman_in_lotus_position_tone5}{1F9D8 1F3FF 200D 2640}
\bxce@do{woman_in_manual_wheelchair}{1F469 200D 1F9BD}
\bxce@do{woman_in_manual_wheelchair_tone1}{1F469 1F3FB 200D 1F9BD}
\bxce@do{woman_in_manual_wheelchair_tone2}{1F469 1F3FC 200D 1F9BD}
\bxce@do{woman_in_manual_wheelchair_tone3}{1F469 1F3FD 200D 1F9BD}
\bxce@do{woman_in_manual_wheelchair_tone4}{1F469 1F3FE 200D 1F9BD}
\bxce@do{woman_in_manual_wheelchair_tone5}{1F469 1F3FF 200D 1F9BD}
\bxce@do{woman_in_motorized_wheelchair}{1F469 200D 1F9BC}
\bxce@do{woman_in_motorized_wheelchair_tone1}{1F469 1F3FB 200D 1F9BC}
\bxce@do{woman_in_motorized_wheelchair_tone2}{1F469 1F3FC 200D 1F9BC}
\bxce@do{woman_in_motorized_wheelchair_tone3}{1F469 1F3FD 200D 1F9BC}
\bxce@do{woman_in_motorized_wheelchair_tone4}{1F469 1F3FE 200D 1F9BC}
\bxce@do{woman_in_motorized_wheelchair_tone5}{1F469 1F3FF 200D 1F9BC}
\bxce@do{woman_in_steamy_room}{1F9D6 200D 2640}
\bxce@do{woman_in_steamy_room_tone1}{1F9D6 1F3FB 200D 2640}
\bxce@do{woman_in_steamy_room_tone2}{1F9D6 1F3FC 200D 2640}
\bxce@do{woman_in_steamy_room_tone3}{1F9D6 1F3FD 200D 2640}
\bxce@do{woman_in_steamy_room_tone4}{1F9D6 1F3FE 200D 2640}
\bxce@do{woman_in_steamy_room_tone5}{1F9D6 1F3FF 200D 2640}
\bxce@do{woman_in_tuxedo}{1F935 200D 2640}
\bxce@do{woman_in_tuxedo_tone1}{1F935 1F3FB 200D 2640}
\bxce@do{woman_in_tuxedo_tone2}{1F935 1F3FC 200D 2640}
\bxce@do{woman_in_tuxedo_tone3}{1F935 1F3FD 200D 2640}
\bxce@do{woman_in_tuxedo_tone4}{1F935 1F3FE 200D 2640}
\bxce@do{woman_in_tuxedo_tone5}{1F935 1F3FF 200D 2640}
\bxce@do{woman_judge}{1F469 200D 2696}
\bxce@do{woman_judge_tone1}{1F469 1F3FB 200D 2696}
\bxce@do{woman_judge_tone2}{1F469 1F3FC 200D 2696}
\bxce@do{woman_judge_tone3}{1F469 1F3FD 200D 2696}
\bxce@do{woman_judge_tone4}{1F469 1F3FE 200D 2696}
\bxce@do{woman_judge_tone5}{1F469 1F3FF 200D 2696}
\bxce@do{woman_juggling}{1F939 200D 2640}
\bxce@do{woman_juggling_tone1}{1F939 1F3FB 200D 2640}
\bxce@do{woman_juggling_tone2}{1F939 1F3FC 200D 2640}
\bxce@do{woman_juggling_tone3}{1F939 1F3FD 200D 2640}
\bxce@do{woman_juggling_tone4}{1F939 1F3FE 200D 2640}
\bxce@do{woman_juggling_tone5}{1F939 1F3FF 200D 2640}
\bxce@do{woman_kneeling}{1F9CE 200D 2640}
\bxce@do{woman_kneeling_tone1}{1F9CE 1F3FB 200D 2640}
\bxce@do{woman_kneeling_tone2}{1F9CE 1F3FC 200D 2640}
\bxce@do{woman_kneeling_tone3}{1F9CE 1F3FD 200D 2640}
\bxce@do{woman_kneeling_tone4}{1F9CE 1F3FE 200D 2640}
\bxce@do{woman_kneeling_tone5}{1F9CE 1F3FF 200D 2640}
\bxce@do{woman_lifting_weights}{1F3CB 200D 2640}
\bxce@do{woman_lifting_weights_tone1}{1F3CB 1F3FB 200D 2640}
\bxce@do{woman_lifting_weights_tone2}{1F3CB 1F3FC 200D 2640}
\bxce@do{woman_lifting_weights_tone3}{1F3CB 1F3FD 200D 2640}
\bxce@do{woman_lifting_weights_tone4}{1F3CB 1F3FE 200D 2640}
\bxce@do{woman_lifting_weights_tone5}{1F3CB 1F3FF 200D 2640}
\bxce@do{woman_mage}{1F9D9 200D 2640}
\bxce@do{woman_mage_tone1}{1F9D9 1F3FB 200D 2640}
\bxce@do{woman_mage_tone2}{1F9D9 1F3FC 200D 2640}
\bxce@do{woman_mage_tone3}{1F9D9 1F3FD 200D 2640}
\bxce@do{woman_mage_tone4}{1F9D9 1F3FE 200D 2640}
\bxce@do{woman_mage_tone5}{1F9D9 1F3FF 200D 2640}
\bxce@do{woman_mechanic}{1F469 200D 1F527}
\bxce@do{woman_mechanic_tone1}{1F469 1F3FB 200D 1F527}
\bxce@do{woman_mechanic_tone2}{1F469 1F3FC 200D 1F527}
\bxce@do{woman_mechanic_tone3}{1F469 1F3FD 200D 1F527}
\bxce@do{woman_mechanic_tone4}{1F469 1F3FE 200D 1F527}
\bxce@do{woman_mechanic_tone5}{1F469 1F3FF 200D 1F527}
\bxce@do{woman_mountain_biking}{1F6B5 200D 2640}
\bxce@do{woman_mountain_biking_tone1}{1F6B5 1F3FB 200D 2640}
\bxce@do{woman_mountain_biking_tone2}{1F6B5 1F3FC 200D 2640}
\bxce@do{woman_mountain_biking_tone3}{1F6B5 1F3FD 200D 2640}
\bxce@do{woman_mountain_biking_tone4}{1F6B5 1F3FE 200D 2640}
\bxce@do{woman_mountain_biking_tone5}{1F6B5 1F3FF 200D 2640}
\bxce@do{woman_office_worker}{1F469 200D 1F4BC}
\bxce@do{woman_office_worker_tone1}{1F469 1F3FB 200D 1F4BC}
\bxce@do{woman_office_worker_tone2}{1F469 1F3FC 200D 1F4BC}
\bxce@do{woman_office_worker_tone3}{1F469 1F3FD 200D 1F4BC}
\bxce@do{woman_office_worker_tone4}{1F469 1F3FE 200D 1F4BC}
\bxce@do{woman_office_worker_tone5}{1F469 1F3FF 200D 1F4BC}
\bxce@do{woman_pilot}{1F469 200D 2708}
\bxce@do{woman_pilot_tone1}{1F469 1F3FB 200D 2708}
\bxce@do{woman_pilot_tone2}{1F469 1F3FC 200D 2708}
\bxce@do{woman_pilot_tone3}{1F469 1F3FD 200D 2708}
\bxce@do{woman_pilot_tone4}{1F469 1F3FE 200D 2708}
\bxce@do{woman_pilot_tone5}{1F469 1F3FF 200D 2708}
\bxce@do{woman_playing_handball}{1F93E 200D 2640}
\bxce@do{woman_playing_handball_tone1}{1F93E 1F3FB 200D 2640}
\bxce@do{woman_playing_handball_tone2}{1F93E 1F3FC 200D 2640}
\bxce@do{woman_playing_handball_tone3}{1F93E 1F3FD 200D 2640}
\bxce@do{woman_playing_handball_tone4}{1F93E 1F3FE 200D 2640}
\bxce@do{woman_playing_handball_tone5}{1F93E 1F3FF 200D 2640}
\bxce@do{woman_playing_water_polo}{1F93D 200D 2640}
\bxce@do{woman_playing_water_polo_tone1}{1F93D 1F3FB 200D 2640}
\bxce@do{woman_playing_water_polo_tone2}{1F93D 1F3FC 200D 2640}
\bxce@do{woman_playing_water_polo_tone3}{1F93D 1F3FD 200D 2640}
\bxce@do{woman_playing_water_polo_tone4}{1F93D 1F3FE 200D 2640}
\bxce@do{woman_playing_water_polo_tone5}{1F93D 1F3FF 200D 2640}
\bxce@do{woman_police_officer}{1F46E 200D 2640}
\bxce@do{woman_police_officer_tone1}{1F46E 1F3FB 200D 2640}
\bxce@do{woman_police_officer_tone2}{1F46E 1F3FC 200D 2640}
\bxce@do{woman_police_officer_tone3}{1F46E 1F3FD 200D 2640}
\bxce@do{woman_police_officer_tone4}{1F46E 1F3FE 200D 2640}
\bxce@do{woman_police_officer_tone5}{1F46E 1F3FF 200D 2640}
\bxce@do{woman_pouting}{1F64E 200D 2640}
\bxce@do{woman_pouting_tone1}{1F64E 1F3FB 200D 2640}
\bxce@do{woman_pouting_tone2}{1F64E 1F3FC 200D 2640}
\bxce@do{woman_pouting_tone3}{1F64E 1F3FD 200D 2640}
\bxce@do{woman_pouting_tone4}{1F64E 1F3FE 200D 2640}
\bxce@do{woman_pouting_tone5}{1F64E 1F3FF 200D 2640}
\bxce@do{woman_raising_hand}{1F64B 200D 2640}
\bxce@do{woman_raising_hand_tone1}{1F64B 1F3FB 200D 2640}
\bxce@do{woman_raising_hand_tone2}{1F64B 1F3FC 200D 2640}
\bxce@do{woman_raising_hand_tone3}{1F64B 1F3FD 200D 2640}
\bxce@do{woman_raising_hand_tone4}{1F64B 1F3FE 200D 2640}
\bxce@do{woman_raising_hand_tone5}{1F64B 1F3FF 200D 2640}
\bxce@do{woman_red_haired}{1F469 200D 1F9B0}
\bxce@do{woman_red_haired_tone1}{1F469 1F3FB 200D 1F9B0}
\bxce@do{woman_red_haired_tone2}{1F469 1F3FC 200D 1F9B0}
\bxce@do{woman_red_haired_tone3}{1F469 1F3FD 200D 1F9B0}
\bxce@do{woman_red_haired_tone4}{1F469 1F3FE 200D 1F9B0}
\bxce@do{woman_red_haired_tone5}{1F469 1F3FF 200D 1F9B0}
\bxce@do{woman_rowing_boat}{1F6A3 200D 2640}
\bxce@do{woman_rowing_boat_tone1}{1F6A3 1F3FB 200D 2640}
\bxce@do{woman_rowing_boat_tone2}{1F6A3 1F3FC 200D 2640}
\bxce@do{woman_rowing_boat_tone3}{1F6A3 1F3FD 200D 2640}
\bxce@do{woman_rowing_boat_tone4}{1F6A3 1F3FE 200D 2640}
\bxce@do{woman_rowing_boat_tone5}{1F6A3 1F3FF 200D 2640}
\bxce@do{woman_running}{1F3C3 200D 2640}
\bxce@do{woman_running_tone1}{1F3C3 1F3FB 200D 2640}
\bxce@do{woman_running_tone2}{1F3C3 1F3FC 200D 2640}
\bxce@do{woman_running_tone3}{1F3C3 1F3FD 200D 2640}
\bxce@do{woman_running_tone4}{1F3C3 1F3FE 200D 2640}
\bxce@do{woman_running_tone5}{1F3C3 1F3FF 200D 2640}
\bxce@do{woman_scientist}{1F469 200D 1F52C}
\bxce@do{woman_scientist_tone1}{1F469 1F3FB 200D 1F52C}
\bxce@do{woman_scientist_tone2}{1F469 1F3FC 200D 1F52C}
\bxce@do{woman_scientist_tone3}{1F469 1F3FD 200D 1F52C}
\bxce@do{woman_scientist_tone4}{1F469 1F3FE 200D 1F52C}
\bxce@do{woman_scientist_tone5}{1F469 1F3FF 200D 1F52C}
\bxce@do{woman_shrugging}{1F937 200D 2640}
\bxce@do{woman_shrugging_tone1}{1F937 1F3FB 200D 2640}
\bxce@do{woman_shrugging_tone2}{1F937 1F3FC 200D 2640}
\bxce@do{woman_shrugging_tone3}{1F937 1F3FD 200D 2640}
\bxce@do{woman_shrugging_tone4}{1F937 1F3FE 200D 2640}
\bxce@do{woman_shrugging_tone5}{1F937 1F3FF 200D 2640}
\bxce@do{woman_singer}{1F469 200D 1F3A4}
\bxce@do{woman_singer_tone1}{1F469 1F3FB 200D 1F3A4}
\bxce@do{woman_singer_tone2}{1F469 1F3FC 200D 1F3A4}
\bxce@do{woman_singer_tone3}{1F469 1F3FD 200D 1F3A4}
\bxce@do{woman_singer_tone4}{1F469 1F3FE 200D 1F3A4}
\bxce@do{woman_singer_tone5}{1F469 1F3FF 200D 1F3A4}
\bxce@do{woman_standing}{1F9CD 200D 2640}
\bxce@do{woman_standing_tone1}{1F9CD 1F3FB 200D 2640}
\bxce@do{woman_standing_tone2}{1F9CD 1F3FC 200D 2640}
\bxce@do{woman_standing_tone3}{1F9CD 1F3FD 200D 2640}
\bxce@do{woman_standing_tone4}{1F9CD 1F3FE 200D 2640}
\bxce@do{woman_standing_tone5}{1F9CD 1F3FF 200D 2640}
\bxce@do{woman_student}{1F469 200D 1F393}
\bxce@do{woman_student_tone1}{1F469 1F3FB 200D 1F393}
\bxce@do{woman_student_tone2}{1F469 1F3FC 200D 1F393}
\bxce@do{woman_student_tone3}{1F469 1F3FD 200D 1F393}
\bxce@do{woman_student_tone4}{1F469 1F3FE 200D 1F393}
\bxce@do{woman_student_tone5}{1F469 1F3FF 200D 1F393}
\bxce@do{woman_superhero}{1F9B8 200D 2640}
\bxce@do{woman_superhero_tone1}{1F9B8 1F3FB 200D 2640}
\bxce@do{woman_superhero_tone2}{1F9B8 1F3FC 200D 2640}
\bxce@do{woman_superhero_tone3}{1F9B8 1F3FD 200D 2640}
\bxce@do{woman_superhero_tone4}{1F9B8 1F3FE 200D 2640}
\bxce@do{woman_superhero_tone5}{1F9B8 1F3FF 200D 2640}
\bxce@do{woman_supervillain}{1F9B9 200D 2640}
\bxce@do{woman_supervillain_tone1}{1F9B9 1F3FB 200D 2640}
\bxce@do{woman_supervillain_tone2}{1F9B9 1F3FC 200D 2640}
\bxce@do{woman_supervillain_tone3}{1F9B9 1F3FD 200D 2640}
\bxce@do{woman_supervillain_tone4}{1F9B9 1F3FE 200D 2640}
\bxce@do{woman_supervillain_tone5}{1F9B9 1F3FF 200D 2640}
\bxce@do{woman_surfing}{1F3C4 200D 2640}
\bxce@do{woman_surfing_tone1}{1F3C4 1F3FB 200D 2640}
\bxce@do{woman_surfing_tone2}{1F3C4 1F3FC 200D 2640}
\bxce@do{woman_surfing_tone3}{1F3C4 1F3FD 200D 2640}
\bxce@do{woman_surfing_tone4}{1F3C4 1F3FE 200D 2640}
\bxce@do{woman_surfing_tone5}{1F3C4 1F3FF 200D 2640}
\bxce@do{woman_swimming}{1F3CA 200D 2640}
\bxce@do{woman_swimming_tone1}{1F3CA 1F3FB 200D 2640}
\bxce@do{woman_swimming_tone2}{1F3CA 1F3FC 200D 2640}
\bxce@do{woman_swimming_tone3}{1F3CA 1F3FD 200D 2640}
\bxce@do{woman_swimming_tone4}{1F3CA 1F3FE 200D 2640}
\bxce@do{woman_swimming_tone5}{1F3CA 1F3FF 200D 2640}
\bxce@do{woman_teacher}{1F469 200D 1F3EB}
\bxce@do{woman_teacher_tone1}{1F469 1F3FB 200D 1F3EB}
\bxce@do{woman_teacher_tone2}{1F469 1F3FC 200D 1F3EB}
\bxce@do{woman_teacher_tone3}{1F469 1F3FD 200D 1F3EB}
\bxce@do{woman_teacher_tone4}{1F469 1F3FE 200D 1F3EB}
\bxce@do{woman_teacher_tone5}{1F469 1F3FF 200D 1F3EB}
\bxce@do{woman_technologist}{1F469 200D 1F4BB}
\bxce@do{woman_technologist_tone1}{1F469 1F3FB 200D 1F4BB}
\bxce@do{woman_technologist_tone2}{1F469 1F3FC 200D 1F4BB}
\bxce@do{woman_technologist_tone3}{1F469 1F3FD 200D 1F4BB}
\bxce@do{woman_technologist_tone4}{1F469 1F3FE 200D 1F4BB}
\bxce@do{woman_technologist_tone5}{1F469 1F3FF 200D 1F4BB}
\bxce@do{woman_tipping_hand}{1F481 200D 2640}
\bxce@do{woman_tipping_hand_tone1}{1F481 1F3FB 200D 2640}
\bxce@do{woman_tipping_hand_tone2}{1F481 1F3FC 200D 2640}
\bxce@do{woman_tipping_hand_tone3}{1F481 1F3FD 200D 2640}
\bxce@do{woman_tipping_hand_tone4}{1F481 1F3FE 200D 2640}
\bxce@do{woman_tipping_hand_tone5}{1F481 1F3FF 200D 2640}
\bxce@do{woman_tone1}{1F469 1F3FB}
\bxce@do{woman_tone1_beard}{1F9D4 1F3FB 200D 2640}
\bxce@do{woman_tone2}{1F469 1F3FC}
\bxce@do{woman_tone2_beard}{1F9D4 1F3FC 200D 2640}
\bxce@do{woman_tone3}{1F469 1F3FD}
\bxce@do{woman_tone3_beard}{1F9D4 1F3FD 200D 2640}
\bxce@do{woman_tone4}{1F469 1F3FE}
\bxce@do{woman_tone4_beard}{1F9D4 1F3FE 200D 2640}
\bxce@do{woman_tone5}{1F469 1F3FF}
\bxce@do{woman_tone5_beard}{1F9D4 1F3FF 200D 2640}
\bxce@do{woman_vampire}{1F9DB 200D 2640}
\bxce@do{woman_vampire_tone1}{1F9DB 1F3FB 200D 2640}
\bxce@do{woman_vampire_tone2}{1F9DB 1F3FC 200D 2640}
\bxce@do{woman_vampire_tone3}{1F9DB 1F3FD 200D 2640}
\bxce@do{woman_vampire_tone4}{1F9DB 1F3FE 200D 2640}
\bxce@do{woman_vampire_tone5}{1F9DB 1F3FF 200D 2640}
\bxce@do{woman_walking}{1F6B6 200D 2640}
\bxce@do{woman_walking_tone1}{1F6B6 1F3FB 200D 2640}
\bxce@do{woman_walking_tone2}{1F6B6 1F3FC 200D 2640}
\bxce@do{woman_walking_tone3}{1F6B6 1F3FD 200D 2640}
\bxce@do{woman_walking_tone4}{1F6B6 1F3FE 200D 2640}
\bxce@do{woman_walking_tone5}{1F6B6 1F3FF 200D 2640}
\bxce@do{woman_wearing_turban}{1F473 200D 2640}
\bxce@do{woman_wearing_turban_tone1}{1F473 1F3FB 200D 2640}
\bxce@do{woman_wearing_turban_tone2}{1F473 1F3FC 200D 2640}
\bxce@do{woman_wearing_turban_tone3}{1F473 1F3FD 200D 2640}
\bxce@do{woman_wearing_turban_tone4}{1F473 1F3FE 200D 2640}
\bxce@do{woman_wearing_turban_tone5}{1F473 1F3FF 200D 2640}
\bxce@do{woman_white_haired}{1F469 200D 1F9B3}
\bxce@do{woman_white_haired_tone1}{1F469 1F3FB 200D 1F9B3}
\bxce@do{woman_white_haired_tone2}{1F469 1F3FC 200D 1F9B3}
\bxce@do{woman_white_haired_tone3}{1F469 1F3FD 200D 1F9B3}
\bxce@do{woman_white_haired_tone4}{1F469 1F3FE 200D 1F9B3}
\bxce@do{woman_white_haired_tone5}{1F469 1F3FF 200D 1F9B3}
\bxce@do{woman_with_headscarf}{1F9D5}
\bxce@do{woman_with_headscarf_tone1}{1F9D5 1F3FB}
\bxce@do{woman_with_headscarf_tone2}{1F9D5 1F3FC}
\bxce@do{woman_with_headscarf_tone3}{1F9D5 1F3FD}
\bxce@do{woman_with_headscarf_tone4}{1F9D5 1F3FE}
\bxce@do{woman_with_headscarf_tone5}{1F9D5 1F3FF}
\bxce@do{woman_with_probing_cane}{1F469 200D 1F9AF}
\bxce@do{woman_with_probing_cane_tone1}{1F469 1F3FB 200D 1F9AF}
\bxce@do{woman_with_probing_cane_tone2}{1F469 1F3FC 200D 1F9AF}
\bxce@do{woman_with_probing_cane_tone3}{1F469 1F3FD 200D 1F9AF}
\bxce@do{woman_with_probing_cane_tone4}{1F469 1F3FE 200D 1F9AF}
\bxce@do{woman_with_probing_cane_tone5}{1F469 1F3FF 200D 1F9AF}
\bxce@do{woman_with_veil}{1F470 200D 2640}
\bxce@do{woman_with_veil_tone1}{1F470 1F3FB 200D 2640}
\bxce@do{woman_with_veil_tone2}{1F470 1F3FC 200D 2640}
\bxce@do{woman_with_veil_tone3}{1F470 1F3FD 200D 2640}
\bxce@do{woman_with_veil_tone4}{1F470 1F3FE 200D 2640}
\bxce@do{woman_with_veil_tone5}{1F470 1F3FF 200D 2640}
\bxce@do{woman_zombie}{1F9DF 200D 2640}
\bxce@do{womans_clothes}{1F45A}
\bxce@do{womans_flat_shoe}{1F97F}
\bxce@do{womans_hat}{1F452}
\bxce@do{women_holding_hands}{1F46D}
\bxce@do{women_holding_hands_tone1}{1F46D 1F3FB}
\bxce@do{women_holding_hands_tone1_tone2}{1F469 1F3FB 200D 1F91D 200D 1F469 1F3FC}
\bxce@do{women_holding_hands_tone1_tone3}{1F469 1F3FB 200D 1F91D 200D 1F469 1F3FD}
\bxce@do{women_holding_hands_tone1_tone4}{1F469 1F3FB 200D 1F91D 200D 1F469 1F3FE}
\bxce@do{women_holding_hands_tone1_tone5}{1F469 1F3FB 200D 1F91D 200D 1F469 1F3FF}
\bxce@do{women_holding_hands_tone2}{1F46D 1F3FC}
\bxce@do{women_holding_hands_tone2_tone1}{1F469 1F3FC 200D 1F91D 200D 1F469 1F3FB}
\bxce@do{women_holding_hands_tone2_tone3}{1F469 1F3FC 200D 1F91D 200D 1F469 1F3FD}
\bxce@do{women_holding_hands_tone2_tone4}{1F469 1F3FC 200D 1F91D 200D 1F469 1F3FE}
\bxce@do{women_holding_hands_tone2_tone5}{1F469 1F3FC 200D 1F91D 200D 1F469 1F3FF}
\bxce@do{women_holding_hands_tone3}{1F46D 1F3FD}
\bxce@do{women_holding_hands_tone3_tone1}{1F469 1F3FD 200D 1F91D 200D 1F469 1F3FB}
\bxce@do{women_holding_hands_tone3_tone2}{1F469 1F3FD 200D 1F91D 200D 1F469 1F3FC}
\bxce@do{women_holding_hands_tone3_tone4}{1F469 1F3FD 200D 1F91D 200D 1F469 1F3FE}
\bxce@do{women_holding_hands_tone3_tone5}{1F469 1F3FD 200D 1F91D 200D 1F469 1F3FF}
\bxce@do{women_holding_hands_tone4}{1F46D 1F3FE}
\bxce@do{women_holding_hands_tone4_tone1}{1F469 1F3FE 200D 1F91D 200D 1F469 1F3FB}
\bxce@do{women_holding_hands_tone4_tone2}{1F469 1F3FE 200D 1F91D 200D 1F469 1F3FC}
\bxce@do{women_holding_hands_tone4_tone3}{1F469 1F3FE 200D 1F91D 200D 1F469 1F3FD}
\bxce@do{women_holding_hands_tone4_tone5}{1F469 1F3FE 200D 1F91D 200D 1F469 1F3FF}
\bxce@do{women_holding_hands_tone5}{1F46D 1F3FF}
\bxce@do{women_holding_hands_tone5_tone1}{1F469 1F3FF 200D 1F91D 200D 1F469 1F3FB}
\bxce@do{women_holding_hands_tone5_tone2}{1F469 1F3FF 200D 1F91D 200D 1F469 1F3FC}
\bxce@do{women_holding_hands_tone5_tone3}{1F469 1F3FF 200D 1F91D 200D 1F469 1F3FD}
\bxce@do{women_holding_hands_tone5_tone4}{1F469 1F3FF 200D 1F91D 200D 1F469 1F3FE}
\bxce@do{women_with_bunny_ears_partying}{1F46F 200D 2640}
\bxce@do{women_wrestling}{1F93C 200D 2640}
\bxce@do{womens}{1F6BA}
\bxce@do{wood}{1FAB5}
\bxce@do{woozy_face}{1F974}
\bxce@do{worm}{1FAB1}
\bxce@do{worried}{1F61F}
\bxce@do{wrench}{1F527}
\bxce@do{writing_hand}{270D}
\bxce@do{writing_hand_tone1}{270D 1F3FB}
\bxce@do{writing_hand_tone2}{270D 1F3FC}
\bxce@do{writing_hand_tone3}{270D 1F3FD}
\bxce@do{writing_hand_tone4}{270D 1F3FE}
\bxce@do{writing_hand_tone5}{270D 1F3FF}
\or %[7]
\bxce@do{x}{274C}
\bxce@do{yarn}{1F9F6}
\bxce@do{yawning_face}{1F971}
\bxce@do{yellow_circle}{1F7E1}
\bxce@do{yellow_heart}{1F49B}
\bxce@do{yellow_square}{1F7E8}
\bxce@do{yen}{1F4B4}
\bxce@do{yin_yang}{262F}
\bxce@do{yo_yo}{1FA80}
\bxce@do{yum}{1F60B}
\bxce@do{zany_face}{1F92A}
\bxce@do{zap}{26A1}
\bxce@do{zebra}{1F993}
\bxce@do{zero}{30 20E3}
\bxce@do{zipper_mouth}{1F910}
\bxce@do{zombie}{1F9DF}
\bxce@do{zzz}{1F4A4}
\else
\bxce@do{1}{0}
\bxce@do{8}{0}
\bxce@do{a}{0}
\bxce@do{b}{0}
\bxce@do{c}{0}
\bxce@do{d}{1}
\bxce@do{e}{1}
\bxce@do{f}{1}
\bxce@do{g}{2}
\bxce@do{h}{2}
\bxce@do{i}{2}
\bxce@do{j}{2}
\bxce@do{k}{2}
\bxce@do{l}{2}
\bxce@do{m}{3}
\bxce@do{n}{4}
\bxce@do{o}{4}
\bxce@do{p}{4}
\bxce@do{q}{5}
\bxce@do{r}{5}
\bxce@do{s}{5}
\bxce@do{t}{6}
\bxce@do{u}{6}
\bxce@do{v}{6}
\bxce@do{w}{6}
\bxce@do{x}{7}
\bxce@do{y}{7}
\bxce@do{z}{7}
\fi
\bxce@ndend
%--------------------------------------- done
%% EOF
